--  @(#)61    1.9  src/tedw_apps/inv/install/v420/cdw/ddl/inv_cdw_schema.sql, inventory, inventory_4.2.2, 20041114  12/2/03  17:17:22
--
-- Licensed Materials - Property of IBM
--
-- 5698-INV
--
-- (C) Copyright IBM Corp. 2002 All Rights Reserved
--
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with
-- IBM Corp

---------------------------------------------------------------------------------
--  NOTE: the Central Data Warehouse (CDW) is always on DB2 so the staging tables
-- and other DB objects are always the same whatever is the RIM database involved
-- in the ETL process.
---------------------------------------------------------------------------------
--
-----------------------------------------
-- Inventory Staging Tables
-----------------------------------------

-- initial staging tables

create table inv.stage_COMPUTER_t (
COMPUTER_SYS_ID varchar(64),
TME_OBJECT_ID varchar(128),
TME_OBJECT_LABEL varchar(254),
COMPUTER_MODEL varchar(128),
SYS_SER_NUM varchar(32),
OS_NAME varchar(64),
OS_TYPE varchar(32),
OS_MAJOR_VERS integer,
OS_MINOR_VERS integer,
OS_SUB_VERS varchar(32),
RECORD_TIME timestamp
);
create table inv.stage_COMPUTER like inv.stage_COMPUTER_t;

create table inv.stage_PCSYS_t (
COMPUTER_SYS_ID varchar(64),
USER_NAME varchar(32),
DOMAIN_NAME varchar(32),
WORKGROUP_NAME varchar(32)
);
create table inv.stage_PCSYS like inv.stage_PCSYS_t;

create table inv.stage_IPNETWORK_t (
COMPUTER_SYS_ID varchar(64),
IP_HOSTNAME varchar(64),
IP_DOMAIN varchar(64),
IP_ADDR varchar(40)
);
create table inv.stage_IPNETWORK like inv.stage_IPNETWORK_t;

create table inv.stage_IPXNETWORK_t (
COMPUTER_SYS_ID varchar(64),
IPX_ADDR varchar(40)
);
create table inv.stage_IPXNETWORK like inv.stage_IPXNETWORK_t;

create table inv.stage_MEMORY_t (
COMPUTER_SYS_ID varchar(64),
PHYSICAL_TOTAL_KB integer
);
create table inv.stage_MEMORY like inv.stage_MEMORY_t;

create table inv.stage_PROCESSOR_t (
COMPUTER_SYS_ID varchar(64),
NUM_PROCESSORS integer,
MANUFACTURER varchar(64),
PROCESSOR_MODEL varchar(32),
MAX_SPEED integer,
CURRENT_SPEED integer,
CHIP_FAMILY integer,
CHIP_MODEL integer
);
create table inv.stage_PROCESSOR like inv.stage_PROCESSOR_t;

create table inv.stage_STORAGE_t (
COMPUTER_SYS_ID varchar(64),
INST_STORAGE_ID integer,
STORAGE_TYPE varchar(64),
MANUFACTURER varchar(128),
MODEL varchar(254),
HDISK_SIZE_MB integer
);
create table inv.stage_STORAGE like inv.stage_STORAGE_t;

create table inv.stage_MEM_MODULE_t (
COMPUTER_SYS_ID varchar(64),
INST_MEM_ID integer,
MODULE_SIZE_MB integer,
SOCKET_NAME varchar(32),
PACKAGING varchar(16),
MEM_TYPE varchar(48)
);
create table inv.stage_MEM_MODULE like inv.stage_MEM_MODULE_t;

-- unified stage table

create table inv.stage_IP_HOST_t(
COMPUTER_SYS_ID varchar(64) not null,
COMP_NM varchar(254) not null,
TME_OBJECT_ID varchar(128) not null,
TME_OBJECT_LABEL varchar(254) not null,
COMPUTER_MODEL varchar(128) not null,
SYS_SER_NUM varchar(32) not null,
OS_NAME varchar(64) not null,
OS_TYPE varchar(32) not null,
OS_MAJOR_VERS integer not null,
OS_MINOR_VERS integer not null,
OS_SUB_VERS varchar(32) not null,
RECORD_TIME timestamp not null,
USER_NAME varchar(32) not null,
DOMAIN_NAME varchar(32) not null,
WORKGROUP_NAME varchar(32) not null,
IP_HOSTNAME varchar(64) not null,
IP_DOMAIN varchar(64) not null,
IP_ADDR varchar(40) not null,
IPX_ADDR varchar(40) not null,
PHYSICAL_TOTAL_KB integer not null,
NUM_PROCESSORS integer not null,
MANUFACTURER varchar(64) not null,
PROCESSOR_MODEL varchar(32) not null,
MAX_SPEED integer not null,
CURRENT_SPEED integer not null,
CHIP_FAMILY integer not null,
CHIP_MODEL integer not null,
SYSTEM_PURPOSE varchar(32) not null
);
create table inv.stage_IP_HOST like inv.stage_IP_HOST_t;

create table inv.stage_INV_STOR_t (
COMP_NM varchar(254) not null,
CHILD_COMP_NM varchar(254) not null,
STORAGE_TYPE varchar(64) not null,
MANUFACTURER varchar(128) not null,
MODEL varchar(254) not null,
HDISK_SIZE_MB integer not null
);
create table inv.stage_INV_STOR like inv.stage_INV_STOR_t;

create table inv.stage_INV_MEMORY_t (
COMP_NM varchar(254) not null,
CHILD_COMP_NM varchar(254) not null,
MODULE_SIZE_MB integer not null,
SOCKET_NAME varchar(32) not null,
PACKAGING varchar(16) not null,
MEM_TYPE varchar(48) not null
);
create table inv.stage_INV_MEMORY like inv.stage_INV_MEMORY_t;

--
-- Lookup and reject tables for INV. We're using fqhostname as the lookup value
--
CREATE TABLE INV.cust_lookup (
   cust_acct_cd  CHAR(3),
   value         CHAR(32)
);

CREATE TABLE INV.centr_lookup (
   centr_cd  CHAR(3),
   value     CHAR(32)
);

--
-- This table has the same columns
-- as stage_ip_host.
--
CREATE TABLE INV.Invalid_IP_HOST like inv.stage_IP_HOST_t;


--------------------------------------------------------------
-- Software and Mdist2 Staging Tables
-- The column in the final staging table will set to not null
-- except for the timestamp column, because I don't what will 
-- be the default value for the timestamp.
--------------------------------------------------------------

-- initial staging tables
-- RECORD_TIME will convert to UTC

create table inv.stage_sd_h_inst_t (
computer_sys_id varchar(64),
tme_sware_oid varchar(64),
sware_atime varchar(32),
sd_action varchar(64),
state varchar(32),
md2_dist_id varchar(32),
record_time TIMESTAMP
);
create table inv.stage_sd_h_inst like inv.stage_sd_h_inst_t;

create table inv.stage_sd_package_t (
sware_name varchar(128) not null,
sware_vers varchar(64) not null,
tme_sware_oid varchar(64),
sware_src_host varchar(64)
);
create table inv.stage_sd_package like inv.stage_sd_package_t;

----------------------------------------------------------------------
-- Extract All the distribution with source is 'Software Distribution'
-- No matter FINISH_TIME is null or not
----------------------------------------------------------------------
create table inv.stage_dist_state_t (
md2_dist_id varchar(32) not null,
dist_size integer not null,
start_time timestamp,
finish_time timestamp,
source_application varchar(251) not null,
last_modify_time TIMESTAMP not null
);
create table inv.stage_dist_state like inv.stage_dist_state_t;

----------------------------------------------------------------------
-- Extract All the distribution with a valid FINISH_TIME
----------------------------------------------------------------------
create table inv.stage_dist_node_state_t (
md2_dist_id varchar(32),
tme_object_id varchar(50),
start_time timestamp,
finish_time timestamp,
current_state integer,
receiving_time integer,
last_modify_time TIMESTAMP
);
create table inv.stage_dist_node_state like inv.stage_dist_node_state_t;

create table inv.stage_dis_swd_t (
comp_nm varchar(254) not null,
child_comp_nm varchar(254) not null,
dis_sd_atime varchar(32) not null,
dis_sd_operation varchar(64) not null,
dis_sd_state varchar(32) not null,
dis_md_state integer not null,
dis_fp_tme_oid varchar(64) not null,
md2_start_time timestamp not null,
md2_finish_time timestamp not null,
md2_receiving_time integer not null,
md2_dist_size integer not null,
md2_elapsed_time integer not null,
last_modify_time TIMESTAMP not null
);
create table inv.stage_dis_swd like inv.stage_dis_swd_t;

create table inv.stage_dis_filepack_t (
comp_nm varchar(254) not null,
dis_fp_name varchar(128) not null,
version varchar(64) not null,
dis_fp_tme_oid varchar(64) not null,
dis_fp_src_host varchar(64) not null
);
create table inv.stage_dis_filepack like inv.stage_dis_filepack_t;

-----------------------------------------
-- Create Star schema Tables
-----------------------------------------

--staging tables for datamart process

create table inv.stage_d_metric (
 metric_id            integer not null,
 insert_dttm          timestamp not null,
 met_name             varchar(52) not null,
 met_desc             varchar(254),
 met_units            varchar(20) not null,
 met_category         varchar(120) not null,
 min_exists           character not null,
 max_exists           character not null,
 avg_exists           character not null,
 total_exists         character not null,
 msrc_nm              varchar(50),
       primary key (metric_id)
);

-- host state table

create table inv.stage_host_state_t (
 host_id          integer not null,
 hostname         varchar(64) not null,
 ip_address       varchar(40) not null,
 os_name          varchar(64) not null,
 major_version    integer not null,
 minor_version    integer not null,
 sub_version     varchar(32) ,
 physical_mem_kb  integer not null,
 num_cpus         integer not null,
 cpu_model        varchar(32) not null,
 cpu_speed_mhz    integer not null,
      primary key (host_id)
);

create table inv.stage_host_state like inv.stage_host_state_t;

create view inv.ip_address_v1 as
select
 ip_address,
 LOCATE('.',ip_address) - 1 as addr_w_end,
 LOCATE('.',ip_address,LOCATE('.',ip_address) + 1) -1 as addr_x_end,
 LOCATE('.',ip_address,LOCATE('.',ip_address,LOCATE('.',ip_address) + 1) + 1) -1 as addr_y_end
from
 inv.stage_host_state
group by
 ip_address
;

create view inv.hostname_v1 as 
select 
  hostname,
  LOCATE('.',hostname) + 1 as name_b_beg,
  LOCATE('.',hostname,LOCATE('.',hostname) + 1) + 1 as name_c_beg,
  LOCATE('.',hostname,LOCATE('.',hostname,LOCATE('.',hostname) + 1) + 1) + 1 as name_d_beg,
  LOCATE('.',hostname,LOCATE('.',hostname,LOCATE('.',hostname,LOCATE('.',hostname) + 1) + 1) + 1) +1 as name_e_beg
from
  inv.stage_host_state
group by
  hostname
;

create view inv.hostname_v2 as
select
  hostname,
  name_b_beg,
  name_c_beg,
  name_d_beg,
  name_e_beg,
  case  when (name_b_beg > 1 and name_c_beg > 1 and name_d_beg > 1 and name_e_beg > 1) then 5
      when (name_b_beg > 1 and name_c_beg > 1 and name_d_beg > 1 and name_e_beg = 1) then 4
      when (name_b_beg > 1 and name_c_beg > 1 and name_d_beg = 1 ) then 3
      when (name_b_beg > 1 and name_c_beg = 1 ) then 2
      when (name_b_beg = 1 ) then 1
  end   as name_parts
from
  inv.hostname_v1
;

-- temp tables and views to build d_swd_host

create table inv.stage_ip_address_t (
 ip_address   varchar(40) not null,
 IP_A_NETWORK varchar(40) not null,
 IP_B_NETWORK varchar(40) not null,
 IP_C_NETWORK varchar(40) not null
);
create table inv.stage_ip_address like inv.stage_ip_address_t;


create table inv.stage_hostname_t (
  HOSTNAME varchar(64),
  NETWORK_DOMAIN varchar(64),
  NETWORK_SUBDOMAIN varchar(64),
  NETWORK_SUBDOMAIN_2 varchar(64),
  SHORT_HOSTNAME varchar(64)
);
create table inv.stage_hostname like inv.stage_hostname_t;

-- FILE_PACK
create table inv.stage_file_pack (
 fp_id            integer not null,
 fp_name          varchar(128) not null,
 fp_version       varchar(64) not null,
 fp_name_version  varchar(192) not null,
 fp_tme_oid       varchar(64) not null,
 fp_src_host      varchar(64) not null,
      primary key (fp_id)
);
create table inv.stage_file_pack_t like inv.stage_file_pack;

-- stage_d_swd_dist, dist_id is the swd comp_id, host_id is ip_host comp_id
create table inv.stage_d_swd_dist_t (
 dist_id          integer not null,
 host_id		  integer not null,
 mdist_id		  varchar(32) not null,
 dist_size_kb     integer not null,
 filepack_name    varchar(128) not null,
 filepack_version varchar(32) not null,
 sd_action        varchar(64) not null,
 sd_state         varchar(32) not null,
 md_state         varchar(16) not null,
      primary key (dist_id)
);
create table inv.stage_d_swd_dist like inv.stage_d_swd_dist_t;
