--  @(#)63    1.12  src/tedw_apps/inv/install/v420/cdw/dml/inv_cdw_data.sql, inventory, inventory_4.2.2, 20041114  8/26/02  14:48:15
--
-- Licensed Materials - Property of IBM
--
-- 5698-INV
--
-- (C) Copyright IBM Corp. 2002 All Rights Reserved
--
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with
-- IBM Corp
--
-- This files defines specific entries for Configuration Manager.
--
-- All data being placed into TWH tables is initially inserted into a
-- temporary table that has the same columns as the target table in the CDW.
-- That table is then inserted into the CDW table with a "where not exists"
-- clause. This insures that duplicate data is not inserted and an
-- error is not generated for trying to insert duplicate data.


-- Insert Attribute Types
-- (defines the types of characteristics or properties that may be
-- captured about a component)
--
declare global temporary table AttrTyp (
       AttrTyp_Cd           CHAR(17) NOT NULL,
       AttrTyp_Nm           VARCHAR(120) NOT NULL
)
with replace on commit preserve rows not logged
;

insert into session.attrtyp values('INV_RECORD_TIME','Record Time');
insert into session.attrtyp values('INV_USER_NAME','PC user Name');
insert into session.attrtyp values('INV_DOMAIN_NAME','PC Domain Name');
insert into session.attrtyp values('INV_WORKGROUP_NM','PC Workgroup Name');
insert into session.attrtyp values('INV_IPX_ADDR','IPX Address');
insert into session.attrtyp values('INV_PHYSICAL_MEM','Physical Memory');
insert into session.attrtyp values('INV_NUM_CPU','Number of CPUs');
insert into session.attrtyp values('INV_CPU_MANUFACT','CPU Manufacturer');
insert into session.attrtyp values('INV_CPU_NAME','CPU Model Name');
insert into session.attrtyp values('INV_CPU_MAX_SPEED','CPU Maximum Speed');
insert into session.attrtyp values('INV_CPU_CUR_SPEED','CPU Current Speed');
insert into session.attrtyp values('INV_CPU_FAMILY','CPU Chip Family');
insert into session.attrtyp values('INV_CPU_MODEL','CPU Chip Model');
insert into session.attrtyp values('INV_SYS_PURPOSE','System Purpose');

insert into session.attrtyp values('INV_STO_TYPE','Storage Type');
insert into session.attrtyp values('INV_STO_SIZE_MB','Storage Size in MB');

insert into session.attrtyp values('INV_MEM_TYPE','Memory Type');
insert into session.attrtyp values('INV_MEM_PACKAGE','Memory Package');
insert into session.attrtyp values('INV_MEM_SOCKET','Memory Socket Name');
insert into session.attrtyp values('INV_MEM_SIZE_MB','Memory Size in MB');

insert into twg.AttrTyp
select * from
 session.AttrTyp s
where not exists
( select 1 from
  twg.AttrTyp t
  where
  t.AttrTyp_Cd = s.AttrTyp_Cd )
;

--
-- Insert data into lookup tables to setup a single
-- customer/center environment.
--
insert into INV.cust_lookup
values ('CDW', '@')
;

insert into INV.centr_lookup
values ('CDW', '@')
;

-- @@@@@@@@@@@@@@@ CompTyp @@@@@@@@@@@@@@@
-- create a temporary table for component types

declare global temporary table CompTyp (
      CompTyp_Cd              CHAR(17) NOT NULL,
      CompTyp_Nm              VARCHAR(120) NOT NULL,
      CompTyp_Strt_DtTm       TIMESTAMP NOT NULL,
      CompTyp_End_DtTm        TIMESTAMP NOT NULL
        )
        with replace on commit preserve rows not logged;

insert into session.CompTyp(CompTyp_Cd, CompTyp_Nm,
                                      CompTyp_Strt_DtTm, CompTyp_End_DtTm)
        values('INV_STORAGE', 'Storage',
             Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000');

insert into session.CompTyp(CompTyp_Cd, CompTyp_Nm,
                                      CompTyp_Strt_DtTm, CompTyp_End_DtTm)
        values('INV_MEMORY', 'Memory',
             Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000');

-- insert the component types into the CDW
-- where not exists

insert into TWG.CompTyp (CompTyp_Cd, CompTyp_Nm,
                         CompTyp_Strt_DtTm, CompTyp_End_DtTm)
        select s.CompTyp_Cd,
                 s.CompTyp_Nm,
                 s.CompTyp_Strt_DtTm,
                 s.CompTyp_End_DtTm
        from session.CompTyp s
        where not exists
                (select 1 from TWG.Cur_CompTyp t
                where t.CompTyp_Cd=s.CompTyp_Cd);

delete from session.CompTyp;

-- @@@@@@@@@@@@@@@ RelnRul @@@@@@@@@@@@@@
-- create a temporary table for component relationship rules

declare global temporary table RelnRul (
        CompTyp_Source_Cd       CHAR(17) NOT NULL,
        CompTyp_Target_Cd       CHAR(17) NOT NULL,
        RelnTyp_Cd              CHAR(6) NOT NULL,
        RelnRul_Strt_DtTm       TIMESTAMP NOT NULL,
        RelnRul_End_DtTm        TIMESTAMP NOT NULL
        )
  with replace on commit preserve rows not logged;

insert into session.RelnRul(CompTyp_Source_Cd, CompTyp_Target_Cd, RelnTyp_Cd,
                                          RelnRul_Strt_DtTm, RelnRul_End_DtTm)
        values('IP_HOST', 'INV_STORAGE', 'PCHILD',
             Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000');

insert into session.RelnRul(CompTyp_Source_Cd, CompTyp_Target_Cd, RelnTyp_Cd,
                                          RelnRul_Strt_DtTm, RelnRul_End_DtTm)
        values('IP_HOST', 'INV_MEMORY', 'PCHILD',
             Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000');

insert into session.RelnRul(CompTyp_Source_Cd, CompTyp_Target_Cd, RelnTyp_Cd,
                                          RelnRul_Strt_DtTm, RelnRul_End_DtTm)
        values('IP_INTERFACE', 'INV_STORAGE', 'PCHILD',
             Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000');

insert into session.RelnRul(CompTyp_Source_Cd, CompTyp_Target_Cd, RelnTyp_Cd,
                                          RelnRul_Strt_DtTm, RelnRul_End_DtTm)
        values('IP_INTERFACE', 'INV_MEMORY', 'PCHILD',
             Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000');
insert into session.RelnRul(CompTyp_Source_Cd, CompTyp_Target_Cd, RelnTyp_Cd,
                                          RelnRul_Strt_DtTm, RelnRul_End_DtTm)
        values('IPX_INTERFACE', 'INV_STORAGE', 'PCHILD',
             Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000');

insert into session.RelnRul(CompTyp_Source_Cd, CompTyp_Target_Cd, RelnTyp_Cd,
                                          RelnRul_Strt_DtTm, RelnRul_End_DtTm)
        values('IPX_INTERFACE', 'INV_MEMORY', 'PCHILD',
             Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000');

-- insert the component relationship rules into the CDW
-- where not exists

insert into TWG.RelnRul (CompTyp_Source_Cd, CompTyp_Target_Cd, RelnTyp_Cd,
                         RelnRul_Strt_DtTm, RelnRul_End_DtTm)
        select s.CompTyp_Source_Cd,
             s.CompTyp_Target_Cd,
             s.RelnTyp_Cd,
             s.RelnRul_Strt_DtTm,
             s.RelnRul_End_DtTm
        from session.RelnRul s
        where not exists
                (select 1 from TWG.RelnRul t
                where t.CompTyp_Source_Cd=s.CompTyp_Source_Cd
                and t.CompTyp_Target_Cd=s.CompTyp_Target_Cd
                and t.RelnTyp_Cd=s.RelnTyp_Cd
-- no trigger to set the End_DtTm automatically
-- so only add new one when an existing one has ended
                and t.RelnRul_End_DtTm > s.RelnRul_Strt_DtTm );

delete from session.RelnRul;


-- @@@@@@@@@@@@@@@ AttrRul @@@@@@@@@@@@@@
-- create a temporary table

declare global temporary table AttrRul (
  CompTyp_Cd              CHAR(17) NOT NULL,
  AttrTyp_Cd              CHAR(17) NOT NULL,
  AttrTyp_Strt_DtTm       TIMESTAMP NOT NULL,
  AttrTyp_End_DtTm        TIMESTAMP NOT NULL,
  Attr_Dom_Ind            CHAR(1) NOT NULL
)
with replace on commit preserve rows not logged
;

insert into session.AttrRul values ('IP_HOST',      'INV_RECORD_TIME',   Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000','N');
insert into session.AttrRul values ('IP_HOST',      'INV_USER_NAME',     Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000','N');
insert into session.AttrRul values ('IP_HOST',      'INV_DOMAIN_NAME',   Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000','N');
insert into session.AttrRul values ('IP_HOST',      'INV_WORKGROUP_NM',  Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000','N');
insert into session.AttrRul values ('IP_HOST',      'INV_IPX_ADDR',      Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000','N');
insert into session.AttrRul values ('IP_HOST',      'INV_PHYSICAL_MEM',  Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000','N');
insert into session.AttrRul values ('IP_HOST',      'INV_NUM_CPU',       Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000','N');
insert into session.AttrRul values ('IP_HOST',      'INV_CPU_MANUFACT',  Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000','N');
insert into session.AttrRul values ('IP_HOST',      'INV_CPU_NAME',      Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000','N');
insert into session.AttrRul values ('IP_HOST',      'INV_CPU_MAX_SPEED', Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000','N');
insert into session.AttrRul values ('IP_HOST',      'INV_CPU_CUR_SPEED', Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000','N');
insert into session.AttrRul values ('IP_HOST',      'INV_CPU_FAMILY',    Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000','N');
insert into session.AttrRul values ('IP_HOST',      'INV_CPU_MODEL',     Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000','N');
insert into session.AttrRul values ('IP_HOST',      'INV_SYS_PURPOSE',   Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000','N');
insert into session.AttrRul values ('IP_INTERFACE', 'INV_RECORD_TIME',   Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000','N');
insert into session.AttrRul values ('IP_INTERFACE', 'INV_USER_NAME',     Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000','N');
insert into session.AttrRul values ('IP_INTERFACE', 'INV_DOMAIN_NAME',   Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000','N');
insert into session.AttrRul values ('IP_INTERFACE', 'INV_WORKGROUP_NM',  Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000','N');
insert into session.AttrRul values ('IP_INTERFACE', 'INV_IPX_ADDR',      Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000','N');
insert into session.AttrRul values ('IP_INTERFACE', 'INV_PHYSICAL_MEM',  Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000','N');
insert into session.AttrRul values ('IP_INTERFACE', 'INV_NUM_CPU',       Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000','N');
insert into session.AttrRul values ('IP_INTERFACE', 'INV_CPU_MANUFACT',  Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000','N');
insert into session.AttrRul values ('IP_INTERFACE', 'INV_CPU_NAME',      Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000','N');
insert into session.AttrRul values ('IP_INTERFACE', 'INV_CPU_MAX_SPEED', Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000','N');
insert into session.AttrRul values ('IP_INTERFACE', 'INV_CPU_CUR_SPEED', Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000','N');
insert into session.AttrRul values ('IP_INTERFACE', 'INV_CPU_FAMILY',    Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000','N');
insert into session.AttrRul values ('IP_INTERFACE', 'INV_CPU_MODEL',     Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000','N');
insert into session.AttrRul values ('IP_INTERFACE', 'INV_SYS_PURPOSE',   Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000','N');
insert into session.AttrRul values ('IPX_INTERFACE', 'INV_RECORD_TIME',   Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000','N');
insert into session.AttrRul values ('IPX_INTERFACE', 'INV_USER_NAME',     Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000','N');
insert into session.AttrRul values ('IPX_INTERFACE', 'INV_DOMAIN_NAME',   Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000','N');
insert into session.AttrRul values ('IPX_INTERFACE', 'INV_WORKGROUP_NM',  Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000','N');
insert into session.AttrRul values ('IPX_INTERFACE', 'INV_IPX_ADDR',      Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000','N');
insert into session.AttrRul values ('IPX_INTERFACE', 'INV_PHYSICAL_MEM',  Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000','N');
insert into session.AttrRul values ('IPX_INTERFACE', 'INV_NUM_CPU',       Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000','N');
insert into session.AttrRul values ('IPX_INTERFACE', 'INV_CPU_MANUFACT',  Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000','N');
insert into session.AttrRul values ('IPX_INTERFACE', 'INV_CPU_NAME',      Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000','N');
insert into session.AttrRul values ('IPX_INTERFACE', 'INV_CPU_MAX_SPEED', Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000','N');
insert into session.AttrRul values ('IPX_INTERFACE', 'INV_CPU_CUR_SPEED', Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000','N');
insert into session.AttrRul values ('IPX_INTERFACE', 'INV_CPU_FAMILY',    Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000','N');
insert into session.AttrRul values ('IPX_INTERFACE', 'INV_CPU_MODEL',     Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000','N');
insert into session.AttrRul values ('IPX_INTERFACE', 'INV_SYS_PURPOSE',   Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000','N');
insert into session.AttrRul values ('INV_STORAGE',  'INV_STO_TYPE',      Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000','N');
insert into session.AttrRul values ('INV_STORAGE',  'INV_STO_SIZE_MB',   Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000','N');
insert into session.AttrRul values ('INV_MEMORY',   'INV_MEM_SIZE_MB',   Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000','N');
insert into session.AttrRul values ('INV_MEMORY',   'INV_MEM_SOCKET',    Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000','N');
insert into session.AttrRul values ('INV_MEMORY',   'INV_MEM_PACKAGE',   Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000','N');
insert into session.AttrRul values ('INV_MEMORY',   'INV_MEM_TYPE',      Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000','N');

insert into twg.AttrRul
select * from session.AttrRul s
where not exists
  (select 1 from twg.AttrRul t
  where t.CompTyp_Cd = s.CompTyp_Cd
  and   t.AttrTyp_Cd = s.AttrTyp_Cd);

delete from session.AttrRul;


-- START SWD and MDIST2 SECTION

-- Insert Attribute Types
-- (defines the types of characteristics or properties that may be
-- captured about a component)
--
declare global temporary table AttrTyp (
       AttrTyp_Cd           CHAR(17) NOT NULL,
       AttrTyp_Nm           VARCHAR(120) NOT NULL
)
with replace on commit preserve rows not logged
;

insert into session.attrtyp values('DIS_FP_NAME','Software Distribution File Pack Name');
insert into session.attrtyp values('VERSION','Version of The File Pack');
insert into session.attrtyp values('DIS_FP_SRC_HOST','Software Distribution Software Source Host');
insert into session.attrtyp values('DIS_FP_TME_OID','Software Distribution File Pack OID');

insert into session.attrtyp values('DIS_SD_ATIME','Software Distribution Software Activated Time');
insert into session.attrtyp values('DIS_SD_OPERATION','Software Distribution Operation');
insert into session.attrtyp values('DIS_SD_STATE','Software Distribution Operaton State');
insert into session.attrtyp values('DIS_MD_STATE','Multiplexed Distribution Node Current State');
insert into session.attrtyp values('DIS_MD_SIZE_KB','Multiplexed Distribution Package Size in KB');
insert into session.attrtyp values('DIS_MD_STTM','Multiplexed Distribution Start Time');
insert into session.attrtyp values('DIS_MD_ENDTM','Multiplexed Distribution Finish Time');
insert into session.attrtyp values('DIS_MD_SRCAPPL','Multiplexed Distribution Source Application');


insert into twg.AttrTyp
select * from
 session.AttrTyp s
where not exists
( select 1 from
  twg.AttrTyp t
  where
  t.AttrTyp_Cd = s.AttrTyp_Cd )
;

-- @@@@@@@@@@@@@@@ CompTyp @@@@@@@@@@@@@@@
-- create a temporary table for component types

declare global temporary table CompTyp (
      CompTyp_Cd              CHAR(17) NOT NULL,
      CompTyp_Nm              VARCHAR(120) NOT NULL,
      CompTyp_Strt_DtTm       TIMESTAMP NOT NULL,
      CompTyp_End_DtTm        TIMESTAMP NOT NULL
        )
        with replace on commit preserve rows not logged;

insert into session.CompTyp(CompTyp_Cd, CompTyp_Nm,
                                      CompTyp_Strt_DtTm, CompTyp_End_DtTm)
        values('DIS_SWD', 'Software Distribution',
             Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000');

insert into session.CompTyp(CompTyp_Cd, CompTyp_Nm,
                                      CompTyp_Strt_DtTm, CompTyp_End_DtTm)
        values('DIS_FILEPACK', 'Software Distribution File pack',
             Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000');

insert into session.CompTyp(CompTyp_Cd, CompTyp_Nm,
                                      CompTyp_Strt_DtTm, CompTyp_End_DtTm)
        values('DIS_MDIST', 'Multiplexed Distribution',
             Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000');

-- insert the component types into the CDW
-- where not exists

insert into TWG.CompTyp (CompTyp_Cd, CompTyp_Nm,
                         CompTyp_Strt_DtTm, CompTyp_End_DtTm)
        select s.CompTyp_Cd,
                 s.CompTyp_Nm,
                 s.CompTyp_Strt_DtTm,
                 s.CompTyp_End_DtTm
        from session.CompTyp s
        where not exists
                (select 1 from TWG.Cur_CompTyp t
                where t.CompTyp_Cd=s.CompTyp_Cd);

delete from session.CompTyp;

-- @@@@@@@@@@@@@@@ RelnRul @@@@@@@@@@@@@@
-- create a temporary table for component relationship rules

declare global temporary table RelnRul (
        CompTyp_Source_Cd       CHAR(17) NOT NULL,
        CompTyp_Target_Cd       CHAR(17) NOT NULL,
        RelnTyp_Cd              CHAR(6) NOT NULL,
        RelnRul_Strt_DtTm       TIMESTAMP NOT NULL,
        RelnRul_End_DtTm        TIMESTAMP NOT NULL
        )
  with replace on commit preserve rows not logged;

insert into session.RelnRul(CompTyp_Source_Cd, CompTyp_Target_Cd, RelnTyp_Cd,
                                          RelnRul_Strt_DtTm, RelnRul_End_DtTm)
        values('IP_HOST', 'DIS_SWD', 'PCHILD',
             Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000');

insert into session.RelnRul(CompTyp_Source_Cd, CompTyp_Target_Cd, RelnTyp_Cd,
                                          RelnRul_Strt_DtTm, RelnRul_End_DtTm)
        values('IP_INTERFACE', 'DIS_SWD', 'PCHILD',
             Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000');

insert into session.RelnRul(CompTyp_Source_Cd, CompTyp_Target_Cd, RelnTyp_Cd,
                                          RelnRul_Strt_DtTm, RelnRul_End_DtTm)
        values('IPX_INTERFACE', 'DIS_SWD', 'PCHILD',
             Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000');

-- insert the component relationship rules into the CDW
-- where not exists

insert into TWG.RelnRul (CompTyp_Source_Cd, CompTyp_Target_Cd, RelnTyp_Cd,
                         RelnRul_Strt_DtTm, RelnRul_End_DtTm)
        select s.CompTyp_Source_Cd,
             s.CompTyp_Target_Cd,
             s.RelnTyp_Cd,
             s.RelnRul_Strt_DtTm,
             s.RelnRul_End_DtTm
        from session.RelnRul s
        where not exists
                (select 1 from TWG.RelnRul t
                where t.CompTyp_Source_Cd=s.CompTyp_Source_Cd
                and t.CompTyp_Target_Cd=s.CompTyp_Target_Cd
                and t.RelnTyp_Cd=s.RelnTyp_Cd
-- no trigger to set the End_DtTm automatically
-- so only add new one when an existing one has ended
                and t.RelnRul_End_DtTm > s.RelnRul_Strt_DtTm );

delete from session.RelnRul;


-- @@@@@@@@@@@@@@@ AttrRul @@@@@@@@@@@@@@
-- create a temporary table

declare global temporary table AttrRul (
  CompTyp_Cd              CHAR(17) NOT NULL,
  AttrTyp_Cd              CHAR(17) NOT NULL,
  AttrTyp_Strt_DtTm       TIMESTAMP NOT NULL,
  AttrTyp_End_DtTm        TIMESTAMP NOT NULL,
  Attr_Dom_Ind            CHAR(1) NOT NULL
)
with replace on commit preserve rows not logged
;

insert into session.AttrRul values ('DIS_FILEPACK',      'DIS_FP_NAME',       Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000','N');
insert into session.AttrRul values ('DIS_FILEPACK',      'VERSION',    Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000','N');
insert into session.AttrRul values ('DIS_FILEPACK',      'DIS_FP_TME_OID',  Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000','N');
insert into session.AttrRul values ('DIS_FILEPACK',      'DIS_FP_SRC_HOST',      Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000','N');

insert into session.AttrRul values ('DIS_SWD',      'DIS_SD_ATIME',     Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000','N');
insert into session.AttrRul values ('DIS_SWD',      'DIS_SD_OPERATION',     Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000','N');
insert into session.AttrRul values ('DIS_SWD',      'DIS_SD_STATE',  Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000','N');
insert into session.AttrRul values ('DIS_SWD',      'DIS_MD_STATE',  Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000','N');
insert into session.AttrRul values ('DIS_SWD',      'DIS_FP_TME_OID', Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000','N');
insert into session.AttrRul values ('DIS_SWD',      'DIS_MD_SIZE_KB', Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000','N');

insert into session.AttrRul values ('DIS_MDIST',      'DIS_MD_SIZE_KB', Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000','N');
insert into session.AttrRul values ('DIS_MDIST',      'DIS_MD_STTM', Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000','N');
insert into session.AttrRul values ('DIS_MDIST',      'DIS_MD_ENDTM', Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000','N');
insert into session.AttrRul values ('DIS_MDIST',      'DIS_MD_SRCAPPL', Current Timestamp - Current Timezone, '9999-01-01-00.00.00.000000','N');

insert into twg.AttrRul
select * from session.AttrRul s
where not exists
  (select 1 from twg.AttrRul t
  where t.CompTyp_Cd = s.CompTyp_Cd
  and   t.AttrTyp_Cd = s.AttrTyp_Cd);

delete from session.AttrRul;

-- @@@@@@@@@@@@@@@ MGrpTyp @@@@@@@@@@@@@@@
-- create a temporary table for measurement group type

declare global temporary table DIS_MGrpTyp (
        MGrpTyp_Cd           CHAR(6) NOT NULL,
        MGrpTyp_Nm           VARCHAR(120) NOT NULL
        )
  with replace on commit preserve rows not logged;

insert into session.DIS_MGrpTyp values ('DISSDW',      'Software Distribution Operation Status');
insert into session.DIS_MGrpTyp values ('DISMD',      'Multiplexed Distribution Status');

insert into twg.MGrpTyp
select * from session.DIS_MGrpTyp s
where not exists
  (select 1 from twg.MGrpTyp t
  where t.MGrpTyp_Cd = s.MGrpTyp_Cd);

delete from session.DIS_MGrpTyp;

-- @@@@@@@@@@@@@@@ MGrp @@@@@@@@@@@@@@@
-- create a temporary table for measurement group

declare global temporary table DIS_MGrp (
        MGrp_Cd           CHAR(6) NOT NULL,
        MGrpTyp_Cd        CHAR(6) NOT NULL,
        MGrp_Parent_Cd    CHAR(6),
        MGrp_Nm           VARCHAR(126) NOT NULL
        )
  with replace on commit preserve rows not logged;

insert into session.DIS_MGrp(MGrp_Cd, MGrpTyp_Cd, MGrp_Nm) values ('DISDST', 'DISMD', 'Host Distribution Status');
insert into session.DIS_MGrp(MGrp_Cd, MGrpTyp_Cd, MGrp_Nm) values ('DISOPR', 'DISSDW', 'Host Operation Status');

insert into twg.MGrp
select * from session.DIS_MGrp s
where not exists
  (select 1 from twg.MGrp t
  where t.MGrp_Cd = s.MGrp_Cd
  and   t.MGrpTyp_Cd = s.MGrpTyp_Cd);

delete from session.DIS_MGrp;

-- @@@@@@@@@@@@@@@ MUnitCat @@@@@@@@@@@@@@@
-- create a temporary table for measurement unit category

declare global temporary table DIS_MUnitCat (
        MunitCat_Cd       CHAR(6) NOT NULL,
        MunitCat_Nm       VARCHAR(126) NOT NULL
        )
  with replace on commit preserve rows not logged;

insert into session.DIS_MUnitCat values ('TM', 'Time Duration');
insert into session.DIS_MUnitCat values ('QTY', 'Quantity');
insert into session.DIS_MUnitCat values ('PRC', 'Percentage');
insert into session.DIS_MUnitCat values ('RT', 'Rate');

insert into twg.MUnitCat
select * from session.DIS_MUnitCat s
where not exists
  (select 1 from twg.MUnitCat t
  where t.MunitCat_Cd = s.MunitCat_Cd);

delete from session.DIS_MUnitCat;

-- @@@@@@@@@@@@@@@ MUnit @@@@@@@@@@@@@@@
-- create a temporary table for measurement unit

declare global temporary table DIS_MUnit (
        MUnit_Cd          CHAR(6) NOT NULL,
        MUnitCat_Cd       CHAR(6) NOT NULL,
        MUnitCat_Nm       VARCHAR(126) NOT NULL
        )
  with replace on commit preserve rows not logged;

insert into session.DIS_MUnit values ('KBps', 'RT', 'Kilobytes per Second');
insert into session.DIS_MUnit values ('QTY', 'QTY', 'Quantity');
insert into session.DIS_MUnit values ('Min', 'TM', 'Minutes');
insert into session.DIS_MUnit values ('Sec', 'TM', 'Seconds');

insert into twg.MUnit
select * from session.DIS_MUnit s
where not exists
  (select 1 from twg.MUnit t
  where t.MUnit_Cd = s.MUnit_Cd
  and t.MUnitCat_Cd = s.MUnitCat_Cd);

delete from session.DIS_MUnit;

-- @@@@@@@@@@@@@@@ TmSum @@@@@@@@@@@@@@@
-- create a temporary table for time summary

declare global temporary table DIS_TmSum (
        TmSum_Cd          CHAR NOT NULL,
        TMSum_Nm       VARCHAR(126) NOT NULL
        )
  with replace on commit preserve rows not logged;

insert into session.DIS_TmSum values ('D', 'Daily');

insert into twg.TmSum
select * from session.DIS_TmSum s
where not exists
  (select 1 from twg.TmSum t
  where t.TmSum_Cd = s.TmSum_Cd);

delete from session.DIS_TmSum;

-- @@@@@@@@@@@@@@@ MSrc @@@@@@@@@@@@@@
-- create a temporary table

declare global temporary table DIS_MSrc (
  MSrc_Cd              CHAR(6) NOT NULL,
  MSrc_Parent_Cd       CHAR(6),
  MSrc_Nm              VARCHAR(120) NOT NULL
)
with replace on commit preserve rows not logged
;

insert into session.DIS_MSrc values ('DIS', 'Tivoli', 'IBM Tivoli Software Distribution');
insert into session.DIS_MSrc values ('INV', 'Tivoli', 'IBM Tivoli Inventory');

insert into twg.MSrc
select * from session.DIS_MSrc s
where not exists
  (select 1 from twg.MSrc t
  where t.msrc_Cd = s.msrc_Cd);

delete from session.DIS_MSrc;

-- @@@@@@@@@@@@@@@ MsmtTyp @@@@@@@@@@@@@@@
-- create a temporary table for measurement types
-- NOTE: the MsmtTyp_ID field is populated by the before insert trigger
--           MsmtTyp_ID_Trig
--       so here we insert only a zero dummy value...
--
declare global temporary table DIS_MsmtTyp (
  MsmtTyp_ID           INTEGER      NOT NULL,
  MUnit_Cd             CHAR(6)      NOT NULL,
  MSrc_Cd              CHAR(6)      NOT NULL,
  MsmtTyp_Nm           VARCHAR(120) NOT NULL,
  MsmtTyp_Ds           VARCHAR(254)
)
with replace on commit preserve rows not logged;

insert into session.DIS_MsmtTyp values ( 0, 'QTY',  'DIS', 'Distribution Success', '1 indicates that the distribution was a success and 0 indicates a failure');
insert into session.DIS_MsmtTyp values ( 0, 'QTY',  'DIS', 'Distribution Failure', '1 indicates that the distribution was a failure and 0 indicates a success');
--insert into session.DIS_MsmtTyp values ( 0, 'QTY',  'DIS', 'Operation Success', '1 indicates that the operation was a success and 0 indicates a failure');
--insert into session.DIS_MsmtTyp values ( 0, 'QTY',  'DIS', 'Operation Failure', '1 indicates that the operation was a failure and 0 indicates a success');
insert into session.DIS_MsmtTyp values ( 0, 'QTY',  'DIS', 'Verify Failure', '1 indicates a verify failure after the operation was successful');
insert into session.DIS_MsmtTyp values ( 0, 'Sec',  'DIS', 'Distribution Elapsed Time', 'Wall clock time to distribute the file pack to a host');
insert into session.DIS_MsmtTyp values ( 0, 'Sec',  'DIS', 'Receiving Time', 'Receiving time for distributing the file pack to a host');
insert into session.DIS_MsmtTyp values ( 0, 'KBps',  'DIS', 'Distribution Transfer Rate', 'Distribution rate calculated as a radio of distribution size/distribution elapsed time');

insert into TWG.MsmtTyp
select * from session.DIS_MsmtTyp s
where not exists (
  select 1 from
  TWG.MsmtTyp t
  where
  t.MUnit_Cd   = s.MUnit_Cd and
  t.MSrc_Cd    = s.MSrc_Cd and
  t.MsmtTyp_Nm = s.MsmtTyp_Nm
);

delete from session.DIS_MsmtTyp;

-- @@@@@@@@@@@@@@@ MGrpMbr @@@@@@@@@@@@@@@
-- create a temporary table for measurement group members

declare global temporary table DIS_MGrpMbr (
        MGrp_Cd              CHAR(6) NOT NULL,
        MGrpTyp_Cd           CHAR(6) NOT NULL,
        MsmtTyp_Id           INTEGER NOT NULL
        )
  with replace on commit preserve rows not logged;

insert into session.DIS_MGrpMbr
(select 'DISDST','DISMD', t.MsmtTyp_ID from TWG.MsmtTyp t where MsmtTyp_Nm = 'Distribution Success');
insert into session.DIS_MGrpMbr
(select 'DISDST','DISMD', t.MsmtTyp_ID from TWG.MsmtTyp t where MsmtTyp_Nm = 'Distribution Failure');
--insert into session.DIS_MGrpMbr
--(select 'DISOPR','DISSDW', t.MsmtTyp_ID from TWG.MsmtTyp t where MsmtTyp_Nm = 'Operation Success');
--insert into session.DIS_MGrpMbr
--(select 'DISOPR','DISSDW', t.MsmtTyp_ID from TWG.MsmtTyp t where MsmtTyp_Nm = 'Distribution Failure');
insert into session.DIS_MGrpMbr
(select 'DISOPR','DISSDW', t.MsmtTyp_ID from TWG.MsmtTyp t where MsmtTyp_Nm = 'Verify Failure');
insert into session.DIS_MGrpMbr
(select 'DISDST','DISMD', t.MsmtTyp_ID from TWG.MsmtTyp t where MsmtTyp_Nm = 'Distribution Elapsed Time');
insert into session.DIS_MGrpMbr
(select 'DISDST','DISMD', t.MsmtTyp_ID from TWG.MsmtTyp t where MsmtTyp_Nm = 'Receiving Time');
insert into session.DIS_MGrpMbr
(select 'DISDST','DISMD', t.MsmtTyp_ID from TWG.MsmtTyp t where MsmtTyp_Nm = 'Distribution Transfer Rate');
insert into session.DIS_MGrpMbr
(select 'TOT_E','GROUP', t.MsmtTyp_ID from TWG.MsmtTyp t where MsmtTyp_Nm = 'Distribution Success');
insert into session.DIS_MGrpMbr
(select 'TOT_E','GROUP', t.MsmtTyp_ID from TWG.MsmtTyp t where MsmtTyp_Nm = 'Distribution Failure');
insert into session.DIS_MGrpMbr
(select 'TOT_E','GROUP', t.MsmtTyp_ID from TWG.MsmtTyp t where MsmtTyp_Nm = 'Operation Success');
insert into session.DIS_MGrpMbr
(select 'TOT_E','GROUP', t.MsmtTyp_ID from TWG.MsmtTyp t where MsmtTyp_Nm = 'Operation Failure');
insert into session.DIS_MGrpMbr
(select 'TOT_E','GROUP', t.MsmtTyp_ID from TWG.MsmtTyp t where MsmtTyp_Nm = 'Verify Failure');
insert into session.DIS_MGrpMbr
(select 'TOT_E','GROUP', t.MsmtTyp_ID from TWG.MsmtTyp t where MsmtTyp_Nm = 'Distribution Elapsed Time');
insert into session.DIS_MGrpMbr
(select 'TOT_E','GROUP', t.MsmtTyp_ID from TWG.MsmtTyp t where MsmtTyp_Nm = 'Receiving Time');
insert into session.DIS_MGrpMbr
(select 'TOT_E','GROUP', t.MsmtTyp_ID from TWG.MsmtTyp t where MsmtTyp_Nm = 'Distribution Transfer Rate');

-- insert the measurement group member into the CDW
-- where not exists

insert into TWG.MGrpMbr
        select *
        from session.DIS_MGrpMbr s
        where not exists
                ( select 1 from TWG.MGrpMbr t
                where t.MGrp_Cd=s.MGrp_Cd
                and t.MGrpTyp_Cd=s.MGrpTyp_Cd
                and t.MsmtTyp_Id=s.MsmtTyp_Id);

delete from session.DIS_MGrpMbr;

-- @@@@@@@@@@@@@@@ MsmtRul @@@@@@@@@@@@@@
-- create a temporary table for measurement rule

declare global temporary table DIS_MsmtRul (
  CompTyp_Cd      CHAR(17) NOT NULL,
  MsmtTyp_ID      INTEGER  NOT NULL
)
with replace on commit preserve rows not logged;

insert into session.DIS_MsmtRul
(select 'DIS_SWD', t.MsmtTyp_ID from TWG.MsmtTyp t where MsmtTyp_Nm = 'Distribution Success');
insert into session.DIS_MsmtRul
(select 'DIS_SWD', t.MsmtTyp_ID from TWG.MsmtTyp t where MsmtTyp_Nm = 'Distribution Failure');
insert into session.DIS_MsmtRul
(select 'DIS_SWD', t.MsmtTyp_ID from TWG.MsmtTyp t where MsmtTyp_Nm = 'Verify Failure');
insert into session.DIS_MsmtRul
(select 'DIS_SWD', t.MsmtTyp_ID from TWG.MsmtTyp t where MsmtTyp_Nm = 'Distribution Elapsed Time');
insert into session.DIS_MsmtRul
(select 'DIS_SWD', t.MsmtTyp_ID from TWG.MsmtTyp t where MsmtTyp_Nm = 'Receiving Time');
insert into session.DIS_MsmtRul
(select 'DIS_SWD', t.MsmtTyp_ID from TWG.MsmtTyp t where MsmtTyp_Nm = 'Distribution Transfer Rate');

insert into TWG.MsmtRul
select * from session.DIS_MsmtRul s
where not exists
( select 1 from
  TWG.MsmtRul t
  where
  t.MsmtTyp_ID = s.MsmtTyp_ID
  and t.CompTyp_Cd = s.CompTyp_Cd);

delete from session.DIS_MsmtRul;

-- @@@@@@@@@@@@@@@ Extract_Control @@@@@@@@@@@@@@@
-- create a temporary table for extract control tables

declare global temporary table DIS_Extract_Control (
        ExtCtl_Source           varchar(120) not null,
        ExtCtl_Target           varchar(120) not null,
        ExtCtl_From_RawSeq      char(10) for bit data,
        ExtCtl_To_RawSeq        char(10) for bit data,
        ExtCtl_From_IntSeq      bigint,
        ExtCtl_To_IntSeq        bigint,
        ExtCtl_From_DtTm        timestamp not null,
        ExtCtl_To_DtTm          timestamp not null
        )
  with replace on commit preserve rows not logged;

-- Use extract control when moving data from the source DB to the CDW.

insert into session.DIS_Extract_Control (ExtCtl_Source, ExtCtl_Target,
           ExtCtl_From_RawSeq,ExtCtl_To_RawSeq, ExtCtl_From_IntSeq,
           ExtCtl_To_IntSeq,ExtCtl_From_DtTm, ExtCtl_To_DtTm)
        values ('SD_H_INST', 'inv.stage_sd_h_inst', x'', x'', -1, 2000000000,
              '1970-01-01-00.00.00.000000', '9999-01-01-00.00.00.000000');

insert into session.DIS_Extract_Control (ExtCtl_Source, ExtCtl_Target,
           ExtCtl_From_RawSeq,ExtCtl_To_RawSeq, ExtCtl_From_IntSeq,
           ExtCtl_To_IntSeq,ExtCtl_From_DtTm, ExtCtl_To_DtTm)
        values ('DIST_NODE_STATE', 'inv.stage_dist_node_state', x'', x'', -1, 2000000000,
              '1970-01-01-00.00.00.000000', '9999-01-01-00.00.00.000000');

-- Use extract control when moving data from staging to TWG.MSMT
-- You only need to do this if you have more than 1 sql statement populating
--   the msmt table....one might complete and the other fails.

insert into session.DIS_Extract_control values (
    'inv.stage_dis_swd' ,
    'TWG.MSMT' ,
    x'',
    x'',
    -1,
    2000000000,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);


-- Use extract control when moving data into the MART db.

insert into session.DIS_Extract_Control values (
    'TWG.MSMT' ,
    'inv.STAGE_F_SWD_DAY' ,
    x'',
    x'',
    -1,
    2000000000,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into session.DIS_Extract_Control values (
    'inv.stage_d_metric' ,
    'inv.D_SWD_METRIC' ,
    x'',
    x'',
    -1,
    2000000000,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into session.DIS_Extract_Control (ExtCtl_Source, ExtCtl_Target,
           ExtCtl_From_RawSeq,ExtCtl_To_RawSeq, ExtCtl_From_IntSeq,
           ExtCtl_To_IntSeq,ExtCtl_From_DtTm, ExtCtl_To_DtTm)
        values ('TWG.COMP', 'inv.stage_host_state', x'', x'', -1, 2000000000,
              '1970-01-01-00.00.00.000000', '9999-01-01-00.00.00.000000');

insert into session.DIS_Extract_Control (ExtCtl_Source, ExtCtl_Target,
           ExtCtl_From_RawSeq,ExtCtl_To_RawSeq, ExtCtl_From_IntSeq,
           ExtCtl_To_IntSeq,ExtCtl_From_DtTm, ExtCtl_To_DtTm)
        values ('TWG.COMP', 'inv.stage_d_swd_dist', x'', x'', -1, 2000000000,
              '1970-01-01-00.00.00.000000', '9999-01-01-00.00.00.000000');

-- insert the extract control values rules into the CDW
-- where not exists

insert into TWG.Extract_Control
        select s.ExtCtl_Source,
               s.ExtCtl_Target,
               s.ExtCtl_From_RawSeq,
               s.ExtCtl_To_RawSeq,
               s.ExtCtl_From_IntSeq,
               s.ExtCtl_To_IntSeq,
               s.ExtCtl_From_DtTm,
               s.ExtCtl_To_DtTm
        from session.DIS_Extract_Control s
        where not exists
                (select 1 from TWG.Extract_Control t
                        where t.ExtCtl_Source=s.ExtCtl_Source
                        and t.ExtCtl_Target=s.ExtCtl_Target);

delete from session.DIS_Extract_Control;

-- @@@@@@@@@@@@@@@ Prune_Msmt_Control @@@@@@@@@@@@@@@
-- create a temporary table for prune measurement control tables

declare global temporary table DIS_Prune_Msmt_Control (
        MSrc_Cd                char(6) not null,
        TmSum_Cd               char not null,
        PMsmtC_Age_In_Days     decimal(8,0) not null
        )
  with replace on commit preserve rows not logged;

insert into session.DIS_Prune_Msmt_Control (MSrc_Cd, TmSum_Cd, PMsmtC_Age_In_Days)
        values ('DIS', 'H', 000010000);

-- insert the prune measurement control values into the CDW
-- where not exists

insert into TWG.Prune_Msmt_Control
        select s.Msrc_Cd,
               s.TmSum_Cd,
               s.PMsmtC_Age_In_Days
        from session.DIS_Prune_Msmt_Control s
        where not exists
                (select 1 from TWG.Prune_Msmt_Control t
                        where t.MSrc_Cd=s.MSrc_Cd
                        and t.TmSum_Cd=s.TmSum_Cd);

delete from session.DIS_Prune_Msmt_Control;

------------------------------------------
-- insert static data into the DM metrics dimension staging tables
------------------------------------------

declare global temporary table temp_min_exists (
 msmttyp_id	integer,
 min_exists     char(1)
)
with replace on commit preserve rows not logged
;

insert into session.temp_min_exists
select
 mb.msmttyp_id,
 'Y' as min_exists
from
 TWG.MgrpMbr mb
where
 mb.mgrptyp_cd = 'GROUP' and
 mb.mgrp_cd='MIN_E'
;

select count(*) from session.temp_min_exists;

declare global temporary table temp_max_exists (
 msmttyp_id	integer,
 max_exists     char(1)
)
with replace on commit preserve rows not logged
;

insert into session.temp_max_exists
select
 mb.msmttyp_id,
 'Y' as max_exists
from
 TWG.MgrpMbr mb
where
 mb.mgrptyp_cd = 'GROUP' and
 mb.mgrp_cd='MAX_E'
;

select count(*) from session.temp_max_exists;

declare global temporary table temp_avg_exists (
 msmttyp_id	integer,
 avg_exists     char(1)
)
with replace on commit preserve rows not logged
;

insert into session.temp_avg_exists
select
 mb.msmttyp_id,
 'Y' as avg_exists
from
 TWG.MgrpMbr mb
where
 mb.mgrptyp_cd = 'GROUP' and
 mb.mgrp_cd='AVG_E'
;

select count(*) from session.temp_avg_exists;

declare global temporary table temp_tot_exists (
 msmttyp_id	integer,
 tot_exists     char(1)
)
with replace on commit preserve rows not logged
;

insert into session.temp_tot_exists
select
 mb.msmttyp_id,
 'Y' as tot_exists
from
 TWG.MgrpMbr mb
where
 mb.mgrptyp_cd = 'GROUP' and
 mb.mgrp_cd='TOT_E'
;

select count(*) from session.temp_tot_exists;


delete from inv.stage_d_metric;

insert into inv.stage_d_metric
select
 mt.MsmtTyp_ID as Metric_ID,
 current timestamp - current timezone as insert_dttm,
 substr(mt.MsmtTyp_Nm,1,30) as Met_Name,
 mt.MsmtTyp_Ds as Met_Desc,
 mt.MUnit_Cd as Met_Units ,
 mg1.MGrp_Nm as Met_Category,
 value(min.min_exists,'N') as min_exists,
 value(max.max_exists,'N') as max_exists,
 value(avg.avg_exists,'N') as avg_exists,
 value(tot.tot_exists,'N') as total_exists,
 'DIS' as msrc_nm
from
 TWG.msmttyp mt left outer join session.temp_min_exists min
 on mt.msmttyp_id=min.msmttyp_id,
 TWG.msmttyp mt2 left outer join session.temp_max_exists max
 on mt2.msmttyp_id=max.msmttyp_id,
 TWG.msmttyp mt3 left outer join session.temp_avg_exists avg
 on mt3.msmttyp_id=avg.msmttyp_id,
 TWG.msmttyp mt4 left outer join session.temp_tot_exists tot
 on mt4.msmttyp_id=tot.msmttyp_id,
 TWG.MsmtRul mr,
 TWG.Mgrp mg1,
 TWG.MgrpMbr mb1
where
 mt.MsmtTyp_ID = mr.MsmtTyp_ID and
 mr.CompTyp_Cd = 'DIS_SWD' and
 mt.MSrc_Cd = 'DIS' and
 mt.MsmtTyp_ID = mt2.MsmtTyp_ID and
 mt.MsmtTyp_ID = mt3.MsmtTyp_ID and
 mt.MsmtTyp_ID = mt4.MsmtTyp_ID and
 mt.MsmtTyp_ID = mb1.Msmttyp_ID and
 mb1.Mgrp_Cd = mg1.Mgrp_Cd and
 (mb1.Mgrptyp_Cd = 'DISMD' or mb1.Mgrptyp_Cd = 'DISSDW')
group by
 mt.MsmtTyp_id, mt.MsmtTyp_nm, mt.MsmtTyp_ds, mt.MUnit_cd, mg1.MGrp_Nm,
 min_exists, avg_exists, tot_exists, max_exists
;
