------------------------------------------------------------------------
--  @(#)64    1.6  src/tedw_apps/inv/install/v420/cdw/dml/twh_cdw_data.sql, inventory, inventory_4.2.2, 20041114  9/4/02  15:35:18
--
-- Licensed Materials - Property of IBM
--
-- 5698-INV
--
-- Tivoli Enterprise Data Warehouse, v 1.1.0
-- (C) Copyright IBM Corp. 2002.  All Rights Reserved.
--
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with
-- IBM Corp.
--
--
------------------------------------------------------------------------
--
-- File Information: src/tools/sql/twh_cdw_data.sql, twh_core, twh_1.2
--
-- Revision: 1.19
--
-- Date: 9/3/02 15:43:43
--
-- Description: This is a common file for inserting static data
-- into the CDW. All application installs should place this file in their
-- /tedw/ava_code/v110/cdw/dml directory.
--
------------------------------------------------------------------------

-- All data is initially inserted into a temporary table that has
-- the same columns as the target table in the CDW.
-- That table is then inserted into the CDW table with a "where not exists"
-- clause. This insures that duplicate data is not inserted and an
-- error is not generated for trying to insert duplicate data.

declare global temporary table comptyp (
       CompTyp_Cd           CHAR(17) NOT NULL,
       CompTyp_Parent_Cd    CHAR(17),
       CompTyp_Nm           VARCHAR(120) NOT NULL,
       CompTyp_Strt_DtTm    TIMESTAMP NOT NULL,
       CompTyp_End_DtTm     TIMESTAMP NOT NULL
)
with replace on commit preserve rows not logged
;

--Insert all time values in UTC
insert into session.comptyp values ('IP_HOST', NULL, 'IP Host', current timestamp - current timezone, '9999-01-01-12.00.00.000000');

insert into session.comptyp values ('IP_INTERFACE', NULL, 'IP Interface', current timestamp - current timezone, '9999-01-01-12.00.00.000000');

insert into session.comptyp values ('IPX_INTERFACE', NULL, 'IPX Interface', current timestamp - current timezone, '9999-01-01-12.00.00.000000');

insert into session.comptyp values ('TME_ENDPOINT', NULL, 'Tivoli Endpoint', current timestamp - current timezone, '9999-01-01-12.00.00.000000');

insert into session.comptyp values ('WEBSITE', NULL, 'Website', current timestamp - current timezone, '9999-01-01-12.00.00.000000');

insert into session.comptyp values ('WEBSITE_QUERY', NULL, 'Website Query', current timestamp - current timezone, '9999-01-01-12.00.00.000000');

insert into session.comptyp values ('WEBSITE_PATH', NULL, 'Website Path', current timestamp - current timezone, '9999-01-01-12.00.00.000000');

insert into twg.comptyp
select * from session.comptyp s
where not exists (
  select 1 from
  twg.comptyp t where
  t.comptyp_cd = s.comptyp_cd
);

--
-- Insert component relation type codes
--
declare global temporary table RelnTyp (
       RelnTyp_Cd           CHAR(6) NOT NULL,
       RelnTyp_Nm           VARCHAR(120) NOT NULL)
with replace on commit preserve rows not logged
;

insert into session.RelnTyp values (
  'PCHILD', 'Parent Child Relation'
);
insert into session.RelnTyp values (
  'MEMBER', 'Member Relation'
);
insert into session.RelnTyp values (
  'OWNS', 'Owns Relation'
);
insert into session.RelnTyp values (
  'CNTRLS', 'Controls Relation'
);
insert into session.RelnTyp values (
  'NETWRK', 'Network Relation'
);
insert into session.RelnTyp values (
  'RUNSON', 'Runs on Relation'
);
insert into session.RelnTyp values (
  'INVOKE', 'Invoke Relation'
);
insert into session.RelnTyp values (
  'DEPEND', 'Depend Relation'
);
insert into session.RelnTyp values (
  'PCONT', 'Physical Containment Relation'
);
insert into session.RelnTyp values (
  'MONITR', 'Monitoring relation'
);

insert into twg.RelnTyp
select * from session.RelnTyp s
where not exists (
  select 1 from
  twg.RelnTyp t where
  t.RelnTyp_Cd = s.RelnTyp_Cd
);


--
-- Insert time summary codes
--
declare global temporary table tmsum (
  TmSum_Cd             CHAR NOT NULL,
  TmSum_Nm             VARCHAR(120) NOT NULL
)
with replace on commit preserve rows not logged
;

insert into session.tmsum values ('H', 'Hourly');
insert into session.tmsum values ('D', 'Daily');
insert into session.tmsum values ('W', 'Weekly');
insert into session.tmsum values ('M', 'Monthly');
insert into session.TmSum values ('Q', 'Quarterly');
insert into session.TmSum values ('Y', 'Yearly');
insert into session.TmSum values ('P', 'Point');

insert into twg.tmsum
select * from session.tmsum s
where not exists (
  select 1 from
  twg.tmsum t where
  t.TmSum_Cd = s.TmSum_Cd
);


--
-- Insert measurement unit codes
--
declare global temporary table munitcat (
  MUnitCat_Cd          CHAR(6) NOT NULL,
  MUnitCat_Nm          VARCHAR(120) NOT NULL
)
with replace on commit preserve rows not logged
;

insert into session.munitcat values ('TM','Time Duration');
insert into session.munitcat values ('QTY','Quantity');
insert into session.munitcat values ('PRC','Percentage');
insert into session.munitcat values ('RT','Rate');

insert into twg.munitcat
select * from session.munitcat s
where not exists (
  select 1 from
  twg.munitcat t where
  t.munitcat_Cd = s.munitcat_Cd
);


--
-- Insert measurement units
--
declare global temporary table munit (
  MUnit_Cd             CHAR(6) NOT NULL,
  MUnitCat_Cd          CHAR(6),
  MUnit_Nm             VARCHAR(120) NOT NULL
)
with replace on commit preserve rows not logged
;

insert into session.MUnit values ('PRC', 'PRC', 'Percentage');
insert into session.MUnit values ('Bps', 'RT', 'Bytes per Second');
insert into session.MUnit values ('MBps', 'RT', 'Megabytes per Second');
insert into session.MUnit values ('KBps', 'RT', 'Kilobytes per Second');
insert into session.MUnit values ('Rps', 'RT', 'Requests per Second');
insert into session.MUnit values ('Qps', 'RT', 'Quantity per Second');
insert into session.MUnit values ('Qpm', 'RT', 'Quantity per Minute');
insert into session.MUnit values ('QTY', 'QTY', 'Quantity');
insert into session.MUnit values ('GB', 'QTY', 'Gigabytes');
insert into session.MUnit values ('KB', 'QTY', 'Kilobytes');
insert into session.MUnit values ('MB', 'QTY', 'Megabytes');
insert into session.MUnit values ('B', 'QTY', 'Bytes');
insert into session.MUnit values ('4KPgs', 'QTY', '4K Pages');
insert into session.MUnit values ('SU','QTY','Service Units');
insert into session.MUnit values ('MSec', 'TM', 'Milliseconds');
insert into session.MUnit values ('Sec', 'TM', 'Seconds');
insert into session.MUnit values ('Min', 'TM', 'Minutes');
insert into session.MUnit values ('Hr', 'TM', 'Hours');
insert into session.MUnit values ('Day', 'TM', 'Days');
insert into session.MUnit values ('HSc', 'TM', 'Hundredths of a Second');

insert into twg.munit
select * from session.munit s
where not exists (
  select 1 from
  twg.munit t where
  t.munit_Cd = s.munit_Cd
);


--
-- Insert measurement group type codes
--
declare global temporary table mgrptyp (
  MGrpTyp_Cd           CHAR(6) NOT NULL,
  MGrpTyp_Nm           VARCHAR(120) NOT NULL
)
with replace on commit preserve rows not logged
;

insert into session.MgrpTyp values ('STATE','State');
insert into session.MgrpTyp values ('CATEG','Category');
insert into session.mgrptyp values ('GROUP', 'Aggregate Types or Group Functions');
insert into session.MgrpTyp values ('TRANS','State Transition Groups');

insert into twg.mgrptyp
select * from session.mgrptyp s
where not exists (
  select 1 from
  twg.mgrptyp t where
  t.mgrptyp_Cd = s.mgrptyp_Cd
);


--
-- Insert measurement groups
--
declare global temporary table mgrp (
  MGrp_Cd              CHAR(6) NOT NULL,
  MGrpTyp_Cd           CHAR(6) NOT NULL,
  MGrp_Parent_Cd       CHAR(6),
  MGrp_Nm              VARCHAR(120) NOT NULL
)
with replace on commit preserve rows not logged
;

insert into session.MGrp values ('PERF','CATEG', NULL, 'Performance');
insert into session.MGrp values ('UTIL','CATEG', NULL, 'Utilization');
insert into session.MGrp values ('AVL','CATEG', NULL, 'Availability');
insert into session.MGrp values ('STATE','CATEG', NULL, 'Percentage State Measurements');
insert into session.MGrp values ('STORAG','CATEG', NULL, 'Storage');
insert into session.MGrp values ('AVG_E', 'GROUP', NULL, 'Average Value Exists');
insert into session.MGrp values ('MIN_E', 'GROUP', NULL, 'Minimum Value Exists');
insert into session.MGrp values ('MAX_E', 'GROUP', NULL, 'Maximum Value Exists');
insert into session.MGrp values ('TOT_E', 'GROUP', NULL, 'Total Value Exists');

insert into twg.mgrp
select * from session.mgrp s
where not exists (
  select 1 from
  twg.mgrp t where
  t.mgrp_Cd = s.mgrp_Cd
);


--
-- Insert measurement source codes
--
declare global temporary table msrc (
  MSrc_Cd              CHAR(6) NOT NULL,
  MSrc_Parent_Cd       CHAR(6),
  MSrc_Nm              VARCHAR(120) NOT NULL
)
with replace on commit preserve rows not logged
;

insert into session.msrc values ('Tivoli', NULL, 'Tivoli Application');
insert into session.msrc values ('MODEL1', NULL, 'Tivoli Common Data Model V1');

insert into twg.msrc
select * from session.msrc s
where not exists (
  select 1 from
  twg.msrc t where
  t.msrc_Cd = s.msrc_Cd
);


--
-- Insert measurement type codes
--
declare global temporary table MsmtTyp (
  MsmtTyp_ID           INTEGER NOT NULL,
  MUnit_Cd             CHAR(6) NOT NULL,
  MSrc_Cd              CHAR(6) NOT NULL,
  MsmtTyp_Nm           VARCHAR(120) NOT NULL,
  MsmtTyp_Ds           VARCHAR(254)
)
with replace on commit preserve rows not logged
;

insert into session.MsmtTyp values (0, 'Min','MODEL1','Available', 'The amount of time that the resource is available');
;
insert into session.MsmtTyp values (0, 'Min','MODEL1','Degrading', 'The amount of time that the resource is degrading');
;
insert into session.MsmtTyp values (0, 'Min','MODEL1','Unavailable', 'The amount of time that the resource is unavailable');
;
insert into session.MsmtTyp values (0, 'Min','MODEL1','Unreachable', 'The amount of time that the resource is unreachable');
;
insert into session.MsmtTyp values (0, 'Min','MODEL1','Responding', 'The amount of time that it took to detect, isolate, and respond to a problem with the resource');
;
insert into session.MsmtTyp values (0, 'Min','MODEL1','Repairing', 'The amount of time that it took to fix the problem associated with the resource');
;
insert into session.MsmtTyp values (0, 'Min','MODEL1','Closing', 'The amount of time that it took to close the problem with the resource');
;
insert into session.MsmtTyp values (0, 'Min','MODEL1','Unknown', 'The amount of time that the state of the resource is unknown');
;
insert into session.MsmtTyp values (0, 'Min','MODEL1','Unmanaged', 'The amount of time that the resource is unmanaged');
;
insert into session.MsmtTyp values (0, 'Min','MODEL1','Number of Transactions', 'The number of times that the resource has changed state');
;

insert into twg.MsmtTyp
select * from session.MsmtTyp s
where not exists (
  select 1 from
  twg.MsmtTyp t where
  t.MsmtTyp_Nm = s.MsmtTyp_Nm
);


--
-- Insert measurement rules
--
declare global temporary table MsmtRul (
  CompTyp_Cd           CHAR(17) NOT NULL,
  MsmtTyp_ID           INTEGER NOT NULL
)
with replace on commit preserve rows not logged
;

insert into session.MsmtRul
  select 'IP_HOST', MsmtTyp_ID from twg.MsmtTyp where MsmtTyp_Nm in (
    'Available',
    'Degrading',
    'Unavailable',
    'Unreachable',
    'Responding',
    'Repairing',
    'Closing',
    'Unknown',
    'Unmanaged'
  )
;

insert into session.MsmtRul
  select 'IP_INTERFACE', MsmtTyp_ID from twg.MsmtTyp where MsmtTyp_Nm in (
    'Available',
    'Degrading',
    'Unavailable',
    'Unreachable',
    'Responding',
    'Repairing',
    'Closing',
    'Unknown',
    'Unmanaged'
  )
;

insert into session.MsmtRul
  select 'IPX_INTERFACE', MsmtTyp_ID from twg.MsmtTyp where MsmtTyp_Nm in (
    'Available',
    'Degrading',
    'Unavailable',
    'Unreachable',
    'Responding',
    'Repairing',
    'Closing',
    'Unknown',
    'Unmanaged'
  )
;

insert into session.MsmtRul
  select 'TME_ENDPOINT', MsmtTyp_ID from twg.MsmtTyp where MsmtTyp_Nm in (
    'Available',
    'Degrading',
    'Unavailable',
    'Unreachable',
    'Responding',
    'Repairing',
    'Closing',
    'Unknown',
    'Unmanaged'
  )
;

insert into session.MsmtRul
  select 'WEBSITE', MsmtTyp_ID from twg.MsmtTyp where MsmtTyp_Nm in (
    'Available',
    'Degrading',
    'Unavailable',
    'Unreachable',
    'Responding',
    'Repairing',
    'Closing',
    'Unknown',
    'Unmanaged'
  )
;
insert into session.MsmtRul
  select 'WEBSITE_PATH', MsmtTyp_ID from twg.MsmtTyp where MsmtTyp_Nm in (
    'Available',
    'Degrading',
    'Unavailable',
    'Unreachable',
    'Responding',
    'Repairing',
    'Closing',
    'Unknown',
    'Unmanaged'
  )
;
insert into session.MsmtRul
  select 'WEBSITE_QUERY', MsmtTyp_ID from twg.MsmtTyp where MsmtTyp_Nm in (
    'Available',
    'Degrading',
    'Unavailable',
    'Unreachable',
    'Responding',
    'Repairing',
    'Closing',
    'Unknown',
    'Unmanaged'
  )
;

insert into twg.MsmtRul
select * from session.MsmtRul s
where not exists (
  select 1 from
  twg.MsmtRul t where
  t.CompTyp_Cd = s.CompTyp_Cd and
  t.MsmtTyp_ID = s.MsmtTyp_ID
);


--
-- Insert Attribute Types
--
declare global temporary table AttrTyp (
       AttrTyp_Cd           CHAR(17) NOT NULL,
       AttrTyp_Nm           VARCHAR(120) NOT NULL
)
with replace on commit preserve rows not logged
;

insert into session.AttrTyp values('LAST_IP_ADDRESS','Last IP Address');
insert into session.AttrTyp values('TME_OBJECT_ID','Tivoli Object ID');
insert into session.AttrTyp values('TME_LABEL','Tivoli Endpoint Label');
insert into session.AttrTyp values('OS_NAME', 'Operating System Name');
insert into session.AttrTyp values('OS_TYPE', 'Operating System Type');
insert into session.AttrTyp values('MAJOR_VERSION', 'Major Version Number');
insert into session.AttrTyp values('MINOR_VERSION', 'Minor Version Number');
insert into session.AttrTyp values('SUB_VERSION', 'Sub Version Number');
insert into session.AttrTyp values('VERSION', 'Version Number');
insert into session.AttrTyp values('CONTACT', 'Contact Name');
insert into session.AttrTyp values('MANUFACTURER', 'Manufacturer');
insert into session.AttrTyp values('MACHINE_TYPE', 'Machine Type');
insert into session.AttrTyp values('MODEL', 'Model Specification for this Hardware Device');
insert into session.AttrTyp values('SERIAL_NUMBER', 'Serial Number');
insert into session.AttrTyp values('IP_DOMAIN', 'IP Domain');
insert into session.AttrTyp values('IP_HOSTNAME', 'IP Hostname');
insert into session.AttrTyp values('IP_NET_ADDRESS', 'IP Network Address');
insert into session.AttrTyp values('OWNER', 'Owner');
insert into session.AttrTyp values('NAME', 'Name');
insert into session.AttrTyp values('TYPE', 'Type');
insert into session.AttrTyp values('DESCRIPTION', 'Description');
insert into session.AttrTyp values('USER_LABEL', 'Label for a Component');
--valid values for URL are: - acap,afs,cid,data,dav,fax,file,ftp,gopher
--    http,https,imap,ldap,mailserver,mailto,mid,modem,news,nfs,nntp
--    opaquelocktoken,pop,prospero,rtsp,service,sip,soap.beep,soap.beeps
--    tel,telnet,tip,tn3270,urn,vemmi,wais,z39.50r,z39.50s
insert into session.AttrTyp values('URL_PROTOCOL', 'Protocol Portion of a URL');

insert into TWG.AttrTyp
select * from
 session.AttrTyp s
where not exists
( select 1 from
  TWG.AttrTyp t
  where
  t.AttrTyp_Cd=s.AttrTyp_Cd )
;

--
-- Insert Attribute Rules
--
declare global temporary table AttrRul (
       CompTyp_Cd           CHAR(17) NOT NULL,
       AttrTyp_Cd           CHAR(17) NOT NULL,
       AttrRul_Strt_DtTm    TIMESTAMP NOT NULL,
       AttrRul_End_DtTm     TIMESTAMP NOT NULL,
       AttrRul_Dom_Ind      CHAR NOT NULL
)
with replace on commit preserve rows not logged
;

insert into session.AttrRul values('IP_HOST','LAST_IP_ADDRESS',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_HOST','TME_OBJECT_ID',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_HOST','TME_LABEL',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_HOST','OS_NAME',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_HOST','OS_TYPE',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_HOST','MAJOR_VERSION',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_HOST','MINOR_VERSION',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_HOST','SUB_VERSION',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_HOST','VERSION',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_HOST','CONTACT',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_HOST','MANUFACTURER',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_HOST','MACHINE_TYPE',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_HOST','MODEL',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_HOST','SERIAL_NUMBER',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_HOST','IP_DOMAIN',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_HOST','IP_HOSTNAME',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_HOST','IP_NET_ADDRESS',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_HOST','NAME',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_HOST','TYPE',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_HOST','DESCRIPTION',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_HOST','USER_LABEL',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_HOST','URL_PROTOCOL',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');

insert into session.AttrRul values('IP_INTERFACE','TME_OBJECT_ID',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_INTERFACE','TME_LABEL',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_INTERFACE','OS_NAME',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_INTERFACE','OS_TYPE',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_INTERFACE','MAJOR_VERSION',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_INTERFACE','MINOR_VERSION',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_INTERFACE','SUB_VERSION',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_INTERFACE','VERSION',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_INTERFACE','CONTACT',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_INTERFACE','MANUFACTURER',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_INTERFACE','MACHINE_TYPE',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_INTERFACE','MODEL',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_INTERFACE','SERIAL_NUMBER',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_INTERFACE','IP_DOMAIN',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_INTERFACE','IP_NET_ADDRESS',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_INTERFACE','NAME',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_INTERFACE','TYPE',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_INTERFACE','DESCRIPTION',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_INTERFACE','USER_LABEL',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_INTERFACE','URL_PROTOCOL',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');

insert into session.AttrRul values('IPX_INTERFACE','TME_OBJECT_ID',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IPX_INTERFACE','TME_LABEL',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IPX_INTERFACE','OS_NAME',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IPX_INTERFACE','OS_TYPE',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IPX_INTERFACE','MAJOR_VERSION',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IPX_INTERFACE','MINOR_VERSION',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IPX_INTERFACE','SUB_VERSION',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IPX_INTERFACE','VERSION',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IPX_INTERFACE','CONTACT',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IPX_INTERFACE','MANUFACTURER',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IPX_INTERFACE','MACHINE_TYPE',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IPX_INTERFACE','MODEL',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IPX_INTERFACE','SERIAL_NUMBER',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IPX_INTERFACE','IP_DOMAIN',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IPX_INTERFACE','IP_NET_ADDRESS',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IPX_INTERFACE','NAME',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IPX_INTERFACE','TYPE',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IPX_INTERFACE','DESCRIPTION',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IPX_INTERFACE','USER_LABEL',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IPX_INTERFACE','URL_PROTOCOL',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');

insert into session.AttrRul values('TME_ENDPOINT','TME_LABEL',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('TME_ENDPOINT','OS_NAME',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('TME_ENDPOINT','OS_TYPE',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('TME_ENDPOINT','MAJOR_VERSION',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('TME_ENDPOINT','MINOR_VERSION',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('TME_ENDPOINT','SUB_VERSION',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('TME_ENDPOINT','VERSION',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('TME_ENDPOINT','CONTACT',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('TME_ENDPOINT','MANUFACTURER',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('TME_ENDPOINT','MACHINE_TYPE',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('TME_ENDPOINT','MODEL',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('TME_ENDPOINT','SERIAL_NUMBER',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('TME_ENDPOINT','IP_DOMAIN',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('TME_ENDPOINT','IP_HOSTNAME',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('TME_ENDPOINT','IP_NET_ADDRESS',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('TME_ENDPOINT','NAME',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('TME_ENDPOINT','TYPE',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('TME_ENDPOINT','DESCRIPTION',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('TME_ENDPOINT','USER_LABEL',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('TME_ENDPOINT','URL_PROTOCOL',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');

insert into session.AttrRul values('WEBSITE','TME_LABEL',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('WEBSITE','OS_NAME',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('WEBSITE','OS_TYPE',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('WEBSITE','MAJOR_VERSION',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('WEBSITE','MINOR_VERSION',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('WEBSITE','SUB_VERSION',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('WEBSITE','VERSION',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('WEBSITE','CONTACT',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('WEBSITE','MANUFACTURER',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('WEBSITE','MACHINE_TYPE',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('WEBSITE','MODEL',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('WEBSITE','SERIAL_NUMBER',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('WEBSITE','IP_DOMAIN',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('WEBSITE','IP_HOSTNAME',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('WEBSITE','IP_NET_ADDRESS',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('WEBSITE','NAME',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('WEBSITE','TYPE',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('WEBSITE','DESCRIPTION',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('WEBSITE','USER_LABEL',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('WEBSITE','URL_PROTOCOL',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');

insert into session.AttrRul values('WEBSITE_PATH','TME_LABEL',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('WEBSITE_PATH','OS_NAME',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('WEBSITE_PATH','OS_TYPE',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('WEBSITE_PATH','MAJOR_VERSION',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('WEBSITE_PATH','MINOR_VERSION',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('WEBSITE_PATH','SUB_VERSION',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('WEBSITE_PATH','VERSION',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('WEBSITE_PATH','CONTACT',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('WEBSITE_PATH','MANUFACTURER',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('WEBSITE_PATH','MACHINE_TYPE',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('WEBSITE_PATH','MODEL',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('WEBSITE_PATH','SERIAL_NUMBER',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('WEBSITE_PATH','IP_DOMAIN',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('WEBSITE_PATH','IP_HOSTNAME',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('WEBSITE_PATH','IP_NET_ADDRESS',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('WEBSITE_PATH','NAME',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('WEBSITE_PATH','TYPE',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('WEBSITE_PATH','DESCRIPTION',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('WEBSITE_PATH','USER_LABEL',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('WEBSITE_PATH','URL_PROTOCOL',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');

insert into session.AttrRul values('WEBSITE_QUERY','TME_LABEL',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('WEBSITE_QUERY','OS_NAME',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('WEBSITE_QUERY','OS_TYPE',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('WEBSITE_QUERY','MAJOR_VERSION',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('WEBSITE_QUERY','MINOR_VERSION',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('WEBSITE_QUERY','SUB_VERSION',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('WEBSITE_QUERY','VERSION',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('WEBSITE_QUERY','CONTACT',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('WEBSITE_QUERY','MANUFACTURER',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('WEBSITE_QUERY','MACHINE_TYPE',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('WEBSITE_QUERY','MODEL',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('WEBSITE_QUERY','SERIAL_NUMBER',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('WEBSITE_QUERY','IP_DOMAIN',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('WEBSITE_QUERY','IP_HOSTNAME',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('WEBSITE_QUERY','IP_NET_ADDRESS',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('WEBSITE_QUERY','NAME',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('WEBSITE_QUERY','TYPE',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('WEBSITE_QUERY','DESCRIPTION',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('WEBSITE_QUERY','USER_LABEL',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('WEBSITE_QUERY','URL_PROTOCOL',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');

insert into TWG.AttrRul
select * from
 session.AttrRul s
where not exists
( select 1 from
  TWG.AttrRul t,
  TWG.CompTyp c
  where
  t.AttrTyp_Cd=s.AttrTyp_Cd and c.CompTyp_Cd=s.CompTyp_Cd)
;
