--  @(#)34    1.1  src/tedw_apps/inv/install/v420/etl/sql/DIS_c20_s020_extractSDData.db2, inventory, inventory_4.2.2, 20041114  8/23/02  11:10:51
--
-- Licensed Materials - Property of IBM
--
-- 5698-INV
--
-- (C) Copyright IBM Corp. 2002 All Rights Reserved
--
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with
-- IBM Corp

---------------------------------------------------
-- Purpose: Extracts SWD data from DB2 into staging
---------------------------------------------------

----------------------------------
-- ***** START: Initialize TWG.Extract_Control on first run *****
--#EXECUTE_AT_TARGET
update TWG.Extract_Control set ExtCtl_From_DtTm = Current Timestamp
                 - Current Timezone
                 - (select PMsmtC_Age_In_Days
                   from TWG.Prune_Msmt_Control
                   where MSrc_Cd = 'DIS'
                     and TmSum_Cd = 'H')
        where ExtCtl_Source = 'SD_H_INST'
          and ExtCtl_Target = 'inv.stage_sd_h_inst'
          and ExtCtl_From_DtTm = '1970-01-01-00.00.00.000000';

-- drop/create temp extract control table
--#IGNORE_ERROR
drop table temp_ext_ctl;

create table temp_ext_ctl (
        extctl_from_dttm        timestamp not null,
        extctl_to_dttm          timestamp not null
        );

-- insert a row in the temp extract control table
--#INSERT_INTO_SOURCE
insert into temp_ext_ctl
        select ExtCtl_From_DtTm,
               Current Timestamp
        from TWG.Extract_Control 
        where ExtCtl_Source = 'SD_H_INST'
          and ExtCtl_Target = 'inv.stage_sd_h_inst';                          ;

-- recall that time from TWG.Extract_Control and temp_ECO_Extract_Control is GMT
-- so, updating to current timezone
update temp_ext_ctl set extctl_from_dttm
        = extctl_from_dttm + current timezone;

-- create/clean the staging tables in TWH_CDW
----------------------------------
-- Extract DIS_SWD values
----------------------------------
--#EXECUTE_AT_TARGET
--#IGNORE_ERROR
drop table inv.stage_sd_h_inst;
--#EXECUTE_AT_TARGET
create table inv.stage_sd_h_inst like inv.stage_sd_h_inst_t;

-- perform the extract of SD_H_INST
-- convert timestamps to GMT, since select statement is executed in 
-- source side, the current timezone is source db timezone
--#INSERT_INTO_TARGET
insert into inv.stage_sd_h_inst
SELECT
   s.COMPUTER_SYS_ID as computer_sys_id,
   s.TME_SWARE_OID as tme_sware_oid,
   s.SWARE_ATIME as sware_atime,
   s.SD_ACTION as sd_action,
   s.STATE as state,
   s.MD2_DIST_ID as md2_dist_id,
   s.RECORD_TIME - current timezone as record_time
FROM
   SD_H_INST s,
   temp_ext_ctl ec
WHERE s.RECORD_TIME > ec.extctl_from_dttm
  AND s.RECORD_TIME <= ec.extctl_to_dttm
ORDER BY
   COMPUTER_SYS_ID
;

--extract SD_PACKAGE, this donot have extract control
--#EXECUTE_AT_TARGET
--#IGNORE_ERROR
drop table inv.stage_sd_package;
--#EXECUTE_AT_TARGET
create table inv.stage_sd_package like inv.stage_sd_package_t;
--#INSERT_INTO_TARGET
insert into inv.stage_sd_package
SELECT
   s.SWARE_NAME as sware_name,
   s.SWARE_VERS as sware_vers,
   s.TME_SWARE_OID as tme_sware_oid,
   s.SWARE_SRC_HOST as sware_src_host
FROM
   SD_PACKAGES s
ORDER BY
   SWARE_NAME,
   SWARE_VERS
;

-- updating extract control to_dttm time to be GMT
update temp_ext_ctl
        set extctl_to_dttm = extctl_to_dttm - current timezone;

-- delete the inv.temp_DIS_to_dttm table
--#EXECUTE_AT_TARGET
--#IGNORE_ERROR
drop table inv.temp_DIS_to_dttm;

-- create temp_DIS_to_dttm on CDW (table to hold temp_to value)
--#EXECUTE_AT_TARGET
create table inv.temp_DIS_to_dttm (
        extctl_to_dttm       timestamp not null);

-- update inv.temp_DIS_to_dttm in CDW
--#INSERT_INTO_TARGET
insert into inv.temp_DIS_to_dttm
        select extctl_to_dttm
        from temp_ext_ctl;

-- now drop the temp_ext_ctl table
drop table temp_ext_ctl;

-- update TWG.Extract_Control with new to_dttm
--#EXECUTE_AT_TARGET
update TWG.Extract_Control
        set ExtCtl_Source = ExtCtl_Source,
            ExtCtl_Target = ExtCtl_Target,
            ExtCtl_From_DtTm = ExtCtl_From_DtTm,
            ExtCtl_To_DtTm = (select extctl_to_dttm
                                  from inv.temp_DIS_to_dttm)
        where ExtCtl_Source = 'SD_H_INST'
        and ExtCtl_Target = 'inv.stage_sd_h_inst';

-- delete the inv.temp_DIS_to_dttm table
--#EXECUTE_AT_TARGET
drop table inv.temp_DIS_to_dttm;

-- write to TWG.Extract_Log
--#EXECUTE_AT_TARGET
insert into TWG.Extract_Log
        select ec.ExtCtl_Source,
               ec.ExtCtl_Target,
               Current Timestamp - Current Timezone,
               x'',
               x'',
               0,
               0,
               ec.ExtCtl_From_DtTm,
               ec.ExtCtl_To_DtTm
        from TWG.Extract_Control ec
        where ExtCtl_Source = 'SD_H_INST'
        and ExtCtl_Target = 'inv.stage_sd_h_inst';

