--  @(#)35    1.1  src/tedw_apps/inv/install/v420/etl/sql/DIS_c20_s030_extractMDData.db2, inventory, inventory_4.2.2, 20041114  8/23/02  11:10:56
--
-- Licensed Materials - Property of IBM
--
-- 5698-INV
--
-- (C) Copyright IBM Corp. 2002 All Rights Reserved
--
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with
-- IBM Corp

------------------------------------------------------
-- Purpose: Extracts MDIST2 data from DB2 into staging
------------------------------------------------------

----------------------------------
-- ***** START: Initialize TWG.Extract_Control on first run *****
--#EXECUTE_AT_TARGET
update TWG.Extract_Control set ExtCtl_From_DtTm = Current Timestamp
                 - Current Timezone
                 - (select PMsmtC_Age_In_Days
                   from TWG.Prune_Msmt_Control
                   where MSrc_Cd = 'DIS'
                     and TmSum_Cd = 'H')
        where ExtCtl_Source = 'DIST_NODE_STATE'
          and ExtCtl_Target = 'inv.stage_dist_node_state'
          and ExtCtl_From_DtTm = '1970-01-01-00.00.00.000000';

-- drop/create temp extract control table in source db
--#IGNORE_ERROR
drop table temp_ext_ctl;

create table temp_ext_ctl (
        extctl_from_dttm        timestamp not null,
        extctl_to_dttm          timestamp not null
        );

-- insert a row in the temp extract control table
-- select statement is executed in source side, 
-- so the current timezone is source db timezone
-- since MDIST use GMT, need convert current time to GMT.

--#INSERT_INTO_SOURCE
insert into temp_ext_ctl
        select ExtCtl_From_DtTm,
               Current Timestamp - current timezone
        from TWG.Extract_Control 
        where ExtCtl_Source = 'DIST_NODE_STATE'
          and ExtCtl_Target = 'inv.stage_dist_node_state';

-- recall that time from TWG.Extract_Control is GMT
-- and MDIST time is in GMT too, don't need convert.

----------------------------------
-- Extract DIS_MDIST values
----------------------------------
----------------------------------------------------------------------
-- Extract All the distribution with source is 'Software Distribution'
-- No matter FINISH_TIME is null or not
----------------------------------------------------------------------
--#EXECUTE_AT_TARGET
--#IGNORE_ERROR
drop table inv.stage_dist_state;
--#EXECUTE_AT_TARGET
create table inv.stage_dist_state like inv.stage_dist_state_t;
--#INSERT_INTO_TARGET
insert into inv.stage_dist_state
SELECT
   d.ID as md2_dist_id,
   value(d.DIST_SIZE,-1) as dist_size,
   d.START_TIME as start_time,
   d.FINISH_TIME as finish_time,
   value(d.SOURCE_APPLICATION,'') as source_application,
   d.LAST_MODIFY_TIME as last_modify_time
FROM
   DIST_STATE d,
   temp_ext_ctl ec
WHERE d.LAST_MODIFY_TIME > ec.extctl_from_dttm
  AND d.LAST_MODIFY_TIME <= ec.extctl_to_dttm
  AND d.SOURCE_APPLICATION = 'Software Distribution'
ORDER BY
   d.ID
;

-----------------------------------------------------------------------------
-- Extract All the distribution with a valid FINISH_TIME from DIST_NODE_STATE
-----------------------------------------------------------------------------
----------------------------------
-- NODE_TYPE: 
--              ENDPOINT = 0
--              REPEATER = 1
-- CURRENT_STATE: 
--              Waiting = 0
--              Paused = 1
--              Unavailable = 2
--              Receiving = 3
--              Interrupted = 4
--              Sending = 5
--              Successful = 6
--              Failed = 7
--              Canceled = 8
--              Rejected = 9
--              Expired = 10
--              Stored = 11
----------------------------------
--#EXECUTE_AT_TARGET
--#IGNORE_ERROR
drop table inv.stage_dist_node_state;
--#EXECUTE_AT_TARGET
create table inv.stage_dist_node_state like inv.stage_dist_node_state_t;
--#INSERT_INTO_TARGET
insert into inv.stage_dist_node_state
SELECT
   d.DISTRIBUTION_ID as md2_dist_id,
   d.NODE as tme_object_id,
   d.START_TIME as start_time,
   d.FINISH_TIME as finish_time,
   d.CURRENT_STATE as current_state,
   d.RECEIVING_TIME as receiving_time,
   d.LAST_MODIFY_TIME as last_modify_time
FROM
   DIST_NODE_STATE d,
   temp_ext_ctl ec
WHERE
   d.START_TIME is not null
   and d.FINISH_TIME is not null
   and d.NODE_TYPE = 0 
   and d.LAST_MODIFY_TIME > ec.extctl_from_dttm
   and d.LAST_MODIFY_TIME <= ec.extctl_to_dttm
ORDER BY
   d.DISTRIBUTION_ID
;

-- delete the inv.temp_DIS_to_dttm table
--#EXECUTE_AT_TARGET
--#IGNORE_ERROR
drop table inv.temp_DIS_to_dttm;

-- create temp_DIS_to_dttm on CDW (table to hold temp_to value)
--#EXECUTE_AT_TARGET
create table inv.temp_DIS_to_dttm (
        extctl_to_dttm       timestamp not null);

-- update inv.temp_DIS_to_dttm in CDW
--#INSERT_INTO_TARGET
insert into inv.temp_DIS_to_dttm
        select extctl_to_dttm
        from temp_ext_ctl;

-- now drop the temp_ext_ctl table
drop table temp_ext_ctl;

-- update TWG.Extract_Control with new to_dttm
--#EXECUTE_AT_TARGET
update TWG.Extract_Control
        set ExtCtl_Source = ExtCtl_Source,
            ExtCtl_Target = ExtCtl_Target,
            ExtCtl_From_DtTm = ExtCtl_From_DtTm,
            ExtCtl_To_DtTm = (select extctl_to_dttm
                                  from inv.temp_DIS_to_dttm)
        where ExtCtl_Source = 'DIST_NODE_STATE'
        and ExtCtl_Target = 'inv.stage_dist_node_state';

-- delete the inv.temp_DIS_to_dttm table
--#EXECUTE_AT_TARGET
drop table inv.temp_DIS_to_dttm;

-- write to TWG.Extract_Log
--#EXECUTE_AT_TARGET
insert into TWG.Extract_Log
        select ec.ExtCtl_Source,
               ec.ExtCtl_Target,
               Current Timestamp - Current Timezone,
               x'',
               x'',
               0,
               0,
               ec.ExtCtl_From_DtTm,
               ec.ExtCtl_To_DtTm
        from TWG.Extract_Control ec
        where ExtCtl_Source = 'DIST_NODE_STATE'
        and ExtCtl_Target = 'inv.stage_dist_node_state';

