--  @(#)36    1.12  src/tedw_apps/inv/install/v420/etl/sql/DIS_c20_s040_loadDisData.db2, inventory, inventory_4.2.2, 20041114  11/10/04  04:50:54
--
-- Licensed Materials - Property of IBM
--
-- 5698-DIS
--
-- (C) Copyright IBM Corp. 2002 All Rights Reserved
--
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with
-- IBM Corp

---------------------------------------------------
-- Purpose: Extracts DIS data from staging into CDW
---------------------------------------------------

----------------------------------
----------------------------------
-- Process IP_HOSTS values
----------------------------------
--#EXECUTE_AT_TARGET
--#IGNORE_ERROR
drop table inv.stage_ip_host_temp;
--#EXECUTE_AT_TARGET
create table inv.stage_ip_host_temp like inv.stage_ip_host_t;
--#EXECUTE_AT_TARGET
insert into inv.stage_ip_host_temp
select
  T1.COMPUTER_SYS_ID,
  case
   when T4.IP_HOSTNAME != '' AND T4.IP_DOMAIN != '' then lower(T4.IP_HOSTNAME)||'.'||lower(T4.IP_DOMAIN)
   when T4.IP_ADDR != '' then T4.IP_ADDR
   when T6.IPX_ADDR != '' then T6.IPX_ADDR
   else ''
  end as comp_nm,
  value(T1.TME_OBJECT_ID,'') as tme_object_id,
  value(T1.TME_OBJECT_LABEL,'') as tme_object_label,
  value(T1.COMPUTER_MODEL,'') as computer_model,
  value(T1.SYS_SER_NUM,'') as sys_ser_num,
  value(T1.OS_NAME,'') as os_name,
  value(T1.OS_TYPE,'') as os_type,
  value(T1.OS_MAJOR_VERS,-1) as os_major_vers,
  value(T1.OS_MINOR_VERS,-1) as os_minor_vers,
  value(T1.OS_SUB_VERS,'') as os_sub_vers,
  T1.RECORD_TIME as record_time,
  value(T2.USER_NAME,'') as user_name,
  value(T2.DOMAIN_NAME,'') as domain_name,
  value(T2.WORKGROUP_NAME,'') as workgroup_name,
  value(lower(T4.IP_HOSTNAME),'') as ip_hostname,
  value(lower(T4.IP_DOMAIN),'') as ip_domain,
  value(T4.IP_ADDR,'') as ip_addr,
  value(T6.IPX_ADDR,'') as ipx_addr,
  value(T8.PHYSICAL_TOTAL_KB,-1) as physical_total_kb,
  value(T10.NUM_PROCESSORS,-1) as num_processors,
  value(T10.MANUFACTURER,'') as manufacturer,
  value(T10.PROCESSOR_MODEL,'') as processor_model,
  value(T10.MAX_SPEED,-1) as max_speed,
  value(T10.CURRENT_SPEED,-1) as current_speed,
  value(T10.CHIP_FAMILY,-1) as chip_family,
  value(T10.CHIP_MODEL,-1) as chip_model,
  'Unknown' as system_purpose
FROM
  inv.stage_COMPUTER T1  LEFT OUTER JOIN inv.stage_PCSYS T2
      ON     T1.COMPUTER_SYS_ID = T2.COMPUTER_SYS_ID,
  inv.stage_COMPUTER T3  LEFT OUTER JOIN  inv.stage_IPNETWORK  T4
      ON     T3.COMPUTER_SYS_ID = T4.COMPUTER_SYS_ID,
  inv.stage_COMPUTER T5  LEFT OUTER JOIN inv.stage_IPXNETWORK T6
      ON     T5.COMPUTER_SYS_ID = T6.COMPUTER_SYS_ID,
  inv.stage_COMPUTER T7  LEFT OUTER JOIN  inv.stage_MEMORY T8
      ON     T7.COMPUTER_SYS_ID = T8.COMPUTER_SYS_ID,
  inv.stage_COMPUTER T9  LEFT OUTER JOIN  inv.stage_PROCESSOR T10
      ON     T9.COMPUTER_SYS_ID = T10.COMPUTER_SYS_ID

WHERE
  T1.COMPUTER_SYS_ID = T3.COMPUTER_SYS_ID  AND
  T1.COMPUTER_SYS_ID = T5.COMPUTER_SYS_ID  AND
  T1.COMPUTER_SYS_ID = T7.COMPUTER_SYS_ID  AND
  T1.COMPUTER_SYS_ID = T9.COMPUTER_SYS_ID and
 (locate('_', T4.ip_addr) = 0 or locate('A', T4.ip_addr) > 0)
;


--#EXECUTE_AT_TARGET
--sample check for invalid data
-- check if valid cust
-- check if valid centr
-- check for duplicate comp_nm
-- check for comp_nm = ''
--invalid data is not written to CDW
insert into inv.invalid_ip_host
select * from inv.stage_ip_host_temp n
where
  not exists(
    select 1 from inv.cust_lookup
    where inv.cust_lookup.value = n.comp_nm OR
          inv.cust_lookup.value = '@') OR
  not exists(
    select 1 from inv.centr_lookup
    where inv.centr_lookup.value = n.comp_nm OR
          inv.centr_lookup.value = '@') OR
  exists(
    select 1 from inv.stage_ip_host_temp t
    where t.comp_nm = n.comp_nm
    group by comp_nm having count(comp_nm)>1) OR
  comp_nm = ''
;

--Remove duplicate comp_nm records
--#EXECUTE_AT_TARGET
--#IGNORE_ERROR
drop table inv.stage_ip_host;
--#EXECUTE_AT_TARGET
create table inv.stage_ip_host like inv.stage_ip_host_t;
--#EXECUTE_AT_TARGET
insert into inv.stage_ip_host
select * from inv.stage_ip_host_temp t
where EXISTS(
 select 1
 from inv.stage_ip_host_temp n
 where t.comp_nm = n.comp_nm 
 group by comp_nm having count(comp_nm)!>1)
;

--------------------------------------------------------
-- Process DIS_SWD values
-- Mdist2 use endpoint oid as node id, 
-- but inventory use oid plus resource type as object id
--------------------------------------------------------
--#EXECUTE_AT_TARGET
--#IGNORE_ERROR
drop table inv.stage_dis_swd;
--#EXECUTE_AT_TARGET
create table inv.stage_dis_swd like inv.stage_dis_swd_t;
--#EXECUTE_AT_TARGET
insert into inv.stage_dis_swd
SELECT
   I1.comp_nm,
   CONCAT('sd',T1.md2_dist_id) as child_comp_nm,
   value(T1.sware_atime,'') as dis_sd_atime,
   value(T1.sd_action,'') as dis_sd_operation,
   value(T1.state, '') as dis_sd_state,
   value(M1.current_state,-1) as dis_md_state,
   value(T1.tme_sware_oid,'') as dis_fp_tme_oid,
   M1.start_time as md2_start_time,
   M1.finish_time as md2_finish_time,
   value(M1.receiving_time, -1) as md2_receiving_time,
   value(D1.dist_size, -1) as md2_dist_size,
   HOUR(M1.finish_time - M1.start_time)*60*60 
   + MINUTE(M1.finish_time - M1.start_time)*60
   + SECOND(M1.finish_time - M1.start_time) as md2_elapsed_time,
   M1.last_modify_time as last_modify_time
FROM
   inv.stage_ip_host I1,
   inv.stage_sd_h_inst T1,
   inv.stage_dist_state D1,
   inv.stage_dist_node_state M1
WHERE
   I1.computer_sys_id = T1.computer_sys_id
   and 
   T1.md2_dist_id = M1.md2_dist_id
   and 
   T1.md2_dist_id = D1.md2_dist_id
   and
   M1.tme_object_id = SUBSTR(I1.tme_object_id, 1, locate('#', I1.tme_object_id) -1 )
;


--------------------------------------------------------
-- Process DIS_FILEPACK values
--------------------------------------------------------
--#EXECUTE_AT_TARGET
--#IGNORE_ERROR
drop table inv.stage_dis_filepack;
--#EXECUTE_AT_TARGET
create table inv.stage_dis_filepack like inv.stage_dis_filepack_t;
--#EXECUTE_AT_TARGET
insert into inv.stage_dis_filepack
SELECT
   (p.sware_name CONCAT ' ' CONCAT p.sware_vers) as comp_nm,
   p.sware_name as dis_fp_name,
   p.sware_vers as version,
   value(p.tme_sware_oid, '') as dis_fp_tme_oid,
   value(p.sware_src_host,'') as dis_fp_src_host
FROM
   inv.stage_sd_package p
;

----------------------------------
----------------------------------
-- Load values
----------------------------------

------------------------------------
-- Load IP_HOST values into CDW
------------------------------------

-- Create a staging table so that we can keep track of deleted components
--
--#EXECUTE_AT_TARGET
--#IGNORE_ERROR
drop table inv.stage_delete_comp;
--#EXECUTE_AT_TARGET
create table inv.stage_delete_comp like twg.comp;


-- In order to improve performance we create a temporary stage_comp table
-- specific to the INV application, i.e. a table like the TWG.Comp one,
-- but filled in only with data related to the INV application; moreover
-- when inserting into this table, we use the TWG.cur_comp view, which
-- provides only the currently available components avoiding to explicitly
-- indicate the clause: current timestamp - current timezone between
-- TWG.Comp.Comp_Strt_DtTm and TWG.Comp.Comp_End_DtTm.
--
--#EXECUTE_AT_TARGET
--#IGNORE_ERROR
drop table inv.stage_comp;
--#EXECUTE_AT_TARGET
create table inv.stage_comp like twg.comp;
--#EXECUTE_AT_TARGET
insert into inv.stage_comp (Comp_ID, CompTyp_Cd, Centr_Cd, Cust_ID,
  Comp_Corr_ID, Comp_Nm, Comp_Corr_Val, Comp_Strt_DtTm, Comp_End_DtTm, Comp_Ds)
select
  c.Comp_ID, c.CompTyp_Cd, c.Centr_Cd, c.Cust_ID, c.Comp_Corr_ID, c.Comp_Nm,
  c.Comp_Corr_Val, c.Comp_Strt_DtTm, c.Comp_End_DtTm, c.Comp_Ds
from twg.cur_comp c
where
(c.comptyp_cd='IP_HOST' OR c.comptyp_cd='IP_INTERFACE' OR c.comptyp_cd='IPX_INTERFACE')
;

--#EXECUTE_AT_TARGET
INSERT INTO TWG.COMP
select
 0 as Comp_Id,
 case
  when n.IP_HOSTNAME != '' AND n.IP_DOMAIN != '' then 'IP_HOST'
  when n.IP_ADDR != '' then 'IP_INTERFACE'
  when n.IPX_ADDR != '' then 'IPX_INTERFACE'
 end as CompTyp_Cd,
 centr.Centr_Cd as Centr_Cd,
 cu.Cust_ID as Cust_ID,
 0 as Comp_Corr_Id,
 n.Comp_Nm as Comp_Nm,
 '' as Comp_Corr_Val,
 current timestamp - current timezone as Comp_Strt_DtTm ,
 '9999-01-01-00.00.00.000000' as Comp_End_DtTm,
 '' as Comp_Ds
from
 inv.stage_ip_host n,
 inv.centr_lookup centr,
 inv.cust_lookup cust,
 twg.cust cu
where
 n.comp_nm != ''
 AND ((cust.value = n.comp_nm AND cust.Cust_Acct_Cd = cu.Cust_Acct_Cd)
      OR cust.value = '@')
 AND (centr.value = n.comp_nm OR centr.value = '@')
 AND not exists (
  select 1
  from
   inv.stage_comp c
  where
   c.comp_nm=n.comp_nm)
;

-- Check for deleted components
--
insert into inv.stage_delete_comp
select * from inv.stage_comp c
where
 not exists (
  select 1
  from
  inv.stage_ip_host n
 where
  c.comp_nm = n.comp_nm
 )
;

-- Delete child component DIS_SWD too.
--
insert into inv.stage_delete_comp
select * from twg.comp comp
where comp.Comp_Corr_Val in (select Comp_Nm from inv.stage_delete_comp c) 
and comp.CompTyp_Cd='DIS_SWD'
;


--#EXECUTE_AT_TARGET
insert into twg.compattr
select
 0 as compattr_id,
 c.comp_id,
 'TME_OBJECT_ID' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 n.tme_object_id as CompAttr_Val
from
 inv.stage_ip_host n,
 twg.cur_comp c
where
 c.comp_nm=n.comp_nm
 and n.tme_object_id != ''
 and not exists (
  select 1
  from
   twg.cur_compattr ca,
   twg.cur_comp c2
  where
   n.comp_nm=c2.comp_nm
   and ca.comp_id=c2.comp_id
   and ca.CompAttr_Val=n.tme_object_id
   and ca.AttrTyp_Cd='TME_OBJECT_ID')
union
select
 0 as compattr_id,
 c.comp_id,
 'TME_LABEL' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 n.tme_object_label as CompAttr_Val
from
 inv.stage_ip_host n,
 twg.cur_comp c
where
 c.comp_nm=n.comp_nm
 and n.tme_object_label != ''
 and not exists (
  select 1
  from
   twg.cur_compattr ca,
   twg.cur_comp c2
  where
   n.comp_nm=c2.comp_nm
   and ca.comp_id=c2.comp_id
   and ca.CompAttr_Val=n.tme_object_label
   and ca.AttrTyp_Cd='TME_LABEL')
union
select
 0 as compattr_id,
 c.comp_id,
 'MODEL' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 n.computer_model as CompAttr_Val
from
 inv.stage_ip_host n,
 twg.cur_comp c
where
 c.comp_nm=n.comp_nm
 and n.computer_model != ''
 and not exists (
  select 1
  from
   twg.cur_compattr ca,
   twg.cur_comp c2
  where
   n.comp_nm=c2.comp_nm
   and ca.comp_id=c2.comp_id
   and ca.CompAttr_Val=n.computer_model
   and ca.AttrTyp_Cd='MODEL')
union
select
 0 as compattr_id,
 c.comp_id,
 'SERIAL_NUMBER' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 n.sys_ser_num as CompAttr_Val
from
 inv.stage_ip_host n,
 twg.cur_comp c
where
 c.comp_nm=n.comp_nm
 and n.sys_ser_num != ''
 and not exists (
  select 1
  from
   twg.cur_compattr ca,
   twg.cur_comp c2
  where
   n.comp_nm=c2.comp_nm
   and ca.comp_id=c2.comp_id
   and ca.CompAttr_Val=n.sys_ser_num
   and ca.AttrTyp_Cd='SERIAL_NUMBER')
union
select
 0 as compattr_id,
 c.comp_id,
 'OS_NAME' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 n.os_name as CompAttr_Val
from
 inv.stage_ip_host n,
 twg.cur_comp c
where
 c.comp_nm=n.comp_nm
 and n.os_name != ''
 and not exists (
  select 1
  from
   twg.cur_compattr ca,
   twg.cur_comp c2
  where
   n.comp_nm=c2.comp_nm
   and ca.comp_id=c2.comp_id
   and ca.CompAttr_Val=n.os_name
   and ca.AttrTyp_Cd='OS_NAME')
union
select
 0 as compattr_id,
 c.comp_id,
 'OS_TYPE' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 n.os_type as CompAttr_Val
from
 inv.stage_ip_host n,
 twg.cur_comp c
where
 c.comp_nm=n.comp_nm
 and n.os_type != ''
 and not exists (
  select 1
  from
   twg.cur_compattr ca,
   twg.cur_comp c2
  where
   n.comp_nm=c2.comp_nm
   and ca.comp_id=c2.comp_id
   and ca.CompAttr_Val=n.os_type
   and ca.AttrTyp_Cd='OS_TYPE')
union
select
 0 as compattr_id,
 c.comp_id,
 'MAJOR_VERSION' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 char(n.os_major_vers) as CompAttr_Val
from
 inv.stage_ip_host n,
 twg.cur_comp c
where
 c.comp_nm=n.comp_nm
 and n.os_major_vers != -1
 and not exists (
  select 1
  from
   twg.cur_compattr ca,
   twg.cur_comp c2
  where
   n.comp_nm=c2.comp_nm
   and ca.comp_id=c2.comp_id
   and ca.CompAttr_Val=char(n.os_major_vers)
   and ca.AttrTyp_Cd='MAJOR_VERSION')
union
select
 0 as compattr_id,
 c.comp_id,
 'MINOR_VERSION' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 char(n.os_minor_vers) as CompAttr_Val
from
 inv.stage_ip_host n,
 twg.cur_comp c
where
 c.comp_nm=n.comp_nm
 and n.os_minor_vers != -1
 and not exists (
  select 1
  from
   twg.cur_compattr ca,
   twg.cur_comp c2
  where
   n.comp_nm=c2.comp_nm
   and ca.comp_id=c2.comp_id
   and ca.CompAttr_Val=char(n.os_minor_vers)
   and ca.AttrTyp_Cd='MINOR_VERSION')
union
select
 0 as compattr_id,
 c.comp_id,
 'SUB_VERSION' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 n.os_sub_vers as CompAttr_Val
from
 inv.stage_ip_host n,
 twg.cur_comp c
where
 c.comp_nm=n.comp_nm
 and n.os_sub_vers != ''
 and not exists (
  select 1
  from
   twg.cur_compattr ca,
   twg.cur_comp c2
  where
   n.comp_nm=c2.comp_nm
   and ca.comp_id=c2.comp_id
   and ca.CompAttr_Val=n.os_sub_vers
   and ca.AttrTyp_Cd='SUB_VERSION')
union
select
 0 as compattr_id,
 c.comp_id,
 'INV_RECORD_TIME' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 char(n.record_time) as CompAttr_Val
from
 inv.stage_ip_host n,
 twg.cur_comp c
where
 c.comp_nm=n.comp_nm
 and not exists (
  select 1
  from
   twg.cur_compattr ca,
   twg.cur_comp c2
  where
   n.comp_nm=c2.comp_nm
   and ca.comp_id=c2.comp_id
   and ca.CompAttr_Val=char(n.record_time)
   and ca.AttrTyp_Cd='INV_RECORD_TIME')
;

--#EXECUTE_AT_TARGET
insert into twg.compattr
select
 0 as compattr_id,
 c.comp_id,
 'INV_USER_NAME' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 n.user_name as CompAttr_Val
from
 inv.stage_ip_host n,
 twg.cur_comp c
where
 c.comp_nm=n.comp_nm
 and n.user_name != ''
 and not exists (
  select 1
  from
   twg.cur_compattr ca,
   twg.cur_comp c2
  where
   n.comp_nm=c2.comp_nm
   and ca.comp_id=c2.comp_id
   and ca.CompAttr_Val=n.user_name
   and ca.AttrTyp_Cd='INV_USER_NAME')
union
select
 0 as compattr_id,
 c.comp_id as comp_id,
 'INV_DOMAIN_NAME' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 n.domain_name as CompAttr_Val
from
 inv.stage_ip_host n,
 twg.cur_comp c
where
 c.comp_nm=n.comp_nm
 and n.domain_name != ''
 and not exists (
  select 1
  from
   twg.cur_compattr ca,
   twg.cur_comp c2
  where
   n.comp_nm=c2.comp_nm
   and ca.comp_id=c2.comp_id
   and ca.CompAttr_Val=n.domain_name
   and ca.AttrTyp_Cd='INV_DOMAIN_NAME')
union
select
 0 as compattr_id,
 c.comp_id as comp_id,
 'INV_WORKGROUP_NM' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 n.workgroup_name as CompAttr_Val
from
 inv.stage_ip_host n,
 twg.cur_comp c
where
 c.comp_nm=n.comp_nm
 and n.workgroup_name != ''
 and not exists (
  select 1
  from
   twg.cur_compattr ca,
   twg.cur_comp c2
  where
   n.comp_nm=c2.comp_nm
   and ca.comp_id=c2.comp_id
   and ca.CompAttr_Val=n.workgroup_name
   and ca.AttrTyp_Cd='INV_WORKGROUP_NM')
;

--#EXECUTE_AT_TARGET
insert into twg.compattr
select
 0 as compattr_id,
 c.comp_id,
 'IP_HOSTNAME' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 n.ip_hostname as CompAttr_Val
from
 inv.stage_ip_host n,
 twg.cur_comp c
where
 c.comp_nm=n.comp_nm
 and n.ip_hostname != ''
 and not exists (
  select 1
  from
   twg.cur_compattr ca,
   twg.cur_comp c2
  where
   n.comp_nm=c2.comp_nm
   and ca.comp_id=c2.comp_id
   and ca.CompAttr_Val=n.ip_hostname
   and ca.AttrTyp_Cd='IP_HOSTNAME')
union
select
 0 as compattr_id,
 c.comp_id as comp_id,
 'IP_DOMAIN' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 n.ip_domain as CompAttr_Val
from
 inv.stage_ip_host n,
 twg.cur_comp c
where
 c.comp_nm=n.comp_nm
 and n.ip_domain != ''
 and not exists (
  select 1
  from
   twg.cur_compattr ca,
   twg.cur_comp c2
  where
   n.comp_nm=c2.comp_nm
   and ca.comp_id=c2.comp_id
   and ca.CompAttr_Val=n.ip_domain
   and ca.AttrTyp_Cd='IP_DOMAIN')
union
select
 0 as compattr_id,
 c.comp_id as comp_id,
 'LAST_IP_ADDRESS' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 n.ip_addr as CompAttr_Val
from
 inv.stage_ip_host n,
 twg.cur_comp c
where
 c.comp_nm=n.comp_nm
 and n.ip_addr != ''
 and not exists (
  select 1
  from
   twg.cur_compattr ca,
   twg.cur_comp c2
  where
   n.comp_nm=c2.comp_nm
   and ca.comp_id=c2.comp_id
   and ca.CompAttr_Val=n.ip_addr
   and ca.AttrTyp_Cd='LAST_IP_ADDRESS')
;

--#EXECUTE_AT_TARGET
insert into twg.compattr
select
 0 as compattr_id,
 c.comp_id as comp_id,
 'INV_IPX_ADDR' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 n.ipx_addr as CompAttr_Val
from
 inv.stage_ip_host n,
 twg.cur_comp c
where
 c.comp_nm=n.comp_nm
 and n.ipx_addr != ''
 and not exists (
  select 1
  from
   twg.cur_compattr ca,
   twg.cur_comp c2
  where
   n.comp_nm=c2.comp_nm
   and ca.comp_id=c2.comp_id
   and ca.CompAttr_Val=n.ipx_addr
   and ca.AttrTyp_Cd='INV_IPX_ADDR')
;

--#EXECUTE_AT_TARGET
insert into twg.compattr
select
 0 as compattr_id,
 c.comp_id,
 'INV_PHYSICAL_MEM' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 char(n.physical_total_kb) as CompAttr_Val
from
 inv.stage_ip_host n,
 twg.cur_comp c
where
 c.comp_nm=n.comp_nm
 and n.physical_total_kb != -1
 and not exists (
  select 1
  from
   twg.cur_compattr ca,
   twg.cur_comp c2
  where
   n.comp_nm=c2.comp_nm
   and ca.comp_id=c2.comp_id
   and ca.CompAttr_Val=char(n.physical_total_kb)
   and ca.AttrTyp_Cd='INV_PHYSICAL_MEM')
;

--#EXECUTE_AT_TARGET
insert into twg.compattr
select
 0 as compattr_id,
 c.comp_id,
 'INV_NUM_CPU' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 char(n.num_processors) as CompAttr_Val
from
 inv.stage_ip_host n,
 twg.cur_comp c
where
 c.comp_nm=n.comp_nm
 and n.num_processors != -1
 and not exists (
  select 1
  from
   twg.cur_compattr ca,
   twg.cur_comp c2
  where
   c2.comp_nm=n.comp_nm
   and ca.comp_id=c2.comp_id
   and ca.CompAttr_Val=char(n.num_processors)
   and ca.AttrTyp_Cd='INV_NUM_CPU')
union
select
 0 as compattr_id,
 c.comp_id,
 'INV_CPU_NAME' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 n.processor_model as CompAttr_Val
from
 inv.stage_ip_host n,
 twg.cur_comp c
where
 c.comp_nm=n.comp_nm
 and n.processor_model != ''
 and not exists (
  select 1
  from
   twg.cur_compattr ca,
   twg.cur_comp c2
  where
   n.comp_nm=c2.comp_nm
   and ca.comp_id=c2.comp_id
   and ca.CompAttr_Val=n.processor_model
   and ca.AttrTyp_Cd='INV_CPU_NAME')
union
select
 0 as compattr_id,
 c.comp_id,
 'INV_CPU_MAX_SPEED' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 char(n.max_speed) as CompAttr_Val
from
 inv.stage_ip_host n,
 twg.cur_comp c
where
 c.comp_nm=n.comp_nm
 and n.max_speed != -1
 and not exists (
  select 1
  from
   twg.cur_compattr ca,
   twg.cur_comp c2
  where
   n.comp_nm=c2.comp_nm
   and ca.comp_id=c2.comp_id
   and ca.CompAttr_Val=char(n.max_speed)
   and ca.AttrTyp_Cd='INV_CPU_MAX_SPEED')
union
select
 0 as compattr_id,
 c.comp_id,
 'INV_CPU_CUR_SPEED' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 char(n.current_speed) as CompAttr_Val
from
 inv.stage_ip_host n,
 twg.cur_comp c
where
 c.comp_nm=n.comp_nm
 and n.current_speed != -1
 and not exists (
  select 1
  from
   twg.cur_compattr ca,
   twg.cur_comp c2
  where
   n.comp_nm=c2.comp_nm
   and ca.comp_id=c2.comp_id
   and ca.CompAttr_Val=char(n.current_speed)
   and ca.AttrTyp_Cd='INV_CPU_CUR_SPEED')
union
select
 0 as compattr_id,
 c.comp_id,
 'INV_CPU_FAMILY' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 char(n.chip_family) as CompAttr_Val
from
 inv.stage_ip_host n,
 twg.cur_comp c
where
 c.comp_nm=n.comp_nm
 and n.chip_family != -1
 and not exists (
  select 1
  from
   twg.cur_compattr ca,
   twg.cur_comp c2
  where
   n.comp_nm=c2.comp_nm
   and ca.comp_id=c2.comp_id
   and ca.CompAttr_Val=char(n.chip_family)
   and ca.AttrTyp_Cd='INV_CPU_FAMILY')
union
select
 0 as compattr_id,
 c.comp_id,
 'INV_CPU_MODEL' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 char(n.chip_model) as CompAttr_Val
from
 inv.stage_ip_host n,
 twg.cur_comp c
where
 c.comp_nm=n.comp_nm
 and n.chip_model != -1
 and not exists (
  select 1
  from
   twg.cur_compattr ca,
   twg.cur_comp c2
  where
   n.comp_nm=c2.comp_nm
   and ca.comp_id=c2.comp_id
   and ca.CompAttr_Val=char(n.chip_model)
   and ca.AttrTyp_Cd='INV_CPU_MODEL')
;


------------------------------------
-- Load DIS_SWD values into CDW
------------------------------------
--

-- Use the incremental extract for DIS_SWD,
-- The component we extract won't be in TWG.COMP table.
-- Also, DIS_SWD's COMP_NM will have either ip host name or 
-- ip address.
-- But since we need to support recoverability in case of failure.
-- we need to check component existing. 

--#EXECUTE_AT_TARGET
--#IGNORE_ERROR
drop table inv.stage_comp;
--#EXECUTE_AT_TARGET
create table inv.stage_comp like twg.comp;
--#EXECUTE_AT_TARGET
insert into inv.stage_comp (Comp_ID, CompTyp_Cd, Centr_Cd, Cust_ID,
  Comp_Corr_ID, Comp_Nm, Comp_Corr_Val, Comp_Strt_DtTm, Comp_End_DtTm, Comp_Ds)
select comp_id, comptyp_cd, centr_cd, cust_id, comp_corr_id, comp_nm, comp_corr_val, comp_strt_dttm, comp_end_dttm, comp_ds from twg.cur_comp
where
comptyp_cd='DIS_SWD'
;

--#EXECUTE_AT_TARGET
INSERT INTO TWG.COMP
select
 0 as Comp_Id,
 'DIS_SWD' as CompTyp_Cd,
 centr_l.Centr_Cd as Centr_Cd,
 cust.Cust_ID as Cust_ID,
 comp.Comp_Id as Comp_Corr_Id,
 n.child_comp_nm as Comp_Nm,
 n.comp_nm as Comp_Corr_Val,
 current timestamp - current timezone as Comp_Strt_DtTm ,
 '9999-01-01-00.00.00.000000' as Comp_End_DtTm,
 '' as Comp_Ds
from
 inv.stage_dis_swd n,
 inv.centr_lookup centr_l,
 inv.cust_lookup cust_l,
 twg.cust cust,
 twg.cur_comp comp
where
 n.comp_nm = comp.Comp_Nm
 and ((cust_l.value = n.comp_nm AND cust_l.Cust_Acct_Cd = cust.Cust_Acct_Cd)
      OR cust_l.value = '@')
 and (centr_l.value = n.comp_nm OR centr_l.value = '@')
 and not exists (
  select 1
  from
   inv.stage_comp c
  where
   c.Comp_Nm = n.child_comp_nm
   and c.Comp_Corr_Val = n.comp_nm )
;

-- Check for deleted components
-- This will be done as part of IP_HOST, because the DIS_SWD will using 
-- incremental extract. instead, For each each deleted IP_HOST,
-- DIS_SWD will got deleted too.


--#EXECUTE_AT_TARGET
insert into TWG.CompReln
        select 0 as CompReln_Id,
               c.Comp_Corr_Id as Comp_Source_Id,
               c.Comp_Id as Comp_Target_Id,
               'PCHILD' as RelnTyp_Cd,
               current timestamp - current timezone as CompReln_Strt_DtTm,
               '9999-01-01-00.00.00.000000' as CompReln_End_DtTm
        from TWG.Cur_Comp c
        where CompTyp_Cd = 'DIS_SWD'
          and not exists
                (select 1 from TWG.Cur_CompReln r
                        where r.Comp_Source_Id = c.Comp_Corr_Id
                          and r.Comp_Target_Id = c.Comp_Id
                          and r.RelnTyp_Cd = 'PCHILD');

--#EXECUTE_AT_TARGET
insert into twg.CompAttr
select
 0 as CompAttr_ID,
 c.Comp_ID,
 'DIS_SD_ATIME' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 n.dis_sd_atime as CompAttr_Val
from
 inv.stage_dis_swd n,
 twg.cur_comp c
where
 n.CHILD_COMP_NM = c.Comp_Nm
 and n.COMP_NM = c.Comp_Corr_Val
 and n.DIS_SD_ATIME != ''
 and not exists (
  select 1
  from
   twg.cur_compattr ca,
   twg.cur_comp c3
  where
   n.child_comp_nm = c3.comp_nm
   and n.comp_nm = c3.comp_corr_val
   and c3.comp_id = ca.comp_id
   and ca.CompAttr_Val=n.dis_sd_atime
   and ca.AttrTyp_Cd='DIS_SD_ATIME')
union
select
 0 as CompAttr_ID,
 c.Comp_ID,
 'DIS_SD_OPERATION' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 n.dis_sd_operation as CompAttr_Val
from
 inv.stage_dis_swd n,
 twg.cur_comp c
where
 n.child_comp_nm = c.comp_nm
 and n.comp_nm = c.comp_corr_val
 and n.DIS_SD_OPERATION != ''
 and not exists (
  select 1
  from
   twg.cur_compattr ca,
   twg.cur_comp c3
  where
   n.child_comp_nm = c3.comp_nm
   and n.comp_nm = c3.comp_corr_val
   and c3.comp_id = ca.comp_id
   and ca.CompAttr_Val=n.dis_sd_operation
   and ca.AttrTyp_Cd='DIS_SD_OPERATION')
union
select
 0 as CompAttr_ID,
 c.Comp_ID,
 'DIS_SD_STATE' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 n.dis_sd_state as CompAttr_Val
from
 inv.stage_dis_swd n,
 twg.cur_comp c
where
 n.child_comp_nm = c.comp_nm
 and n.comp_nm = c.comp_corr_val
 and n.DIS_SD_STATE != ''
 and not exists (
  select 1
  from
   twg.cur_compattr ca,
   twg.cur_comp c3
  where
   n.child_comp_nm = c3.comp_nm
   and n.comp_nm = c3.comp_corr_val
   and c3.comp_id = ca.comp_id
   and ca.CompAttr_Val=n.dis_sd_state
   and ca.AttrTyp_Cd='DIS_SD_STATE')
union
select
 0 as CompAttr_ID,
 c.Comp_ID,
 'DIS_MD_SIZE_KB' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 char(n.md2_dist_size) as CompAttr_Val
from
 inv.stage_dis_swd n,
 twg.cur_comp c
where
 n.child_comp_nm = c.comp_nm
 and n.comp_nm = c.comp_corr_val
 and n.md2_dist_size != -1
 and not exists (
  select 1
  from
   twg.cur_compattr ca,
   twg.cur_comp c3
  where
   n.child_comp_nm = c3.comp_nm
   and n.comp_nm = c3.comp_corr_val
   and c3.comp_id = ca.comp_id
   and ca.CompAttr_Val= char(n.md2_dist_size)
   and ca.AttrTyp_Cd='DIS_MD_SIZE_KB')
union
select
 0 as CompAttr_ID,
 c.Comp_ID,
 'DIS_MD_STATE' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 char(n.dis_md_state) as CompAttr_Val
from
 inv.stage_dis_swd n,
 twg.cur_comp c
where
 n.child_comp_nm = c.comp_nm
 and n.comp_nm = c.comp_corr_val
 and n.DIS_MD_STATE != -1
 and not exists (
  select 1
  from
   twg.cur_compattr ca,
   twg.cur_comp c3
  where
   n.child_comp_nm = c3.comp_nm
   and n.comp_nm = c3.comp_corr_val
   and c3.comp_id = ca.comp_id
   and ca.CompAttr_Val= char(n.dis_md_state)
   and ca.AttrTyp_Cd='DIS_MD_STATE')
union
select
 0 as Compattr_ID,
 c.comp_id,
 'DIS_FP_TME_OID' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 n.dis_fp_tme_oid as CompAttr_Val
from
 inv.stage_dis_swd n,
 twg.cur_comp c
where
 n.CHILD_COMP_NM = c.Comp_Nm
 and n.COMP_NM = c.Comp_Corr_Val
 and n.DIS_FP_TME_OID != ''
 and not exists (
  select 1
  from
   twg.cur_compattr ca,
   twg.cur_comp c3
  where
   n.CHILD_COMP_NM = c3.Comp_Nm
   and n.COMP_NM = c3.Comp_Corr_Val
   and c3.Comp_ID = ca.Comp_ID
   and ca.CompAttr_Val = n.dis_fp_tme_oid
   and ca.AttrTyp_Cd = 'DIS_FP_TME_OID')
;

-- ***** START: Initialize TWG.Extract_Control on first run *****
-- update the extract control for stageing to msmt table

update TWG.Extract_Control set ExtCtl_From_DtTm = Current Timestamp
                 - Current Timezone
                 - (select PMsmtC_Age_In_Days
                   from TWG.Prune_Msmt_Control
                   where MSrc_Cd = 'DIS'
                     and TmSum_Cd = 'H')
        where ExtCtl_Source = 'inv.stage_dis_swd'
          and ExtCtl_Target = 'TWG.MSMT'
          and ExtCtl_From_DtTm = '1970-01-01-00.00.00.000000';

-- update the extract control for stageing to msmt table, set extctl_to_dttm to
-- max(inv.stage_dis_swd.last_modify_time)

update TWG.Extract_Control set
 ExtCtl_To_DtTm = (select max(last_modify_time) from inv.stage_dis_swd)
where ExtCtl_Source = 'inv.stage_dis_swd'
      and ExtCtl_Target = 'TWG.MSMT' and
      (select count(*) from inv.stage_dis_swd) > 0
;

------------------------------------
-- Measurement Distribution success 
------------------------------------
insert into twg.Msmt (Msmt_ID,Comp_ID, MsmtTyp_ID, 
  TmSum_Cd, Msmt_Strt_Dt, Msmt_Strt_Tm, Msmt_Tot_Val, 
  Msmt_Smpl_Cnt, Msmt_Err_Cnt)
select
  0 as Msmt_ID,
  c.Comp_ID,
  m.MsmtTyp_ID,
  t.TmSum_Cd,
  date(d.last_modify_time) as Msmt_Strt_Dt,
  time(d.last_modify_time) as Msmt_Strt_Tm,
  case 
    when d.dis_md_state = 6 then 1 
    else 0
  end as Msmt_Tot_Val,
  1 as Msmt_Smpl_Cnt,
  0 as Msmt_Err_Cnt
from
  inv.stage_dis_swd d,
  twg.Extract_Control ec,
  twg.Comp c,
  twg.MsmtTyp m,
  twg.TmSum t
where
  c.Comp_Nm=d.child_comp_nm and
  c.Comp_Corr_Val = d.comp_nm and
  ec.extctl_source = 'inv.stage_dis_swd' and
  ec.extctl_target = 'TWG.MSMT' and
  d.last_modify_time > ec.ExtCtl_From_DtTm and
  d.last_modify_time <= ec.ExtCtl_To_DtTm and
  m.MsmtTyp_Nm = 'Distribution Success' and 
  t.TmSum_Nm = 'Daily' 
;

------------------------------------
-- Measurement Distribution failure 
------------------------------------
insert into twg.Msmt (Msmt_ID,Comp_ID, MsmtTyp_ID, 
  TmSum_Cd, Msmt_Strt_Dt, Msmt_Strt_Tm, Msmt_Tot_Val, 
  Msmt_Smpl_Cnt, Msmt_Err_Cnt)
select
  0 as Msmt_ID,
  c.Comp_ID,
  m.MsmtTyp_ID,
  t.TmSum_Cd,
  date(d.last_modify_time) as Msmt_Strt_Dt,
  time(d.last_modify_time) as Msmt_Strt_Tm,
  case 
    when d.dis_md_state = 7 then 1 
    else 0
  end as Msmt_Tot_Val,
  1 as Msmt_Smpl_Cnt,
  0 as Msmt_Err_Cnt
from
  inv.stage_dis_swd d,
  twg.extract_control ec,
  twg.Comp c,
  twg.MsmtTyp m,
  twg.TmSum t
where
  c.Comp_Nm=d.child_comp_nm and
  c.Comp_Corr_Val = d.comp_nm and
  ec.extctl_source = 'inv.stage_dis_swd' and
  ec.extctl_target = 'TWG.MSMT' and
  d.last_modify_time > ec.ExtCtl_From_DtTm and
  d.last_modify_time <= ec.ExtCtl_To_DtTm and
  m.MsmtTyp_Nm = 'Distribution Failure' and 
  t.TmSum_Nm = 'Daily' 
;

------------------------------------
-- Measurement Verify failure 
------------------------------------
insert into twg.Msmt (Msmt_ID,Comp_ID, MsmtTyp_ID, 
  TmSum_Cd, Msmt_Strt_Dt, Msmt_Strt_Tm, Msmt_Tot_Val, 
  Msmt_Smpl_Cnt, Msmt_Err_Cnt)
select
  0 as Msmt_ID,
  c.Comp_ID,
  m.MsmtTyp_ID,
  t.TmSum_Cd,
  date(d.last_modify_time) as Msmt_Strt_Dt,
  time(d.last_modify_time) as Msmt_Strt_Tm,
  case 
    when UPPER( SUBSTR(d.dis_sd_state,5,1) ) = 'E' then 1 
    else 0
  end as Msmt_Tot_Val,
  1 as Msmt_Smpl_Cnt,
  0 as Msmt_Err_Cnt
from
  inv.stage_dis_swd d,
  twg.extract_control ec,
  twg.Comp c,
  twg.MsmtTyp m,
  twg.TmSum t
where
  c.Comp_Nm=d.child_comp_nm and
  c.Comp_Corr_Val = d.comp_nm and
  ec.extctl_source = 'inv.stage_dis_swd' and
  ec.extctl_target = 'TWG.MSMT' and
  d.last_modify_time > ec.ExtCtl_From_DtTm and
  d.last_modify_time <= ec.ExtCtl_To_DtTm and
  d.dis_sd_operation like 'verify%' and 
  m.MsmtTyp_Nm = 'Verify Failure' and 
  t.TmSum_Nm = 'Daily' 
;

----------------------------------------
-- Measurement Distribution Elapsed time 
----------------------------------------
insert into twg.Msmt (Msmt_ID,Comp_ID, MsmtTyp_ID, 
  TmSum_Cd, Msmt_Strt_Dt, Msmt_Strt_Tm, Msmt_Tot_Val, 
  Msmt_Smpl_Cnt, Msmt_Err_Cnt)
select
  0 as Msmt_ID,
  c.Comp_ID,
  m.MsmtTyp_ID,
  t.TmSum_Cd,
  date(d.last_modify_time) as Msmt_Strt_Dt,
  time(d.last_modify_time) as Msmt_Strt_Tm,
  d.md2_elapsed_time as Msmt_Tot_Val,
  1 as Msmt_Smpl_Cnt,
  0 as Msmt_Err_Cnt
from
  inv.stage_dis_swd d,
  twg.extract_control ec,
  twg.Comp c,
  twg.MsmtTyp m,
  twg.TmSum t
where
  c.Comp_Nm=d.child_comp_nm and
  c.Comp_Corr_Val = d.comp_nm and
  ec.extctl_source = 'inv.stage_dis_swd' and
  ec.extctl_target = 'TWG.MSMT' and
  d.last_modify_time > ec.ExtCtl_From_DtTm and
  d.last_modify_time <= ec.ExtCtl_To_DtTm and
  m.MsmtTyp_Nm = 'Distribution Elapsed Time' and 
  t.TmSum_Nm = 'Daily' 
;

----------------------------------------
-- Measurement Receiving time 
----------------------------------------
insert into twg.Msmt (Msmt_ID,Comp_ID, MsmtTyp_ID, 
  TmSum_Cd, Msmt_Strt_Dt, Msmt_Strt_Tm, Msmt_Tot_Val, 
  Msmt_Smpl_Cnt, Msmt_Err_Cnt)
select
  0 as Msmt_ID,
  c.Comp_ID,
  m.MsmtTyp_ID,
  t.TmSum_Cd,
  date(d.last_modify_time) as Msmt_Strt_Dt,
  time(d.last_modify_time) as Msmt_Strt_Tm,
  d.md2_receiving_time as Msmt_Tot_Val,
  1 as Msmt_Smpl_Cnt,
  0 as Msmt_Err_Cnt
from
  inv.stage_dis_swd d,
  twg.extract_control ec,
  twg.Comp c,
  twg.MsmtTyp m,
  twg.TmSum t
where
  c.Comp_Nm=d.child_comp_nm and
  c.Comp_Corr_Val = d.comp_nm and
  ec.extctl_source = 'inv.stage_dis_swd' and
  ec.extctl_target = 'TWG.MSMT' and
  d.last_modify_time > ec.ExtCtl_From_DtTm and
  d.last_modify_time <= ec.ExtCtl_To_DtTm and
  m.MsmtTyp_Nm = 'Receiving Time' and 
  t.TmSum_Nm = 'Daily' 
;

----------------------------------------
-- Measurement Distribution transfer rate 
----------------------------------------
insert into twg.Msmt (Msmt_ID,Comp_ID, MsmtTyp_ID, 
  TmSum_Cd, Msmt_Strt_Dt, Msmt_Strt_Tm, Msmt_Tot_Val, 
  Msmt_Smpl_Cnt, Msmt_Err_Cnt)
select
  0 as Msmt_ID,
  c.Comp_ID,
  m.MsmtTyp_ID,
  t.TmSum_Cd,
  date(d.last_modify_time) as Msmt_Strt_Dt,
  time(d.last_modify_time) as Msmt_Strt_Tm,
  d.md2_dist_size/d.md2_elapsed_time as Msmt_Tot_Val,
  1 as Msmt_Smpl_Cnt,
  0 as Msmt_Err_Cnt
from
  inv.stage_dis_swd d,
  twg.extract_control ec,
  twg.Comp c,
  twg.MsmtTyp m,
  twg.TmSum t
where
  c.Comp_Nm=d.child_comp_nm and
  c.Comp_Corr_Val = d.comp_nm and
  ec.extctl_source = 'inv.stage_dis_swd' and
  ec.extctl_target = 'TWG.MSMT' and
  d.last_modify_time > ec.ExtCtl_From_DtTm and
  d.last_modify_time <= ec.ExtCtl_To_DtTm and
  m.MsmtTyp_Nm = 'Distribution Transfer Rate' and 
  t.TmSum_Nm = 'Daily' 
;

-- update TWG.Extract_Control with new to_dttm
update TWG.Extract_Control
        set ExtCtl_Source = ExtCtl_Source,
            ExtCtl_Target = ExtCtl_Target,
            ExtCtl_From_DtTm = ExtCtl_From_DtTm,
            ExtCtl_To_DtTm = Current Timestamp -Current Timezone
        where ExtCtl_Source = 'inv.stage_dis_swd'
        and ExtCtl_Target = 'TWG.MSMT';

-- Confirm the insertion of data by inserting a row into TWG.EXTRACT_LOG.
-- A trigger gets fired which updates the extract control table's from data with
-- the current to data.

insert into TWG.Extract_Log
select
 ec.extctl_source as extlog_source,
 ec.extctl_target as extlog_target,
 current timestamp as extlog_done_dttm,
 ec.extctl_from_rawseq as extlog_from_rawseq,
 ec.extctl_to_rawseq as extlog_to_rawseq,
 ec.extctl_from_intseq as extlog_from_intseq,
 ec.extctl_to_intseq as extlog_to_intseq,
 ec.extctl_from_dttm as extlog_from_dttm,
 ec.extctl_to_dttm as extlog_to_dttm
from 
 TWG.Extract_control ec
where
 ec.extctl_source = 'inv.stage_dis_swd' and
 ec.extctl_target = 'TWG.MSMT'
; 

------------------------------------
------------------------------------
-- Load DIS_FILEPACK values into CDW
------------------------------------
--#EXECUTE_AT_TARGET
--#IGNORE_ERROR
drop table inv.stage_comp;
--#EXECUTE_AT_TARGET
create table inv.stage_comp like twg.comp;
--#EXECUTE_AT_TARGET
insert into inv.stage_comp (Comp_ID, CompTyp_Cd, Centr_Cd, Cust_ID,
  Comp_Corr_ID, Comp_Nm, Comp_Corr_Val, Comp_Strt_DtTm, Comp_End_DtTm, Comp_Ds)
select comp_id, comptyp_cd, centr_cd, cust_id, comp_corr_id, comp_nm, comp_corr_val, comp_strt_dttm, comp_end_dttm, comp_ds from twg.cur_comp
where
comptyp_cd='DIS_FILEPACK'
;

--#EXECUTE_AT_TARGET
INSERT INTO TWG.COMP
select
 0 as Comp_Id,
 'DIS_FILEPACK' as CompTyp_Cd,
 centr.Centr_Cd as Centr_Cd,
 cu.Cust_ID as Cust_ID,
 0 as Comp_Corr_Id,
 p.comp_nm as Comp_Nm,
 '' as Comp_Corr_Val,
 current timestamp - current timezone as Comp_Strt_DtTm ,
 '9999-01-01-00.00.00.000000' as Comp_End_DtTm,
 '' as Comp_Ds
from
 inv.stage_dis_filepack p,
 inv.centr_lookup centr,
 inv.cust_lookup cust,
 twg.cust cu
where
 p.dis_fp_name != ''
 AND p.version != ''
 AND ((cust.value = p.COMP_NM AND cust.Cust_Acct_Cd = cu.Cust_Acct_Cd)
      OR cust.value = '@')
 AND (centr.value = p.COMP_NM OR centr.value = '@')
 AND not exists (
  select 1
  from
   inv.stage_comp c
  where
   c.Comp_Nm=p.comp_nm)
;

--#EXECUTE_AT_TARGET
insert into twg.CompAttr
select
 0 as CompAttr_ID,
 c.Comp_ID,
 'DIS_FP_NAME' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 n.dis_fp_name as CompAttr_Val
from
 inv.stage_dis_filepack n,
 twg.cur_comp c
where
 n.comp_nm = c.Comp_Nm
 and n.DIS_FP_NAME != ''
 and not exists (
  select 1
  from
   twg.cur_compattr ca,
   twg.cur_comp c3
  where
   n.comp_nm = c3.comp_nm
   and c3.comp_id = ca.comp_id
   and ca.CompAttr_Val=n.dis_fp_name
   and ca.AttrTyp_Cd='DIS_FP_NAME')
union
select
 0 as CompAttr_ID,
 c.Comp_ID,
 'VERSION' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 n.version as CompAttr_Val
from
 inv.stage_dis_filepack n,
 twg.cur_comp c
where
 n.comp_nm = c.Comp_Nm
 and n.version != ''
 and not exists (
  select 1
  from
   twg.cur_compattr ca,
   twg.cur_comp c3
  where
  --version is standard attribute and we only check version attribute in 
  --comp type DIS_FILEPACK
   c3.CompTyp_Cd in ('DIS_FILEPACK')
   and n.comp_nm = c3.comp_nm
   and c3.comp_id = ca.comp_id
   and ca.CompAttr_Val=n.version
   and ca.AttrTyp_Cd='VERSION')
union
select
 0 as CompAttr_ID,
 c.Comp_ID,
 'DIS_FP_TME_OID' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 n.dis_fp_tme_oid as CompAttr_Val
from
 inv.stage_dis_filepack n,
 twg.cur_comp c
where
 n.COMP_NM = c.Comp_Nm
 and n.DIS_FP_TME_OID != ''
 and not exists (
  select 1
  from
   twg.cur_compattr ca,
   twg.cur_comp c3
  where
   n.COMP_NM = c3.comp_nm
   and c3.comp_id = ca.comp_id
   and ca.CompAttr_Val=n.dis_fp_tme_oid
   and ca.AttrTyp_Cd='DIS_FP_TME_OID')
union
select
 0 as CompAttr_ID,
 c.Comp_ID,
 'DIS_FP_SRC_HOST' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 n.dis_fp_src_host as CompAttr_Val
from
 inv.stage_dis_filepack n,
 twg.cur_comp c
where
 n.COMP_NM = c.Comp_Nm
 and n.DIS_FP_SRC_HOST != ''
 and not exists (
  select 1
  from
   twg.cur_compattr ca,
   twg.cur_comp c3
  where
   n.COMP_NM = c3.comp_nm
   and c3.comp_id = ca.comp_id
   and ca.CompAttr_Val=n.dis_fp_src_host
   and ca.AttrTyp_Cd='DIS_FP_SRC_HOST')
;
------------------------------------
-- Load DIS_MDIST values into CDW
------------------------------------
--#EXECUTE_AT_TARGET
--#IGNORE_ERROR
drop table inv.stage_comp;
--#EXECUTE_AT_TARGET
create table inv.stage_comp like twg.comp;
--#EXECUTE_AT_TARGET
insert into inv.stage_comp (Comp_ID, CompTyp_Cd, Centr_Cd, Cust_ID,
  Comp_Corr_ID, Comp_Nm, Comp_Corr_Val, Comp_Strt_DtTm, Comp_End_DtTm, Comp_Ds)
select comp_id, comptyp_cd, centr_cd, cust_id, comp_corr_id, comp_nm, comp_corr_val, comp_strt_dttm, comp_end_dttm, comp_ds from twg.cur_comp
where
comptyp_cd='DIS_MDIST'
;

--#EXECUTE_AT_TARGET
INSERT INTO TWG.COMP
select
 0 as Comp_Id,
 'DIS_MDIST' as CompTyp_Cd,
 centr.Centr_Cd as Centr_Cd,
 cu.Cust_ID as Cust_ID,
 0 as Comp_Corr_Id,
 d.md2_dist_id as Comp_Nm,
 '' as Comp_Corr_Val,
 current timestamp - current timezone as Comp_Strt_DtTm ,
 '9999-01-01-00.00.00.000000' as Comp_End_DtTm,
 '' as Comp_Ds
from
 inv.stage_dist_state d,
 inv.centr_lookup centr,
 inv.cust_lookup cust,
 twg.cust cu
where
 d.md2_dist_id != ''
 AND ((cust.value = d.md2_dist_id AND cust.Cust_Acct_Cd = cu.Cust_Acct_Cd)
      OR cust.value = '@')
 AND (centr.value = d.md2_dist_id OR centr.value = '@')
 AND not exists (
  select 1
  from
   inv.stage_comp c
  where
   c.Comp_Nm=d.md2_dist_id)
;

--#EXECUTE_AT_TARGET
insert into twg.CompAttr
select
 0 as CompAttr_ID,
 c.Comp_ID,
 'DIS_MD_SIZE_KB' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 char(n.dist_size) as CompAttr_Val
from
 inv.stage_dist_state n,
 twg.cur_comp c
where
 n.MD2_DIST_ID = c.Comp_Nm
 and n.DIST_SIZE != -1
 and not exists (
  select 1
  from
   twg.cur_compattr ca,
   twg.cur_comp c3
  where
   n.MD2_DIST_ID = c3.Comp_Nm
   and c3.Comp_ID = ca.Comp_ID
   and ca.CompAttr_Val=char(n.dist_size)
   and ca.AttrTyp_Cd='DIS_MD_SIZE_KB')
union
select
 0 as CompAttr_ID,
 c.Comp_ID,
 'DIS_MD_STTM' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 char(n.start_time) as CompAttr_Val
from
 inv.stage_dist_state n,
 twg.cur_comp c
where
 n.MD2_DIST_ID = c.Comp_Nm
 and n.START_TIME is not null
 and not exists (
  select 1
  from
   twg.cur_compattr ca,
   twg.cur_comp c3
  where
   n.MD2_DIST_ID = c3.Comp_Nm
   and c3.Comp_ID = ca.Comp_ID
   and ca.CompAttr_Val=char(n.start_time)
   and ca.AttrTyp_Cd='DIS_MD_STTM')
union
select
 0 as CompAttr_ID,
 c.Comp_ID,
 'DIS_MD_ENDTM' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 char(n.finish_time) as CompAttr_Val
from
 inv.stage_dist_state n,
 twg.cur_comp c
where
 n.MD2_DIST_ID = c.Comp_Nm
 and n.FINISH_TIME is not null
 and not exists (
  select 1
  from
   twg.cur_compattr ca,
   twg.cur_comp c3
  where
   n.MD2_DIST_ID = c3.Comp_Nm
   and c3.Comp_ID = ca.Comp_ID
   and ca.CompAttr_Val=char(n.finish_time)
   and ca.AttrTyp_Cd='DIS_MD_ENDTM')
union
select
 0 as CompAttr_ID,
 c.Comp_ID,
 'DIS_MD_SRCAPPL' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 n.source_application as CompAttr_Val
from
 inv.stage_dist_state n,
 twg.cur_comp c
where
 n.MD2_DIST_ID = c.Comp_Nm
 and n.SOURCE_APPLICATION !=''
 and not exists (
  select 1
  from
   twg.cur_compattr ca,
   twg.cur_comp c3
  where
   n.MD2_DIST_ID = c3.Comp_Nm
   and c3.Comp_ID = ca.Comp_ID
   and ca.CompAttr_Val=n.source_application
   and ca.AttrTyp_Cd='DIS_MD_SRCAPPL')
;

-- Update end timestamps for deleted components
--
update twg.comp
set
 Comp_End_DtTm = current timestamp - current timezone
where
 comp_id IN (select comp_id from inv.stage_delete_comp)
;

update twg.compreln
set
 CompReln_End_DtTm = current timestamp - current timezone
where
 comp_target_id IN (select comp_id from inv.stage_delete_comp)
;

update twg.compattr
set
 CompAttr_End_DtTm = current timestamp - current timezone
where
 comp_id IN (select comp_id from inv.stage_delete_comp)
;
