--  @(#)68    1.16  src/tedw_apps/inv/install/v420/etl/sql/INV_c10_s020_loadInvData.db2, inventory, inventory_4.2.2, 20041114  11/10/04  04:50:58
--
-- Licensed Materials - Property of IBM
--
-- 5698-INV
--
-- (C) Copyright IBM Corp. 2002 All Rights Reserved
--
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with
-- IBM Corp

-- Purpose: Extracts INV data from staging into CDW
----------------------------------


----------------------------------
----------------------------------
-- Process IP_HOSTS values
----------------------------------
--#EXECUTE_AT_TARGET
--#IGNORE_ERROR
drop table inv.stage_ip_host_temp;
--#EXECUTE_AT_TARGET
create table inv.stage_ip_host_temp like inv.stage_ip_host_t;
--#EXECUTE_AT_TARGET
insert into inv.stage_ip_host_temp
select
  T1.COMPUTER_SYS_ID,
  case
   when T4.IP_HOSTNAME != '' AND T4.IP_DOMAIN != '' then lower(T4.IP_HOSTNAME)||'.'||lower(T4.IP_DOMAIN)
   when T4.IP_ADDR != '' then T4.IP_ADDR
   when T6.IPX_ADDR != '' then T6.IPX_ADDR
   else ''
  end as comp_nm,
  value(T1.TME_OBJECT_ID,'') as tme_object_id,
  value(T1.TME_OBJECT_LABEL,'') as tme_object_label,
  value(T1.COMPUTER_MODEL,'') as computer_model,
  value(T1.SYS_SER_NUM,'') as sys_ser_num,
  value(T1.OS_NAME,'') as os_name,
  value(T1.OS_TYPE,'') as os_type,
  value(T1.OS_MAJOR_VERS,-1) as os_major_vers,
  value(T1.OS_MINOR_VERS,-1) as os_minor_vers,
  value(T1.OS_SUB_VERS,'') as os_sub_vers,
  T1.RECORD_TIME as record_time,
  value(T2.USER_NAME,'') as user_name,
  value(T2.DOMAIN_NAME,'') as domain_name,
  value(T2.WORKGROUP_NAME,'') as workgroup_name,
  value(lower(T4.IP_HOSTNAME),'') as ip_hostname,
  value(lower(T4.IP_DOMAIN),'') as ip_domain,
  value(T4.IP_ADDR,'') as ip_addr,
  value(T6.IPX_ADDR,'') as ipx_addr,
  value(T8.PHYSICAL_TOTAL_KB,-1) as physical_total_kb,
  value(T10.NUM_PROCESSORS,-1) as num_processors,
  value(T10.MANUFACTURER,'') as manufacturer,
  value(T10.PROCESSOR_MODEL,'') as processor_model,
  value(T10.MAX_SPEED,-1) as max_speed,
  value(T10.CURRENT_SPEED,-1) as current_speed,
  value(T10.CHIP_FAMILY,-1) as chip_family,
  value(T10.CHIP_MODEL,-1) as chip_model,
  'Unknown' as system_purpose
FROM
  inv.stage_COMPUTER T1  LEFT OUTER JOIN inv.stage_PCSYS T2
      ON     T1.COMPUTER_SYS_ID = T2.COMPUTER_SYS_ID,
  inv.stage_COMPUTER T3  LEFT OUTER JOIN  inv.stage_IPNETWORK  T4
      ON     T3.COMPUTER_SYS_ID = T4.COMPUTER_SYS_ID,
  inv.stage_COMPUTER T5  LEFT OUTER JOIN inv.stage_IPXNETWORK T6
      ON     T5.COMPUTER_SYS_ID = T6.COMPUTER_SYS_ID,
  inv.stage_COMPUTER T7  LEFT OUTER JOIN  inv.stage_MEMORY T8
      ON     T7.COMPUTER_SYS_ID = T8.COMPUTER_SYS_ID,
  inv.stage_COMPUTER T9  LEFT OUTER JOIN  inv.stage_PROCESSOR T10
      ON     T9.COMPUTER_SYS_ID = T10.COMPUTER_SYS_ID

WHERE
  T1.COMPUTER_SYS_ID = T3.COMPUTER_SYS_ID  AND
  T1.COMPUTER_SYS_ID = T5.COMPUTER_SYS_ID  AND
  T1.COMPUTER_SYS_ID = T7.COMPUTER_SYS_ID  AND
  T1.COMPUTER_SYS_ID = T9.COMPUTER_SYS_ID and
 (locate('_', T4.ip_addr) = 0 or locate('A', T4.ip_addr) > 0)
;

--#EXECUTE_AT_TARGET
--sample check for invalid data
-- check if valid cust
-- check if valid centr
-- check for duplicate comp_nm
-- check for comp_nm = ''
--invalid data is not written to CDW
insert into inv.invalid_ip_host
select * from inv.stage_ip_host_temp n
where
  not exists(
    select 1 from inv.cust_lookup
    where inv.cust_lookup.value = n.comp_nm OR
          inv.cust_lookup.value = '@') OR
  not exists(
    select 1 from inv.centr_lookup
    where inv.centr_lookup.value = n.comp_nm OR
          inv.centr_lookup.value = '@') OR
  exists(
    select 1 from inv.stage_ip_host_temp t
    where t.comp_nm = n.comp_nm
    group by comp_nm having count(comp_nm)>1) OR
  comp_nm = ''
;

--Remove duplicate comp_nm records
--#EXECUTE_AT_TARGET
--#IGNORE_ERROR
drop table inv.stage_ip_host;
--#EXECUTE_AT_TARGET
create table inv.stage_ip_host like inv.stage_ip_host_t;
--#EXECUTE_AT_TARGET
insert into inv.stage_ip_host
select * from inv.stage_ip_host_temp t
where EXISTS(
 select 1
 from inv.stage_ip_host_temp n
 where t.comp_nm = n.comp_nm
 group by comp_nm having count(comp_nm)!>1)
;

----------------------------------
-- Process INV_STOR values
----------------------------------
--#EXECUTE_AT_TARGET
--#IGNORE_ERROR
drop table inv.stage_inv_stor;
--#EXECUTE_AT_TARGET
create table inv.stage_inv_stor like inv.stage_inv_stor_t;
--#EXECUTE_AT_TARGET
insert into inv.stage_inv_stor
SELECT
   i.COMP_NM,
   CONCAT('storage',char(p.inst_storage_id)) as child_comp_nm,
   value(p.STORAGE_TYPE,'') as storage_type,
   value(p.MANUFACTURER,'') as manufacturer,
   value(p.MODEL,'') as model,
   value(p.HDISK_SIZE_MB,-1) as hdisk_size_mb
FROM
   inv.stage_IP_HOST i,
   inv.stage_STORAGE p
WHERE
   i.COMPUTER_SYS_ID = p.COMPUTER_SYS_ID
;

----------------------------------
-- Process INV_MEMORY values
----------------------------------
--#EXECUTE_AT_TARGET
--#IGNORE_ERROR
drop table inv.stage_inv_memory;
--#EXECUTE_AT_TARGET
create table inv.stage_inv_memory like inv.stage_inv_memory_t;
--#EXECUTE_AT_TARGET
insert into inv.stage_inv_memory
SELECT
   i.COMP_NM,
   CONCAT('memory',char(p.inst_mem_id)) as child_comp_nm,
   value(p.MODULE_SIZE_MB,-1) as module_size_mb,
   value(p.SOCKET_NAME,'') as socket_name,
   value(p.PACKAGING,'') as packaging,
   value(p.MEM_TYPE,'') as mem_type
FROM
   inv.stage_IP_HOST i,
   inv.stage_MEM_MODULE p
WHERE
   i.COMPUTER_SYS_ID = p.COMPUTER_SYS_ID
;

----------------------------------
-- Load values
----------------------------------

------------------------------------
-- Load IP_HOST values into CDW
------------------------------------

-- Create a staging table so that we can keep track of deleted components
--
--#EXECUTE_AT_TARGET
--#IGNORE_ERROR
drop table inv.stage_delete_comp;
--#EXECUTE_AT_TARGET
create table inv.stage_delete_comp like twg.comp;


-- In order to improve performance we create a temporary stage_comp table
-- specific to the INV application, i.e. a table like the TWG.Comp one,
-- but filled in only with data related to the INV application; moreover
-- when inserting into this table, we use the TWG.cur_comp view, which
-- provides only the currently available components avoiding to explicitly
-- indicate the clause: current timestamp - current timezone between
-- TWG.Comp.Comp_Strt_DtTm and TWG.Comp.Comp_End_DtTm.
--
--#EXECUTE_AT_TARGET
--#IGNORE_ERROR
drop table inv.stage_comp;
--#EXECUTE_AT_TARGET
create table inv.stage_comp like twg.comp;
--#EXECUTE_AT_TARGET
insert into inv.stage_comp (Comp_ID, CompTyp_Cd, Centr_Cd, Cust_ID,
  Comp_Corr_ID, Comp_Nm, Comp_Corr_Val, Comp_Strt_DtTm, Comp_End_DtTm, Comp_Ds)
select
  c.comp_id, c.comptyp_cd, c.centr_cd, c.cust_id, c.comp_corr_id, c.comp_nm,
  c.comp_corr_val, c.comp_strt_dttm, c.comp_end_dttm, c.comp_ds 
from twg.cur_comp c
where
(c.comptyp_cd='IP_HOST' OR c.comptyp_cd='IP_INTERFACE' OR c.comptyp_cd='IPX_INTERFACE')
;

--#EXECUTE_AT_TARGET
INSERT INTO TWG.COMP
select
 0 as Comp_Id,
 case
  when n.IP_HOSTNAME != '' AND n.IP_DOMAIN != '' then 'IP_HOST'
  when n.IP_ADDR != '' then 'IP_INTERFACE'
  when n.IPX_ADDR != '' then 'IPX_INTERFACE'
 end as CompTyp_Cd,
 centr.Centr_Cd as Centr_Cd,
 cu.Cust_ID as Cust_ID,
 0 as Comp_Corr_Id,
 n.Comp_Nm as Comp_Nm,
 '' as Comp_Corr_Val,
 current timestamp - current timezone as Comp_Strt_DtTm ,
 '9999-01-01-00.00.00.000000' as Comp_End_DtTm,
 '' as Comp_Ds
from
 inv.stage_ip_host n,
 inv.centr_lookup centr,
 inv.cust_lookup cust,
 twg.cust cu
where
 n.comp_nm != ''
 AND ((cust.value = n.comp_nm AND cust.Cust_Acct_Cd = cu.Cust_Acct_Cd)
      OR cust.value = '@')
 AND (centr.value = n.comp_nm OR centr.value = '@')
 AND not exists (
  select 1
  from
   inv.stage_comp c
  where
   c.comp_nm=n.comp_nm)
;

-- Check for deleted components
--
insert into inv.stage_delete_comp
select * from inv.stage_comp c
where
 not exists (
  select 1
  from
  inv.stage_ip_host n
 where
  c.comp_nm = n.comp_nm
 )
;

--#EXECUTE_AT_TARGET
insert into twg.compattr
select
 0 as compattr_id,
 c.comp_id,
 'TME_OBJECT_ID' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 n.tme_object_id as CompAttr_Val
from
 inv.stage_ip_host n,
 twg.cur_comp c
where
 c.comp_nm=n.comp_nm
 and n.tme_object_id != ''
 and not exists (
  select 1
  from
   twg.cur_compattr ca,
   twg.cur_comp c2
  where
   n.comp_nm=c2.comp_nm
   and ca.comp_id=c2.comp_id
   and ca.CompAttr_Val=n.tme_object_id
   and ca.AttrTyp_Cd='TME_OBJECT_ID')
union
select
 0 as compattr_id,
 c.comp_id,
 'TME_LABEL' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 n.tme_object_label as CompAttr_Val
from
 inv.stage_ip_host n,
 twg.cur_comp c
where
 c.comp_nm=n.comp_nm
 and n.tme_object_label != ''
 and not exists (
  select 1
  from
   twg.cur_compattr ca,
   twg.cur_comp c2
  where
   n.comp_nm=c2.comp_nm
   and ca.comp_id=c2.comp_id
   and ca.CompAttr_Val=n.tme_object_label
   and ca.AttrTyp_Cd='TME_LABEL')
union
select
 0 as compattr_id,
 c.comp_id,
 'MODEL' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 n.computer_model as CompAttr_Val
from
 inv.stage_ip_host n,
 twg.cur_comp c
where
 c.comp_nm=n.comp_nm
 and n.computer_model != ''
 and not exists (
  select 1
  from
   twg.cur_compattr ca,
   twg.cur_comp c2
  where
   n.comp_nm=c2.comp_nm
   and ca.comp_id=c2.comp_id
   and ca.CompAttr_Val=n.computer_model
   and ca.AttrTyp_Cd='MODEL')
union
select
 0 as compattr_id,
 c.comp_id,
 'SERIAL_NUMBER' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 n.sys_ser_num as CompAttr_Val
from
 inv.stage_ip_host n,
 twg.cur_comp c
where
 c.comp_nm=n.comp_nm
 and n.sys_ser_num != ''
 and not exists (
  select 1
  from
   twg.cur_compattr ca,
   twg.cur_comp c2
  where
   n.comp_nm=c2.comp_nm
   and ca.comp_id=c2.comp_id
   and ca.CompAttr_Val=n.sys_ser_num
   and ca.AttrTyp_Cd='SERIAL_NUMBER')
union
select
 0 as compattr_id,
 c.comp_id,
 'OS_NAME' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 n.os_name as CompAttr_Val
from
 inv.stage_ip_host n,
 twg.cur_comp c
where
 c.comp_nm=n.comp_nm
 and n.os_name != ''
 and not exists (
  select 1
  from
   twg.cur_compattr ca,
   twg.cur_comp c2
  where
   n.comp_nm=c2.comp_nm
   and ca.comp_id=c2.comp_id
   and ca.CompAttr_Val=n.os_name
   and ca.AttrTyp_Cd='OS_NAME')
union
select
 0 as compattr_id,
 c.comp_id,
 'OS_TYPE' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 n.os_type as CompAttr_Val
from
 inv.stage_ip_host n,
 twg.cur_comp c
where
 c.comp_nm=n.comp_nm
 and n.os_type != ''
 and not exists (
  select 1
  from
   twg.cur_compattr ca,
   twg.cur_comp c2
  where
   n.comp_nm=c2.comp_nm
   and ca.comp_id=c2.comp_id
   and ca.CompAttr_Val=n.os_type
   and ca.AttrTyp_Cd='OS_TYPE')
union
select
 0 as compattr_id,
 c.comp_id,
 'MAJOR_VERSION' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 char(n.os_major_vers) as CompAttr_Val
from
 inv.stage_ip_host n,
 twg.cur_comp c
where
 c.comp_nm=n.comp_nm
 and n.os_major_vers != -1
 and not exists (
  select 1
  from
   twg.cur_compattr ca,
   twg.cur_comp c2
  where
   n.comp_nm=c2.comp_nm
   and ca.comp_id=c2.comp_id
   and ca.CompAttr_Val=char(n.os_major_vers)
   and ca.AttrTyp_Cd='MAJOR_VERSION')
union
select
 0 as compattr_id,
 c.comp_id,
 'MINOR_VERSION' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 char(n.os_minor_vers) as CompAttr_Val
from
 inv.stage_ip_host n,
 twg.cur_comp c
where
 c.comp_nm=n.comp_nm
 and n.os_minor_vers != -1
 and not exists (
  select 1
  from
   twg.cur_compattr ca,
   twg.cur_comp c2
  where
   n.comp_nm=c2.comp_nm
   and ca.comp_id=c2.comp_id
   and ca.CompAttr_Val=char(n.os_minor_vers)
   and ca.AttrTyp_Cd='MINOR_VERSION')
union
select
 0 as compattr_id,
 c.comp_id,
 'SUB_VERSION' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 n.os_sub_vers as CompAttr_Val
from
 inv.stage_ip_host n,
 twg.cur_comp c
where
 c.comp_nm=n.comp_nm
 and n.os_sub_vers != ''
 and not exists (
  select 1
  from
   twg.cur_compattr ca,
   twg.cur_comp c2
  where
   n.comp_nm=c2.comp_nm
   and ca.comp_id=c2.comp_id
   and ca.CompAttr_Val=n.os_sub_vers
   and ca.AttrTyp_Cd='SUB_VERSION')
union
select
 0 as compattr_id,
 c.comp_id,
 'INV_SYS_PURPOSE' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 n.system_purpose as CompAttr_Val
from
 inv.stage_ip_host n,
 twg.cur_comp c
where
 c.comp_nm=n.comp_nm
 and n.system_purpose != ''
 and not exists (
  select 1
  from
   twg.cur_compattr ca,
   twg.cur_comp c2
  where
   n.comp_nm=c2.comp_nm
   and ca.comp_id=c2.comp_id
   and ca.CompAttr_Val=n.system_purpose
   and ca.AttrTyp_Cd='INV_SYS_PURPOSE')
union
select
 0 as compattr_id,
 c.comp_id,
 'INV_RECORD_TIME' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 char(n.record_time) as CompAttr_Val
from
 inv.stage_ip_host n,
 twg.cur_comp c
where
 c.comp_nm=n.comp_nm
 and not exists (
  select 1
  from
   twg.cur_compattr ca,
   twg.cur_comp c2
  where
   n.comp_nm=c2.comp_nm
   and ca.comp_id=c2.comp_id
   and ca.CompAttr_Val=char(n.record_time)
   and ca.AttrTyp_Cd='INV_RECORD_TIME')
;

--#EXECUTE_AT_TARGET
insert into twg.compattr
select
 0 as compattr_id,
 c.comp_id,
 'INV_USER_NAME' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 n.user_name as CompAttr_Val
from
 inv.stage_ip_host n,
 twg.cur_comp c
where
 c.comp_nm=n.comp_nm
 and n.user_name != ''
 and not exists (
  select 1
  from
   twg.cur_compattr ca,
   twg.cur_comp c2
  where
   n.comp_nm=c2.comp_nm
   and ca.comp_id=c2.comp_id
   and ca.CompAttr_Val=n.user_name
   and ca.AttrTyp_Cd='INV_USER_NAME')
union
select
 0 as compattr_id,
 c.comp_id as comp_id,
 'INV_DOMAIN_NAME' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 n.domain_name as CompAttr_Val
from
 inv.stage_ip_host n,
 twg.cur_comp c
where
 c.comp_nm=n.comp_nm
 and n.domain_name != ''
 and not exists (
  select 1
  from
   twg.cur_compattr ca,
   twg.cur_comp c2
  where
   n.comp_nm=c2.comp_nm
   and ca.comp_id=c2.comp_id
   and ca.CompAttr_Val=n.domain_name
   and ca.AttrTyp_Cd='INV_DOMAIN_NAME')
union
select
 0 as compattr_id,
 c.comp_id as comp_id,
 'INV_WORKGROUP_NM' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 n.workgroup_name as CompAttr_Val
from
 inv.stage_ip_host n,
 twg.cur_comp c
where
 c.comp_nm=n.comp_nm
 and n.workgroup_name != ''
 and not exists (
  select 1
  from
   twg.cur_compattr ca,
   twg.cur_comp c2
  where
   n.comp_nm=c2.comp_nm
   and ca.comp_id=c2.comp_id
   and ca.CompAttr_Val=n.workgroup_name
   and ca.AttrTyp_Cd='INV_WORKGROUP_NM')
;

--#EXECUTE_AT_TARGET
insert into twg.compattr
select
 0 as compattr_id,
 c.comp_id,
 'IP_HOSTNAME' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 n.ip_hostname as CompAttr_Val
from
 inv.stage_ip_host n,
 twg.cur_comp c
where
 c.comp_nm=n.comp_nm
 and n.ip_hostname != ''
 and not exists (
  select 1
  from
   twg.cur_compattr ca,
   twg.cur_comp c2
  where
   n.comp_nm=c2.comp_nm
   and ca.comp_id=c2.comp_id
   and ca.CompAttr_Val=n.ip_hostname
   and ca.AttrTyp_Cd='IP_HOSTNAME')
union
select
 0 as compattr_id,
 c.comp_id as comp_id,
 'IP_DOMAIN' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 n.ip_domain as CompAttr_Val
from
 inv.stage_ip_host n,
 twg.cur_comp c
where
 c.comp_nm=n.comp_nm
 and n.ip_domain != ''
 and not exists (
  select 1
  from
   twg.cur_compattr ca,
   twg.cur_comp c2
  where
   n.comp_nm=c2.comp_nm
   and ca.comp_id=c2.comp_id
   and ca.CompAttr_Val=n.ip_domain
   and ca.AttrTyp_Cd='IP_DOMAIN')
union
select
 0 as compattr_id,
 c.comp_id as comp_id,
 'LAST_IP_ADDRESS' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 n.ip_addr as CompAttr_Val
from
 inv.stage_ip_host n,
 twg.cur_comp c
where
 c.comp_nm=n.comp_nm
 and n.ip_addr != ''
 and not exists (
  select 1
  from
   twg.cur_compattr ca,
   twg.cur_comp c2
  where
   n.comp_nm=c2.comp_nm
   and ca.comp_id=c2.comp_id
   and ca.CompAttr_Val=n.ip_addr
   and ca.AttrTyp_Cd='LAST_IP_ADDRESS')
;

--#EXECUTE_AT_TARGET
insert into twg.compattr
select
 0 as compattr_id,
 c.comp_id as comp_id,
 'INV_IPX_ADDR' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 n.ipx_addr as CompAttr_Val
from
 inv.stage_ip_host n,
 twg.cur_comp c
where
 c.comp_nm=n.comp_nm
 and n.ipx_addr != ''
 and not exists (
  select 1
  from
   twg.cur_compattr ca,
   twg.cur_comp c2
  where
   n.comp_nm=c2.comp_nm
   and ca.comp_id=c2.comp_id
   and ca.CompAttr_Val=n.ipx_addr
   and ca.AttrTyp_Cd='INV_IPX_ADDR')
;

--#EXECUTE_AT_TARGET
insert into twg.compattr
select
 0 as compattr_id,
 c.comp_id,
 'INV_PHYSICAL_MEM' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 char(n.physical_total_kb) as CompAttr_Val
from
 inv.stage_ip_host n,
 twg.cur_comp c
where
 c.comp_nm=n.comp_nm
 and n.physical_total_kb != -1
 and not exists (
  select 1
  from
   twg.cur_compattr ca,
   twg.cur_comp c2
  where
   n.comp_nm=c2.comp_nm
   and ca.comp_id=c2.comp_id
   and ca.CompAttr_Val=char(n.physical_total_kb)
   and ca.AttrTyp_Cd='INV_PHYSICAL_MEM')
;

--#EXECUTE_AT_TARGET
insert into twg.compattr
select
 0 as compattr_id,
 c.comp_id,
 'INV_NUM_CPU' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 char(n.num_processors) as CompAttr_Val
from
 inv.stage_ip_host n,
 twg.cur_comp c
where
 c.comp_nm=n.comp_nm
 and n.num_processors != -1
 and not exists (
  select 1
  from
   twg.cur_compattr ca,
   twg.cur_comp c2
  where
   c2.comp_nm=n.comp_nm
   and ca.comp_id=c2.comp_id
   and ca.CompAttr_Val=char(n.num_processors)
   and ca.AttrTyp_Cd='INV_NUM_CPU')
union
select
 0 as compattr_id,
 c.comp_id,
 'INV_CPU_MANUFACT' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 n.manufacturer as CompAttr_Val
from
 inv.stage_ip_host n,
 twg.cur_comp c
where
 c.comp_nm=n.comp_nm
 and n.manufacturer != ''
 and not exists (
  select 1
  from
   twg.cur_compattr ca,
   twg.cur_comp c2
  where
   n.comp_nm=c2.comp_nm
   and ca.comp_id=c2.comp_id
   and ca.CompAttr_Val=n.manufacturer
   and ca.AttrTyp_Cd='INV_CPU_MANUFACT')
union
select
 0 as compattr_id,
 c.comp_id,
 'INV_CPU_NAME' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 n.processor_model as CompAttr_Val
from
 inv.stage_ip_host n,
 twg.cur_comp c
where
 c.comp_nm=n.comp_nm
 and n.processor_model != ''
 and not exists (
  select 1
  from
   twg.cur_compattr ca,
   twg.cur_comp c2
  where
   n.comp_nm=c2.comp_nm
   and ca.comp_id=c2.comp_id
   and ca.CompAttr_Val=n.processor_model
   and ca.AttrTyp_Cd='INV_CPU_NAME')
union
select
 0 as compattr_id,
 c.comp_id,
 'INV_CPU_MAX_SPEED' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 char(n.max_speed) as CompAttr_Val
from
 inv.stage_ip_host n,
 twg.cur_comp c
where
 c.comp_nm=n.comp_nm
 and n.max_speed != -1
 and not exists (
  select 1
  from
   twg.cur_compattr ca,
   twg.cur_comp c2
  where
   n.comp_nm=c2.comp_nm
   and ca.comp_id=c2.comp_id
   and ca.CompAttr_Val=char(n.max_speed)
   and ca.AttrTyp_Cd='INV_CPU_MAX_SPEED')
union
select
 0 as compattr_id,
 c.comp_id,
 'INV_CPU_CUR_SPEED' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 char(n.current_speed) as CompAttr_Val
from
 inv.stage_ip_host n,
 twg.cur_comp c
where
 c.comp_nm=n.comp_nm
 and n.current_speed != -1
 and not exists (
  select 1
  from
   twg.cur_compattr ca,
   twg.cur_comp c2
  where
   n.comp_nm=c2.comp_nm
   and ca.comp_id=c2.comp_id
   and ca.CompAttr_Val=char(n.current_speed)
   and ca.AttrTyp_Cd='INV_CPU_CUR_SPEED')
union
select
 0 as compattr_id,
 c.comp_id,
 'INV_CPU_FAMILY' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 char(n.chip_family) as CompAttr_Val
from
 inv.stage_ip_host n,
 twg.cur_comp c
where
 c.comp_nm=n.comp_nm
 and n.chip_family != -1
 and not exists (
  select 1
  from
   twg.cur_compattr ca,
   twg.cur_comp c2
  where
   n.comp_nm=c2.comp_nm
   and ca.comp_id=c2.comp_id
   and ca.CompAttr_Val=char(n.chip_family)
   and ca.AttrTyp_Cd='INV_CPU_FAMILY')
union
select
 0 as compattr_id,
 c.comp_id,
 'INV_CPU_MODEL' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 char(n.chip_model) as CompAttr_Val
from
 inv.stage_ip_host n,
 twg.cur_comp c
where
 c.comp_nm=n.comp_nm
 and n.chip_model != -1
 and not exists (
  select 1
  from
   twg.cur_compattr ca,
   twg.cur_comp c2
  where
   n.comp_nm=c2.comp_nm
   and ca.comp_id=c2.comp_id
   and ca.CompAttr_Val=char(n.chip_model)
   and ca.AttrTyp_Cd='INV_CPU_MODEL')
;


------------------------------------
-- Load INV_STORAGE values into CDW
------------------------------------
--
--#EXECUTE_AT_TARGET
--#IGNORE_ERROR
drop table inv.stage_comp;
--#EXECUTE_AT_TARGET
create table inv.stage_comp like twg.comp;
--#EXECUTE_AT_TARGET
insert into inv.stage_comp (Comp_ID, CompTyp_Cd, Centr_Cd, Cust_ID,
  Comp_Corr_ID, Comp_Nm, Comp_Corr_Val, Comp_Strt_DtTm, Comp_End_DtTm, Comp_Ds)
select
  Comp_ID, CompTyp_Cd, Centr_Cd, Cust_ID, Comp_Corr_ID, Comp_Nm,
  Comp_Corr_Val, Comp_Strt_DtTm, Comp_End_DtTm, Comp_Ds
from twg.cur_comp
where
comptyp_cd='INV_STORAGE'
;

--#EXECUTE_AT_TARGET
INSERT INTO TWG.COMP
select
 0 as Comp_Id,
 'INV_STORAGE' as CompTyp_Cd,
 centr_l.Centr_Cd as Centr_Cd,
 cust.Cust_ID as Cust_ID,
 comp.Comp_Id as Comp_Corr_Id,
 n.child_comp_nm as comp_nm,
 n.Comp_Nm as Comp_Corr_Val,
 current timestamp - current timezone as Comp_Strt_DtTm ,
 '9999-01-01-00.00.00.000000' as Comp_End_DtTm,
 '' as Comp_Ds
from
 inv.stage_inv_stor n,
 inv.centr_lookup centr_l,
 inv.cust_lookup cust_l,
 twg.cust cust,
 twg.cur_comp comp
where
 n.comp_nm != ''
 and n.comp_nm = comp.comp_nm
 and ((cust_l.value = n.comp_nm AND cust_l.Cust_Acct_Cd = cust.Cust_Acct_Cd)
      OR cust_l.value = '@')
 and (centr_l.value = n.comp_nm OR centr_l.value = '@')
 and not exists (
  select 1
  from
   inv.stage_comp c
  where
   c.comp_nm = n.child_comp_nm
   and c.comp_corr_val = n.comp_nm )
;

-- Check for deleted components
--
insert into inv.stage_delete_comp
select * from inv.stage_comp c
where
 not exists (
  select 1
  from
  inv.stage_inv_stor n
 where
  c.comp_nm = n.child_comp_nm
  and c.comp_corr_val = n.comp_nm
 )
;

--#EXECUTE_AT_TARGET
insert into TWG.CompReln
        select 0 as CompReln_Id,
               c.Comp_Corr_Id as Comp_Source_Id,
               c.Comp_Id as Comp_Target_Id,
               'PCHILD' as RelnTyp_Cd,
               current timestamp - current timezone as CompReln_Strt_DtTm,
               '9999-01-01-00.00.00.000000' as CompReln_End_DtTm
        from TWG.Cur_Comp c
        where CompTyp_Cd = 'INV_STORAGE'
          and not exists
                (select 1 from TWG.Cur_CompReln r
                        where r.Comp_Source_Id = c.Comp_Corr_Id
                          and r.Comp_Target_Id = c.Comp_Id
                          and r.RelnTyp_Cd = 'PCHILD');

--#EXECUTE_AT_TARGET
insert into twg.compattr
select
 0 as compattr_id,
 c.comp_id,
 'INV_STO_TYPE' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 n.storage_type as CompAttr_Val
from
 inv.stage_inv_stor n,
 twg.cur_comp c
where
 n.child_comp_nm = c.comp_nm
 and n.comp_nm = c.comp_corr_val
 and n.storage_type != ''
 and not exists (
  select 1
  from
   twg.cur_compattr ca,
   twg.cur_comp c3
  where
   n.child_comp_nm = c3.comp_nm
   and n.comp_nm = c3.comp_corr_val
   and c3.comp_id = ca.comp_id
   and ca.CompAttr_Val = n.storage_type
   and ca.AttrTyp_Cd = 'INV_STO_TYPE')
union
select
 0 as compattr_id,
 c.comp_id,
 'MANUFACTURER' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 n.manufacturer as CompAttr_Val
from
 inv.stage_inv_stor n,
 twg.cur_comp c
where
 n.child_comp_nm = c.comp_nm
 and n.comp_nm = c.comp_corr_val
 and n.manufacturer != ''
 and not exists (
  select 1
  from
   twg.cur_compattr ca,
   twg.cur_comp c3
  where
   n.child_comp_nm = c3.comp_nm
   and n.comp_nm = c3.comp_corr_val
   and c3.comp_id = ca.comp_id
   and ca.CompAttr_Val = n.manufacturer
   and ca.AttrTyp_Cd = 'MANUFACTURER')
union
select
 0 as compattr_id,
 c.comp_id,
 'MODEL' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 n.model as CompAttr_Val
from
 inv.stage_inv_stor n,
 twg.cur_comp c
where
 n.child_comp_nm = c.comp_nm
 and n.comp_nm = c.comp_corr_val
 and n.model != ''
 and not exists (
  select 1
  from
   twg.cur_compattr ca,
   twg.cur_comp c3
  where
   n.child_comp_nm = c3.comp_nm
   and n.comp_nm = c3.comp_corr_val
   and c3.comp_id = ca.comp_id
   and ca.CompAttr_Val = n.model
   and ca.AttrTyp_Cd = 'MODEL')
union
select
 0 as compattr_id,
 c.comp_id,
 'INV_STO_SIZE_MB' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 char(n.hdisk_size_mb) as CompAttr_Val
from
 inv.stage_inv_stor n,
 twg.cur_comp c
where
 n.child_comp_nm = c.comp_nm
 and n.comp_nm = c.comp_corr_val
 and n.hdisk_size_mb != -1
 and not exists (
  select 1
  from
   twg.cur_compattr ca,
   twg.cur_comp c3
  where
   n.child_comp_nm = c3.comp_nm
   and n.comp_nm = c3.comp_corr_val
   and c3.comp_id = ca.comp_id
   and ca.CompAttr_Val=char(n.hdisk_size_mb)
   and ca.AttrTyp_Cd='INV_STO_SIZE_MB')
;


------------------------------------
-- Load INV_MEMORY values into CDW
------------------------------------
--
--#EXECUTE_AT_TARGET
--#IGNORE_ERROR
drop table inv.stage_comp;
--#EXECUTE_AT_TARGET
create table inv.stage_comp like twg.comp;
--#EXECUTE_AT_TARGET
insert into inv.stage_comp (Comp_ID, CompTyp_Cd, Centr_Cd, Cust_ID,
  Comp_Corr_ID, Comp_Nm, Comp_Corr_Val, Comp_Strt_DtTm, Comp_End_DtTm, Comp_Ds)
select
  Comp_ID, CompTyp_Cd, Centr_Cd, Cust_ID, Comp_Corr_ID, Comp_Nm,
  Comp_Corr_Val, Comp_Strt_DtTm, Comp_End_DtTm, Comp_Ds
from twg.cur_comp
where
comptyp_cd='INV_MEMORY'
;

--#EXECUTE_AT_TARGET
INSERT INTO TWG.COMP
select
 0 as Comp_Id,
 'INV_MEMORY' as CompTyp_Cd,
 centr_l.Centr_Cd as Centr_Cd,
 cust.Cust_ID as Cust_ID,
 comp.Comp_Id as Comp_Corr_Id,
 n.child_comp_nm as comp_nm,
 n.Comp_Nm as Comp_Corr_Val,
 current timestamp - current timezone as Comp_Strt_DtTm ,
 '9999-01-01-00.00.00.000000' as Comp_End_DtTm,
 '' as Comp_Ds
from
 inv.stage_inv_memory n,
 inv.centr_lookup centr_l,
 inv.cust_lookup cust_l,
 twg.cust cust,
 twg.cur_comp comp
where
 n.comp_nm != ''
 and n.comp_nm = comp.comp_nm
 and ((cust_l.value = n.comp_nm AND cust_l.Cust_Acct_Cd = cust.Cust_Acct_Cd)
      OR cust_l.value = '@')
 and (centr_l.value = n.comp_nm OR centr_l.value = '@')
 and not exists (
  select 1
  from
   inv.stage_comp c
  where
   c.comp_nm = n.child_comp_nm
   and c.comp_corr_val = n.comp_nm )
;

-- Check for deleted components
--
insert into inv.stage_delete_comp
select * from inv.stage_comp c
where
 not exists (
  select 1
  from
  inv.stage_inv_memory n
 where
  c.comp_nm = n.child_comp_nm
  and c.comp_corr_val = n.comp_nm
 )
;

--#EXECUTE_AT_TARGET
insert into TWG.CompReln
        select 0 as CompReln_Id,
               c.Comp_Corr_Id as Comp_Source_Id,
               c.Comp_Id as Comp_Target_Id,
               'PCHILD' as RelnTyp_Cd,
               current timestamp - current timezone as CompReln_Strt_DtTm,
               '9999-01-01-00.00.00.000000' as CompReln_End_DtTm
        from TWG.Cur_Comp c
        where CompTyp_Cd = 'INV_MEMORY'
          and not exists
                (select 1 from TWG.Cur_CompReln r
                        where r.Comp_Source_Id = c.Comp_Corr_Id
                          and r.Comp_Target_Id = c.Comp_Id
                          and r.RelnTyp_Cd = 'PCHILD');

--#EXECUTE_AT_TARGET
insert into twg.compattr
select
 0 as compattr_id,
 c.comp_id,
 'INV_MEM_TYPE' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 n.mem_type as CompAttr_Val
from
 inv.stage_inv_memory n,
 twg.cur_comp c
where
 n.child_comp_nm = c.comp_nm
 and n.comp_nm = c.comp_corr_val
 and n.mem_type != ''
 and not exists (
  select 1
  from
   twg.cur_compattr ca,
   twg.cur_comp c3
  where
   n.child_comp_nm = c3.comp_nm
   and n.comp_nm = c3.comp_corr_val
   and c3.comp_id = ca.comp_id
   and ca.CompAttr_Val = n.mem_type
   and ca.AttrTyp_Cd = 'INV_MEM_TYPE')
union
select
 0 as compattr_id,
 c.comp_id,
 'INV_MEM_PACKAGE' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 n.packaging as CompAttr_Val
from
 inv.stage_inv_memory n,
 twg.cur_comp c
where
 n.child_comp_nm = c.comp_nm
 and n.comp_nm = c.comp_corr_val
 and n.packaging != ''
 and not exists (
  select 1
  from
   twg.cur_compattr ca,
   twg.cur_comp c3
  where
   n.child_comp_nm = c3.comp_nm
   and n.comp_nm = c3.comp_corr_val
   and c3.comp_id = ca.comp_id
   and ca.CompAttr_Val = n.packaging
   and ca.AttrTyp_Cd = 'INV_MEM_PACKAGE')
union
select
 0 as compattr_id,
 c.comp_id,
 'INV_MEM_SOCKET' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 n.socket_name as CompAttr_Val
from
 inv.stage_inv_memory n,
 twg.cur_comp c
where
 n.child_comp_nm = c.comp_nm
 and n.comp_nm = c.comp_corr_val
 and n.socket_name != ''
 and not exists (
  select 1
  from
   twg.cur_compattr ca,
   twg.cur_comp c3
  where
   n.child_comp_nm = c3.comp_nm
   and n.comp_nm = c3.comp_corr_val
   and c3.comp_id = ca.comp_id
   and ca.CompAttr_Val = n.socket_name
   and ca.AttrTyp_Cd = 'INV_MEM_SOCKET')
union
select
 0 as compattr_id,
 c.comp_id,
 'INV_MEM_SIZE_MB' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 char(n.module_size_mb) as CompAttr_Val
from
 inv.stage_inv_memory n,
 twg.cur_comp c
where
 n.child_comp_nm = c.comp_nm
 and n.comp_nm = c.comp_corr_val
 and n.module_size_mb != -1
 and not exists (
  select 1
  from
   twg.cur_compattr ca,
   twg.cur_comp c3
  where
   n.child_comp_nm = c3.comp_nm
   and n.comp_nm = c3.comp_corr_val
   and c3.comp_id = ca.comp_id
   and ca.CompAttr_Val=char(n.module_size_mb)
   and ca.AttrTyp_Cd='INV_MEM_SIZE_MB')
;

-- Update end timestamps for deleted components
--
update twg.comp
set
 Comp_End_DtTm = current timestamp - current timezone
where
 comp_id IN (select comp_id from inv.stage_delete_comp)
;

update twg.compreln
set
 CompReln_End_DtTm = current timestamp - current timezone
where
 comp_target_id IN (select comp_id from inv.stage_delete_comp)
;

update twg.compattr
set
 CompAttr_End_DtTm = current timestamp - current timezone
where
 comp_id IN (select comp_id from inv.stage_delete_comp)
;
