--  @(#)37    1.7  src/tedw_apps/inv/install/v420/etl/sql/INV_m10_s010_buildMart.db2, inventory, inventory_4.2.2, 20041119  11/15/04  05:25:35
--
-- Licensed Materials - Property of IBM
--
-- 5698-INV
--
-- (C) Copyright IBM Corp. 2002 All Rights Reserved
--
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with
-- IBM Corp

----------------------------------------
-- Purpose: Load CM data from CDW to Mart.
----------------------------------------

---------------------------------
-- insert into the metric dimension table
------------------------------
--NOTE:This process will only happen once. We initially insert the data into the
--     staging table in the cdw/dml script.

-- set the high value for the data to be extracted
update TWG.Extract_Control set 
 extctl_to_intseq = (select max(metric_id) from inv.stage_d_metric),
 extctl_to_dttm = (select max(insert_dttm) from inv.stage_d_metric)
where 
 extctl_source='inv.stage_d_metric' and
 extctl_target='inv.D_SWD_METRIC' and
 (select count(*) from inv.stage_d_metric) > 0
;

--#INSERT_INTO_TARGET
insert into inv.D_SWD_METRIC
select 
  d.metric_id as metric_id,
  d.Met_Name as Met_Name,
  d.Met_Desc as Met_Desc,
  d.Met_Units as Met_units,
  d.Met_Category as Met_Category,
  d.min_exists as MIN_Exists,
  d.max_exists as MAX_Exists,
  d.avg_exists as AVG_Exists,
  d.total_exists as Total_Exists,
  d.Msrc_Nm as MSrc_Nm
from
  inv.stage_d_metric d,
  twg.Extract_Control ec
where
  ec.Extctl_Source = 'inv.stage_d_metric' and
  ec.Extctl_Target = 'inv.D_SWD_METRIC' and
  d.metric_id > ec.extctl_from_intseq and
  d.metric_id <= ec.extctl_to_intseq 
;

-- Confirm the insertion of data by inserting a row into TWG.EXTRACT_LOG.
-- A trigger gets fired which updates the extract control table's from data with
-- the current to data.

insert into twg.extract_log
select
 ec.extctl_source as extlog_source,
 ec.extctl_target as extlog_target,
 current timestamp - current timezone as extlog_done_dttm,
 ec.extctl_from_rawseq as extlog_from_rawseq,
 ec.extctl_to_rawseq as extlog_to_rawseq,
 ec.extctl_from_intseq as extlog_from_intseq,
 ec.extctl_to_intseq as extlog_to_intseq,
 ec.extctl_from_dttm as extlog_from_dttm,
 ec.extctl_to_dttm as extlog_to_dttm
from 
 TWG.Extract_control ec
where
 ec.extctl_source = 'inv.stage_d_metric' and
 ec.extctl_target = 'inv.D_SWD_METRIC'
; 

--Prune any data that is too old based on the values in inv.prune_mart_control

--#EXECUTE_AT_TARGET
delete from inv.F_SWD_DAY f
where
  (date(current timestamp - current timezone) - date(f.Meas_date)) >
  (select PMartC_Duration from inv.prune_mart_control p
   where p.table_name = 'inv.F_SWD_DAY')
;

-- /* inv.stage_host_state */
-- set the high value for the data to be extracted
update TWG.Extract_Control set 
 extctl_to_intseq = ( select max(Comp_ID) from twg.Comp)
where 
 extctl_source='TWG.COMP' and
 extctl_target='inv.stage_host_state'
;

--#IGNORE_ERROR
drop table inv.stage_host_state;

create table inv.stage_host_state like inv.stage_host_state_t;

insert into inv.stage_host_state
select  
  c1.comp_id as host_id,  
  c1.comp_nm as hostname,  
  value(ca1.CompAttr_Val, '') as ip_address,  
  value(ca2.CompAttr_Val, '') as os_name,  
  value(integer(ca3.CompAttr_Val), -1) as major_version,  
  value(integer(ca4.CompAttr_Val), -1) as minor_version,  
  value(ca5.CompAttr_Val, '') as sub_version,  
  value(integer(ca6.CompAttr_Val), -1) as physical_mem_kb,  
  value(integer(ca7.CompAttr_Val), -1) as num_cpus,  
  value(ca8.CompAttr_Val, '') as cpu_model,  
  value(integer(ca9.CompAttr_Val), -1) as cpu_speed
from  
  twg.cur_comp c1  
  left outer join 
  twg.cur_compattr ca1 
  on c1.comp_id= ca1.comp_id
  and ca1.attrtyp_cd = 'LAST_IP_ADDRESS',  
  twg.cur_comp c2  
  left outer join 
  twg.cur_compattr ca2  
  on c2.comp_id= ca2.comp_id
  and ca2.attrtyp_cd = 'OS_NAME',  
  twg.cur_comp c3  
  left outer join 
  twg.cur_compattr ca3  
  on c3.comp_id= ca3.comp_id
  and ca3.attrtyp_cd = 'MAJOR_VERSION',  
  twg.cur_comp c4  
  left outer join 
  twg.cur_compattr ca4  
  on c4.comp_id= ca4.comp_id
  and ca4.attrtyp_cd = 'MINOR_VERSION',  
  twg.cur_comp c5  
  left outer join 
  twg.cur_compattr ca5  
  on c5.comp_id= ca5.comp_id
  and ca5.attrtyp_cd = 'SUB_VERSION',  
  twg.cur_comp c6  
  left outer join 
  twg.cur_compattr ca6  
  on c6.comp_id= ca6.comp_id
  and ca6.attrtyp_cd = 'INV_PHYSICAL_MEM',  
  twg.cur_comp c7  
  left outer join 
  twg.cur_compattr ca7  
  on c7.comp_id= ca7.comp_id
  and ca7.attrtyp_cd = 'INV_NUM_CPU',  
  twg.cur_comp c8  
  left outer join 
  twg.cur_compattr ca8 
  on c8.comp_id= ca8.comp_id
  and ca8.attrtyp_cd = 'INV_CPU_MODEL',
  twg.cur_comp c9  
  left outer join 
  twg.cur_compattr ca9
  on c9.comp_id= ca9.comp_id
  and ca9.attrtyp_cd = 'INV_CPU_CUR_SPEED',
  twg.Extract_Control ec
where   
  c1.comptyp_cd IN ('IP_HOST', 'IP_INTERFACE') and  
  c1.comp_id > ec.extctl_from_intseq and 
  c1.comp_id <= ec.extctl_to_intseq and
  ec.extctl_source='TWG.COMP' and
  ec.extctl_target='inv.stage_host_state' and
  c2.comptyp_cd IN ('IP_HOST', 'IP_INTERFACE') and  
  c3.comptyp_cd IN ('IP_HOST', 'IP_INTERFACE') and  
  c4.comptyp_cd IN ('IP_HOST', 'IP_INTERFACE') and  
  c5.comptyp_cd IN ('IP_HOST', 'IP_INTERFACE') and  
  c6.comptyp_cd IN ('IP_HOST', 'IP_INTERFACE') and  
  c7.comptyp_cd IN ('IP_HOST', 'IP_INTERFACE') and  
  c8.comptyp_cd IN ('IP_HOST', 'IP_INTERFACE') and  
  c9.comptyp_cd IN ('IP_HOST', 'IP_INTERFACE') and  
  c1.comp_id=c2.comp_id and
  c1.comp_id=c3.comp_id and
  c1.comp_id=c4.comp_id and
  c1.comp_id=c5.comp_id and
  c1.comp_id=c6.comp_id and
  c1.comp_id=c7.comp_id and
  c1.comp_id=c8.comp_id and
  c1.comp_id=c9.comp_id
;

-- We could base the views on stage_host_state_t, but then we would
-- have to "delete from stage_host_state_t" and "insert into stage_host_state_t
-- select * from stage_host_state." The problem with this is the space
-- isn't reclaimed until you do a db reorg, so I chose to recreate the views here.

--#IGNORE_ERROR
drop view inv.ip_address_v1;
create view inv.ip_address_v1 as
select
  ip_address,
  LOCATE('.',ip_address) - 1 as addr_w_end,
  LOCATE('.',ip_address,LOCATE('.',ip_address) + 1) -1 as addr_x_end,
  LOCATE('.',ip_address,LOCATE('.',ip_address,LOCATE('.',ip_address) + 1) + 1) -1 as addr_y_end
from
  inv.stage_host_state
group by
  ip_address
;

--#IGNORE_ERROR
drop view inv.hostname_v1;
create view inv.hostname_v1 as 
select 
  hostname,
  LOCATE('.',hostname) + 1 as name_b_beg,
  LOCATE('.',hostname,LOCATE('.',hostname) + 1) + 1 as name_c_beg,
  LOCATE('.',hostname,LOCATE('.',hostname,LOCATE('.',hostname) + 1) + 1) + 1 as name_d_beg,
  LOCATE('.',hostname,LOCATE('.',hostname,LOCATE('.',hostname,LOCATE('.',hostname) + 1) + 1) + 1) +1 as name_e_beg
from
  inv.stage_host_state
group by
  hostname
;

--#IGNORE_ERROR
drop view inv.hostname_v2;
create view inv.hostname_v2 as
select
  hostname,
  name_b_beg,
  name_c_beg,
  name_d_beg,
  name_e_beg,
  case  when (name_b_beg > 1 and name_c_beg > 1 and name_d_beg > 1 and name_e_beg > 1) then 5
      when (name_b_beg > 1 and name_c_beg > 1 and name_d_beg > 1 and name_e_beg = 1) then 4
      when (name_b_beg > 1 and name_c_beg > 1 and name_d_beg = 1 ) then 3
      when (name_b_beg > 1 and name_c_beg = 1 ) then 2
      when (name_b_beg = 1 ) then 1
  end   as name_parts
from
  inv.hostname_v1
;

--#IGNORE_ERROR
drop table inv.stage_ip_address;

create table inv.stage_ip_address like inv.stage_ip_address_t;

insert into inv.stage_ip_address
select  
  ip_address, 
  CASE 
     when ip_address is null THEN 'unknown'      
    when addr_w_end > 0 THEN SUBSTR(ip_address, 1, addr_w_end)      
    else 'unknown'               
  END  as IP_A_NETWORK, 
  CASE 
    when ip_address is null THEN 'unknown'      
    when addr_x_end > 0 THEN SUBSTR(ip_address, 1, addr_x_end)      
    else 'unknown'               
  END  as IP_B_NETWORK, 
  CASE 
    when ip_address is null THEN 'unknown'      
    when addr_y_end > 0 THEN SUBSTR(ip_address, 1, addr_y_end)      
    else 'unknown'               
  END  as IP_C_NETWORK 
from inv.ip_address_v1
;

--#IGNORE_ERROR
drop table inv.stage_hostname;

create table inv.stage_hostname like inv.stage_hostname_t;

insert into inv.stage_hostname
select    
  hostname,   
  CASE 
    when name_parts = 5 then substr(hostname,name_d_beg)        
    when name_parts = 4 then substr(hostname,name_c_beg)        
    when name_parts = 3 then substr(hostname,name_b_beg)        
    else 'no value'   
  END as NETWORK_DOMAIN,   
  CASE 
    when name_parts = 5 then substr(hostname,name_c_beg)        
    when name_parts = 4 then substr(hostname,name_b_beg)        
    else 'no value'   
  END as NETWORK_SUBDOMAIN,   
  CASE 
    when name_parts = 5 then substr(hostname,name_b_beg)        
    else 'no value'   
  END as NETWORK_SUBDOMAIN_2,   
  CASE 
    when hostname is null THEN null        
    when name_b_beg > 1 THEN SUBSTR(hostname, 1, name_b_beg - 2)        
    else hostname         
  END  as short_hostname 
from   inv.hostname_v2
;

--#INSERT_INTO_TARGET
insert into inv.D_SWD_HOST
select    
  hst.host_id, 
  cust.cust_acct_cd,
  centr.centr_cd,   
  hst.hostname,    
  hst.ip_address,    
  hst.os_name,    
  hst.major_version,    
  hst.minor_version,    
  hst.sub_version,    
  hst.physical_mem_kb,    
  hst.num_cpus,    
  hst.cpu_model,    
  hst.cpu_speed_mhz,    
  ip.IP_A_NETWORK,    
  ip.IP_B_NETWORK,    
  ip.IP_C_NETWORK,    
  h.NETWORK_DOMAIN,    
  h.NETWORK_SUBDOMAIN,    
  h.NETWORK_SUBDOMAIN_2,    
  h.SHORT_HOSTNAME,    
  case 
    when physical_mem_kb > 0 and physical_mem_kb <= 32768          
      then '0-32 Megabytes'         
    when physical_mem_kb > 32768 and physical_mem_kb <= 65536          
      then '32-64 Megabytes'         
    when physical_mem_kb > 65536 and physical_mem_kb <= 262144          
      then '64-256 Megabytes'         
    when physical_mem_kb > 262144 and physical_mem_kb <= 1048576          
      then '256-1024 Megabytes'         
    when physical_mem_kb > 1048576 and physical_mem_kb <= 4194304          
       then '1-4 Gigabytes'         
    when physical_mem_kb > 4194304          
       then '4 Gigabytes and more'         
    else 'unknown'     
  end as PHYSICAL_MEMORY_RANGE,    
  LTRIM(RTRIM(hst.os_name)) concat ' ' concat LTRIM(RTRIM(char(hst.major_version))) concat '.' concat LTRIM(RTRIM(char(hst.minor_version))) as os_name_version   
from    
  inv.stage_host_state hst,    
  inv.stage_ip_address ip,    
  inv.stage_hostname h,    
  inv.cust_lookup cust,
  inv.centr_lookup centr 
where    
  hst.ip_address=ip.ip_address and    
  hst.hostname=h.hostname and    
  (cust.value = '@' or hst.hostname=cust.value) and   
  (centr.value = '@' or hst.hostname=centr.value)
;

-- Confirm the insertion of data by inserting a row into TWG.EXTRACT_LOG.
-- A trigger gets fired which updates the extract control table's from data with
-- the current to data.

insert into twg.Extract_Log
select
 ec.extctl_source as extlog_source,
 ec.extctl_target as extlog_target,
 current timestamp - current timezone as extlog_done_dttm,
 ec.extctl_from_rawseq as extlog_from_rawseq,
 ec.extctl_to_rawseq as extlog_to_rawseq,
 ec.extctl_from_intseq as extlog_from_intseq,
 ec.extctl_to_intseq as extlog_to_intseq,
 ec.extctl_from_dttm as extlog_from_dttm,
 ec.extctl_to_dttm as extlog_to_dttm
from 
 TWG.Extract_Control ec
where
 ec.extctl_source = 'TWG.COMP' and
 ec.extctl_target = 'inv.stage_host_state'
; 
-------************************************************************

--#IGNORE_ERROR
drop table inv.stage_file_pack;
create table inv.stage_file_pack like inv.stage_file_pack_t;

--The fp_tme_oid and fp_src_host can be null in the source database.
--So we need left outer join.

insert into inv.stage_file_pack
select  
  c1.Comp_ID as fp_id,
  ca1.CompAttr_Val as fp_name,  
  ca2.CompAttr_Val as fp_version,  
  c1.Comp_Nm as fp_name_version,
  value(ca3.CompAttr_Val,'') as fp_tme_oid,
  value(ca4.CompAttr_Val,'') as fp_src_host
from  
  twg.cur_comp c1,  
  twg.cur_compattr ca1,  
  twg.cur_compattr ca2,  
  twg.cur_compattr ca3, 
  twg.cur_compattr ca4
where
  c1.comp_id = ca3.comp_id
  and c1.comptyp_cd = 'DIS_FILEPACK'  
  and ca3.attrtyp_cd = 'DIS_FP_TME_OID'
  and c1.comp_id= ca4.comp_id 
  and ca4.attrtyp_cd = 'DIS_FP_SRC_HOST' and  
  c1.comp_id = ca1.comp_id and 
  ca1.attrtyp_cd = 'DIS_FP_NAME' and  
  c1.comp_id = ca2.comp_id and 
  ca2.attrtyp_cd = 'VERSION'
;


-- /* inv.stage_d_swd_dist */
-- set the high value for the data to be extracted
update TWG.Extract_Control set 
 extctl_to_intseq = ( select max(Comp_ID) from twg.Comp)
where 
 extctl_source='TWG.COMP' and
 extctl_target='inv.stage_d_swd_dist'
;

--#IGNORE_ERROR
drop table inv.stage_d_swd_dist;
create table inv.stage_d_swd_dist like inv.stage_d_swd_dist_t;

insert into inv.stage_d_swd_dist
select  
  c1.Comp_ID as dist_id,
  c1.Comp_Corr_ID as host_id,
  c1.Comp_Nm as mdist_id,
  integer(ca1.CompAttr_Val) as dist_size_kb,  
  fp.fp_name as filepack_name,  
  fp.fp_version as filepack_version,  
  ca2.CompAttr_Val as sd_action,  
  ca3.CompAttr_Val as sd_state,  
  ca4.CompAttr_Val as md_state 
from  
  twg.cur_comp c1,  
  twg.cur_compattr ca1,  
  twg.cur_compattr ca2,  
  twg.cur_compattr ca3,  
  twg.cur_compattr ca4,
  twg.cur_compattr ca5,
  inv.stage_file_pack fp,
  twg.Extract_Control ec
where   
  c1.comptyp_cd = 'DIS_SWD' and  
  c1.comp_id > ec.extctl_from_intseq and 
  c1.comp_id <= ec.extctl_to_intseq and
  ec.extctl_source='TWG.COMP' and
  ec.extctl_target='inv.stage_d_swd_dist' and
  c1.comp_id = ca1.comp_id and 
  ca1.attrtyp_cd = 'DIS_MD_SIZE_KB' and  
  c1.comp_id = ca2.comp_id and 
  ca2.attrtyp_cd = 'DIS_SD_OPERATION' and  
  c1.comp_id = ca3.comp_id and 
  ca3.attrtyp_cd = 'DIS_SD_STATE' and  
  c1.comp_id = ca4.comp_id and 
  ca4.attrtyp_cd = 'DIS_MD_STATE' and 
  c1.comp_id = ca5.comp_id and 
  ca5.attrtyp_cd = 'DIS_FP_TME_OID' and  
  ca5.CompAttr_Val = fp.fp_tme_oid
;


--#INSERT_INTO_TARGET
insert into inv.D_SWD_DIST
select dist_id as dist_id, 
mdist_id as mdist_id,
dist_size_kb as dist_size_kb,
filepack_name as filepack_name, 
filepack_version as filepack_version,
LTRIM(RTRIM(filepack_name)) concat ' ' concat LTRIM(RTRIM(filepack_version)) as filepack_name_version, 
sd_action as sd_action,
sd_state as sd_state,
md_state  as md_state
from
  inv.stage_d_swd_dist
;

-- Confirm the insertion of data by inserting a row into TWG.EXTRACT_LOG.
-- A trigger gets fired which updates the extract control table's from data with
-- the current to data.

insert into twg.Extract_Log
select
 ec.extctl_source as extlog_source,
 ec.extctl_target as extlog_target,
 current timestamp - current timezone as extlog_done_dttm,
 ec.extctl_from_rawseq as extlog_from_rawseq,
 ec.extctl_to_rawseq as extlog_to_rawseq,
 ec.extctl_from_intseq as extlog_from_intseq,
 ec.extctl_to_intseq as extlog_to_intseq,
 ec.extctl_from_dttm as extlog_from_dttm,
 ec.extctl_to_dttm as extlog_to_dttm
from 
 TWG.Extract_Control ec
where
 ec.extctl_source = 'TWG.COMP' and
 ec.extctl_target = 'inv.stage_d_swd_dist'
; 
--****************************************************************************

-- set the high value for the data to be extracted
update TWG.Extract_Control set 
 extctl_to_intseq = ( select max(msmt_id) from twg.msmt)
where 
 extctl_source='TWG.MSMT' and
 extctl_target='inv.STAGE_F_SWD_DAY' and
 (select count(*) from twg.msmt) > 0
;

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table inv.STAGE_F_SWD_DAY;

--#EXECUTE_AT_TARGET
create table inv.STAGE_F_SWD_DAY like inv.F_SWD_DAY_T;

--#INSERT_INTO_TARGET
insert into inv.STAGE_F_SWD_DAY
select    
  m.msmttyp_id as Metric_ID,  
  d.host_id as HOST_ID,
  m.comp_id as DIST_ID,
  m.msmt_strt_dt as Meas_date,   
  decimal(m.msmt_min_val,9,2) as Min_value,   
  decimal(m.msmt_max_val,9,2) as Max_value,   
  decimal(m.msmt_avg_val,9,2) as Avg_value,
  decimal(m.msmt_tot_val,9,2) as Total_value,
  m.msmt_smpl_cnt as sample_count
from   
  twg.Msmt m, 
  twg.MsmtTyp mt, 
  twg.Extract_Control ec,
  inv.STAGE_D_SWD_DIST d
where   
  m.msmt_id > ec.extctl_from_intseq and 
  m.msmt_id <= ec.extctl_to_intseq and
  ec.extctl_source='TWG.MSMT' and
  ec.extctl_target='inv.STAGE_F_SWD_DAY' and
  (m.msmttyp_id = mt.msmttyp_id and mt.msrc_cd = 'DIS') and
  m.tmsum_cd = 'D' and   
  m.Comp_ID = d.dist_id
;

--#EXECUTE_AT_TARGET
insert into inv.F_SWD_DAY
select * from inv.STAGE_F_SWD_DAY
;

-- Confirm the insertion of data by inserting a row into TWG.EXTRACT_LOG.
-- A trigger gets fired which updates the extract control table's from data with
-- the current to data.

insert into twg.Extract_Log
select
 ec.extctl_source as extlog_source,
 ec.extctl_target as extlog_target,
 current timestamp - current timezone as extlog_done_dttm,
 ec.extctl_from_rawseq as extlog_from_rawseq,
 ec.extctl_to_rawseq as extlog_to_rawseq,
 ec.extctl_from_intseq as extlog_from_intseq,
 ec.extctl_to_intseq as extlog_to_intseq,
 ec.extctl_from_dttm as extlog_from_dttm,
 ec.extctl_to_dttm as extlog_to_dttm
from 
 TWG.Extract_Control ec
where
 ec.extctl_source = 'TWG.MSMT' and
 ec.extctl_target = 'inv.STAGE_F_SWD_DAY'
; 

--The f_week, f_month tables are populated by executing 
--the rollup.sh UDP ?.
